-- AEROSOFT AIRBUS A3XX PRO
-- Module version 1.9
-- Jun 2020

-- Works with Aerosoft A318/319/320/321/330 Profession

-- Those functions with the prefix A33_ are exclusive to A330

-- ## Autopilot controls #####################################

-- $$ Autopilot

function AB_AP_both_on ()
    AB_AP_AP1_on ()
    AB_AP_AP2_on ()
end

function AB_AP_both_off ()
    AB_AP_AP1_off ()
    AB_AP_AP2_off ()
end

function AB_AP_AP1_on ()
   Lvar = "AB_AP_AP1"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    if AB_AP_AP2_check() and not AB_AP_APPR_check() then
       AB_AP_AP2_off()
    end
    ipc.writeLvar(Lvar, 1)
    DspShow ("AP1", "on")
end

function AB_AP_AP1_off ()
   Lvar = "AB_AP_AP1"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("AP1", "off")
end

function AB_AP_AP1_toggle ()
	if _tl("AB_AP_AP1", 0) then
		AB_AP_AP1_on ()
	else
		AB_AP_AP1_off ()
	end
end

function AB_AP_AP2_on()
    AB_AP_AP2_on2()
    _sleep(500)
    AB_AP_AP2_on2()
end

function AB_AP_AP2_off ()
   Lvar = "AB_AP_AP2"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("AP2", "off")
end

function AB_AP_AP2_toggle ()
	if _tl("AB_AP_AP2", 0) then
		AB_AP_AP2_on ()
	else
		AB_AP_AP2_off ()
	end
end

function AB_AP_Disengage ()
    if ipc.readLvar("AB_AP_AP1") == 1 or
        ipc.readLvar("AB_AP_AP2") == 1 then
        AB_AP_AP1_off()
        AB_AP_AP2_off()
    end
end

function AB_AP_AP2_on2 ()
   Lvar = "AB_AP_AP2"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    if AB_AP_AP1_check() and not AB_AP_APPR_check() then
        AB_AP_AP1_off()
    end
    DspShow ("AP2", "on")
end

function AB_AP_AP1_check ()
    if ipc.readLvar("AB_AP_AP1") == 1 then
        return true
    else
        return false
    end
end

function AB_AP_AP2_check ()
    if ipc.readLvar("AB_AP_AP2") == 1 then
        return true
    else
        return false
    end
end

function AB_AP_APPR_check ()
    if ipc.readLvar("AB_AP_LOC2") == 1 then
        return true
    else
        return false
    end
end

function AB_AP_LOC_check ()
    if ipc.readLvar("AB_AP_LOC") == 1 then
        return true
    else
        return false
    end
end

-- $$ Autothrottle

function AB_AP_ATHR_on ()
   Lvar = "AB_AP_ATHR"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("ATHR", "on")
end

function AB_AP_ATHR_off ()
   Lvar = "AB_AP_ATHR"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("ATHR", "off")
end

function AB_AP_ATHR_toggle ()
	if _tl("AB_AP_ATHR") then
		AB_AP_ATHR_on ()
	else
		AB_AP_ATHR_off ()
	end
end

-- $$ Localiser

function AB_AP_LOC_on ()
    -- Switch off APP if on
    if ipc.readLvar("AB_AP_LOC2") == 1 then
        AB_AP_APPR_off ()
    end
    -- Switch on LOC
   Lvar = "AB_AP_LOC"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("LOC", "on")

end

function AB_AP_LOC_off ()
   Lvar = "AB_AP_LOC"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("LOC", "off")
end

function AB_AP_LOC_toggle ()
	if _tl("AB_AP_LOC", 0) then
		AB_AP_LOC_on ()
	else
		AB_AP_LOC_off ()
	end
end

-- $$ Approach

function AB_AP_APPR_on ()
    -- Switch off LOC if on
    if ipc.readLvar("AB_AP_LOC") == 1 then AB_AP_LOC_off () end
    -- Switch on LOC
   Lvar = "AB_AP_LOC2"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("APPR", "on")
end

function AB_AP_APPR_off ()
   Lvar = "AB_AP_LOC2"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    if AB_AP_AP1_check () and AB_AP_AP2_check () then
        AB_AP_AP2_off()
    end
    DspShow ("APPR", "off")
end

function AB_AP_APPR_toggle ()
	if _tl("AB_AP_LOC2", 0) then
		AB_AP_APPR_on ()
	else
		AB_AP_APPR_off ()
	end
end

-- $$ Expedite

function AB_AP_EXPED_on ()
   Lvar = "AB_AP_EXP"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("EXPD", "on")
end

function AB_AP_EXPED_off ()
   Lvar = "AB_AP_EXP"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("EXPD", "off")
end

function AB_AP_EXPED_toggle ()
	if _tl("AB_AP_EXP", 0) then
		AB_AP_EXPED_on ()
	else
		AB_AP_EXPED_off ()
	end
end

-- $$ AP FCU buttons

function AB_MPL_FD_on ()
   Lvar = "AB_MPL_FD"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("FD", "on")
end

function AB_MPL_FD_off ()
   Lvar = "AB_MPL_FD"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("FD", "off")
end

function AB_MPL_FD_toggle ()
	if _tl("AB_MPL_FD", 0) then
		AB_MPL_FD_on ()
	else
		AB_MPL_FD_off ()
	end
end

function AB_MPL_FD_FO_on ()
   Lvar = "AB_MPL_FO_FD"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("FD", "on")
end

function AB_MPL_FD_FO_off ()
   Lvar = "AB_MPL_FO_FD"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("FD", "off")
end

function AB_MPL_FD_FO_toggle ()
	if _tl("AB_MPL_FO_FD", 0) then
		AB_MPL_FD_FO_on ()
	else
		AB_MPL_FD_FO_off ()
	end
end

function AB_MPL_FD_Both_on ()
    AB_MPL_FD_on ()
    AB_MPL_FD_FO_on ()
end

function AB_MPL_FD_Both_off ()
    AB_MPL_FD_off ()
    AB_MPL_FD_FO_off ()
end

function AB_MPL_FD_Both_toggle ()
    AB_MPL_FD_toggle ()
    AB_MPL_FD_FO_toggle ()
end

function AB_MPL_LS_on ()
   Lvar = "AB_MPL_ILS"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspILS(true)
    DspShow ("LS", "on")
end

function AB_MPL_LS_off ()
   Lvar = "AB_MPL_ILS"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspILS(false)
    DspShow ("LS", "off")
end

function AB_MPL_LS_toggle ()
	if _tl("AB_MPL_ILS", 0) then
		AB_MPL_LS_on ()
	else
		AB_MPL_LS_off ()
	end
end

function AB_MPL_LS_FO_on ()
   Lvar = "AB_MPL_FO_ILS"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspILS(true)
    DspShow ("LSFO", "on")
end

function AB_MPL_LS_FO_off ()
   Lvar = "AB_MPL_FO_ILS"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspILS(false)
    DspShow ("LSFO", "off")
end

function AB_MPL_LS_FO_toggle ()
	if _tl("AB_MPL_FO_ILS", 0) then
		AB_MPL_LS_FO_on ()
	else
		AB_MPL_LS_FO_off ()
	end
end

function AB_MPL_LS_Both_on ()
    AB_MPL_LS_on ()
    AB_MPL_LS_FO_on ()
end

function AB_MPL_LS_Both_off ()
    AB_MPL_LS_off ()
    AB_MPL_LS_FO_off ()
end

function AB_MPL_LS_Both_toggle ()
    AB_MPL_LS_toggle ()
    AB_MPL_LS_FO_toggle ()
end

-- $$ SPD/MACH

function AB_AP_SPDMACH_spd ()
    ipc.writeLvar("AB_AP_SPDMACH", 0)
    AB_DspSPDtxt(0)
    AB_DspSPD()
    AB_OVH_Pushbutton ()
    DspShow("Disp","SPD")
end

function AB_AP_SPDMACH_mach ()
    ipc.writeLvar("AB_AP_SPDMACH", 1)
    AB_DspSPDtxt(1)
    AB_DspSPD()
    AB_OVH_Pushbutton ()
    DspShow ("Disp", "MACH")
end

function AB_AP_SPDMACH_toggle ()
	if _tl("AB_AP_SPDMACH", 1) then
       AB_AP_SPDMACH_spd ()
	else
       AB_AP_SPDMACH_mach ()
	end
end

-- $$ HDG/TRK

function AB_AP_HDGTRK_hdg ()
    ipc.writeLvar("AB_AP_HDGTRK", 0)
    AB_DspHDGtxt(0)
    AB_OVH_Pushbutton ()
    DspShow ("Disp", "HDG")
end

function AB_AP_HDGTRK_trk ()
    ipc.writeLvar("AB_AP_HDGTRK", 1)
    AB_DspHDGtxt(1)
    AB_OVH_Pushbutton ()
    DspShow ("Disp", "TRK")
end

function AB_AP_HDGTRK_toggle ()
	if _tl("AB_AP_HDGTRK", 1) then
       AB_AP_HDGTRK_hdg ()
	else
       AB_AP_HDGTRK_trk ()
	end
end

-- ## AP Rotaries  #################################################

-- $$ SPD rotaries

function AB_SPD_plus ()
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    if SpdMachVar == 0 then
   Lvar = "AB_AP_SPEED_Select"
        Lval = round(ipc.readLvar(Lvar))

        if Lval < 399 then
            AddVar = 1
        else
            AddVar = 0
        end
        DspSPD(Lval + AddVar)
    elseif SpdMachVar == 1 then
   Lvar = "AB_AP_Mach_Select"
        Lval = ipc.readLvar(Lvar)
        if Lval < 0.80 then
            AddVar = 0.01
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(Lval + AddVar + 0.005))
    end
    _sleep(20)
    ipc.writeLvar(Lvar, Lval + AddVar)
end

function AB_SPD_plusfast ()
    if SpdMachVar == 0 then
   Lvar = "AB_AP_SPEED_Select"
        Lval = round(ipc.readLvar(Lvar))
        if Lval < 399 then
            AddVar = 10
        else
            AddVar = 0
        end
        DspSPD(Lval + AddVar)
    elseif SpdMachVar == 1 then
   Lvar = "AB_AP_Mach_Select"
        Lval = ipc.readLvar(Lvar)
        if Lval < 0.80 then
            AddVar = 0.10
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(Lval + AddVar + 0.005))
    end
    _sleep(20)
    ipc.writeLvar(Lvar, Lval + AddVar)
end

function AB_SPD_minus ()
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    if SpdMachVar == 0 then
   Lvar = "AB_AP_SPEED_Select"
        Lval = round(ipc.readLvar(Lvar))
        if Lval > 100 then
            AddVar = 1
        else
            AddVar = 0
        end
        DspSPD(Lval - AddVar)
    elseif SpdMachVar == 1 then
   Lvar = "AB_AP_Mach_Select"
        Lval = ipc.readLvar(Lvar)
        if Lval > 0.16 then
            AddVar = 0.01
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(Lval + AddVar + 0.005))
    end
    _sleep(20)
    ipc.writeLvar(Lvar, Lval - AddVar)
end

function AB_SPD_minusfast ()
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    if SpdMachVar == 0 then
   Lvar = "AB_AP_SPEED_Select"
        Lval = round(ipc.readLvar(Lvar))
        if Lval > 110 then
            AddVar = 10
        else
            AddVar = 0
        end
        DspSPD(Lval - AddVar)
    elseif SpdMachVar == 1 then
   Lvar = "AB_AP_Mach_Select"
        Lval = ipc.readLvar(Lvar)
        if Lval > 0.16 then
            AddVar = 0.10
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(Lval - AddVar + 0.005))
    end
    _sleep(20)
    ipc.writeLvar(Lvar, Lval - AddVar)
end

-- $$ HDG rotaties

function AB_HDG_plus ()
    AB_hdgtrk = ipc.readLvar("AB_AP_HDGTRK")
    AB_drift = round(ipc.readLvar("AB_AP_HDGTRK"))
    if AB_hdgtrk == 0 then
   Lvar = "AB_AP_HDG_Select"
    else
   Lvar = "AB_AP_TRK_set"
    end
    Lval = round(ipc.readLvar(Lvar))
    AddVar = Lval + 1
    if AddVar > 359 then
        AddVar = 0
    end
    DspHDG(AddVar)
    ipc.writeLvar(Lvar, AddVar)
end

function AB_HDG_plusfast ()
    AB_hdgtrk = ipc.readLvar("AB_AP_HDGTRK")
    if AB_hdgtrk == 0 then
   Lvar = "AB_AP_HDG_Select"
    else
   Lvar = "AB_AP_TRK_set"
    end
    Lval = round(ipc.readLvar(Lvar))
    AddVar = Lval + 10
    if AddVar > 359 then
        AddVar = AddVar - 359
    end
    DspHDG(AddVar)
    ipc.writeLvar(Lvar, AddVar)
end

function AB_HDG_minus ()
    AB_hdgtrk = ipc.readLvar("AB_AP_HDGTRK")
    if AB_hdgtrk == 0 then
   Lvar = "AB_AP_HDG_Select"
    else
   Lvar = "AB_AP_TRK_set"
    end
    Lval = round(ipc.readLvar(Lvar))
    AddVar = Lval - 1
    if Lval < 0 then
        AddVar = 359
    end
    DspHDG(AddVar)
    ipc.writeLvar(Lvar, AddVar)
end

function AB_HDG_minusfast ()
    AB_hdgtrk = ipc.readLvar("AB_AP_HDGTRK")
    if AB_hdgtrk == 0 then
   Lvar = "AB_AP_HDG_Select"
    else
   Lvar = "AB_AP_TRK_set"
    end
    Lval = round(ipc.readLvar(Lvar))
    AddVar = Lval - 10
    if Lval < 0 then
        AddVar = AddVar + 359
    end
    DspHDG(AddVar)
    ipc.writeLvar(Lvar, AddVar)
end

-- $$ ALT

function AB_ALT_Step_toggle ()
   Lvar = "AB_AP_ALTSTEP"
    if ipc.readLvar(Lvar) == 0 then
        AB_ALT_Step_1000 ()
    else
        AB_ALT_Step_100 ()
    end
end

function AB_ALT_Step_100 ()
   Lvar = "AB_AP_ALTSTEP"
    ipc.writeLvar(Lvar, 0)
    DspShow("Step","100")
end

function AB_ALT_Step_1000 ()
   Lvar = "AB_AP_ALTSTEP"
    ipc.writeLvar(Lvar, 1)
    DspShow("Step","1000")
end

function AB_ALT_plus ()
    if ipc.readLvar("AB_AP_ALTSTEP") == 0 then
        AddVar = 100
    else
        AddVar = 1000
    end
   Lvar = "AB_AP_ALT_Select"
    Lval = ipc.readLvar(Lvar)
    if Lval + AddVar <= 41000 then
        ipc.writeLvar(Lvar, Lval + AddVar)
    else
        ipc.writeLvar(Lvar, 41000)
    end
    AB_DspALT ()
end

function AB_ALT_plusfast ()
	Lvar = "AB_AP_ALT_Select"
    Lval = ipc.readLvar(Lvar)
    AddVar = 1000
    if Lval + AddVar <= 41000 then
        ipc.writeLvar(Lvar, Lval + AddVar)
    else
        ipc.writeLvar(Lvar, 41000)
    end
    AB_DspALT ()
end

function AB_ALT_minus ()
    if ipc.readLvar("AB_AP_ALTSTEP") == 0 then
        AddVar = 100
    else
        AddVar = 1000
    end
   Lvar = "AB_AP_ALT_Select"
    Lval = ipc.readLvar(Lvar)
    if Lval - AddVar >= 100 then
        ipc.writeLvar(Lvar, Lval - AddVar)
    else
        ipc.writeLvar(Lvar, 100)
    end
    AB_DspALT ()
end

function AB_ALT_minusfast ()
	Lvar = "AB_AP_ALT_Select"
    Lval = ipc.readLvar(Lvar)
    AddVar = 1000
    if Lval - AddVar >= 100 then
        ipc.writeLvar(Lvar, Lval - AddVar)
    else
        ipc.writeLvar(Lvar, 100)
    end
    AB_DspALT ()
end

-- $$ VS Rotaties

function AB_VS_plus ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
   Lvar = "AB_AP_VS_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval <= 59 then
            val = Lval + 1
            DspVVS(val)
            ipc.writeLvar(Lvar, val)
        end
    else
   Lvar = "AB_AP_FPA_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval <= 9.8 then
            val = Lval + 0.1
            DspFPA(val)
            ipc.writeLvar(Lvar, val)
        end
    end
end

function AB_VS_plusfast ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
   Lvar = "AB_AP_VS_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval <= 55 then
            val = Lval + 5
            DspVVS(val)
            ipc.writeLvar(Lvar, val)
        end
    else
   Lvar = "AB_AP_FPA_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval <= 9.8 then
            val = Lval + 0.1
            DspFPA(val)
            ipc.writeLvar(Lvar, val)
        end
    end
end

function AB_VS_minus ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
   Lvar = "AB_AP_VS_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval >= -59 then
            val = Lval - 1
            DspVVS(val)
            ipc.writeLvar(Lvar, val)
        end
    else
   Lvar = "AB_AP_FPA_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval >= -9.8 then
            val = Lval - 0.1
            DspFPA(val)
            ipc.writeLvar(Lvar, val)
        end
    end
end

function AB_VS_minusfast ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
   Lvar = "AB_AP_VS_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval >= -55 then
            val = Lval - 5
            DspVVS(val)
            ipc.writeLvar(Lvar, val)
        end
    else
   Lvar = "AB_AP_FPA_Select2"
        Lval = ipc.readLvar(Lvar)
        if Lval >= -9.8 then
            val = Lval - 0.1
            DspFPA(val)
            ipc.writeLvar(Lvar, val)
        end
    end
end

-- ## AP Mode Buttons

-- $$ SPD

function AB_AP_SPD_set ()
   Lvar = "AB_AP_SPDmode"
    ipc.writeLvar(Lvar, -1)
   Lvar = "AB_AP_SPDmode_set"
    ipc.writeLvar(Lvar, -1)
    Anim = "AB_AP_SPD_Knob_Ani"
    ipc.writeLvar(Anim, -1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    -- cancel override timer
    ipc.writeLvar("FCU_Managed_SPDoverride_val", 0)
    ipc.writeLvar("FCU_Managed_SPDdisp_override", 0)
    AB_DspSPD ()
    DspShow ("SPD", "set")
end

function AB_AP_SPD_managed ()
   Lvar = "AB_AP_SPDmode"
    ipc.writeLvar(Lvar, 1)
   Lvar = "AB_AP_SPDmode_set"
    ipc.writeLvar(Lvar, 1)
    Anim = "AB_AP_SPD_Knob_Ani"
    ipc.writeLvar(Anim, 1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    AB_DspSPD ()
    DspShow ("SPD", "mngd")
end

function AB_AP_SPD_toggle ()
	if _tl("AB_AP_SPDmode_set", 0) then
		AB_AP_SPD_set ()
	else
		AB_AP_SPD_managed ()
	end
end

-- $$ HDG

function AB_AP_HDG_set ()
   Lvar = "AB_AP_HDGmode"
    ipc.writeLvar(Lvar, -1)
   Lvar = "AB_AP_HDGmode_set"
    ipc.writeLvar(Lvar, -1)
    Anim = "AB_AP_HDG_Knob_Ani"
    ipc.writeLvar(Anim, -1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    AB_DspHDG()
    DspShow ("HDG", "set")
end

function AB_AP_HDG_managed ()
   Lvar = "AB_AP_HDGmode"
    ipc.writeLvar(Lvar, 1)
   Lvar = "AB_AP_HDGmode_set"
    ipc.writeLvar(Lvar, 1)
    Anim = "AB_AP_HDG_Knob_Ani"
    ipc.writeLvar(Anim, 1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    AB_DspHDG()
	DspShow ("HDG", "mngd")
end

function AB_AP_HDG_toggle ()
	if _tl("AB_AP_HDGmode_set", 1) then
		AB_AP_HDG_set ()
	else
		AB_AP_HDG_managed ()
	end
end

-- $$ ALT

function AB_AP_ALT_set ()
Lvar = "AB_AP_ALTmode"
    ipc.writeLvar(Lvar, -1)
Lvar = "AB_AP_ALTmode_set"
    ipc.writeLvar(Lvar, -1)
    Anim = "AB_AP_ALT_Knob_Ani"
    ipc.writeLvar(Anim, -1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
	AB_DspVVS ()
    AB_DspALT()
    DspShow ("ALT", "set")
end

function AB_AP_ALT_managed ()
   Lvar = "AB_AP_ALTmode"
    ipc.writeLvar(Lvar, 1)
   Lvar = "AB_AP_ALTmode_set"
    ipc.writeLvar(Lvar, 1)
    Anim = "AB_AP_ALT_Knob_Ani"
    ipc.writeLvar(Anim, 1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    AB_DspALT()
    DspShow ("ALT", "mngd")
end

function AB_AP_ALT_toggle ()
    if _tl("AB_AP_ALTmode_set", 1) then
		AB_AP_ALT_set ()
	else
		AB_AP_ALT_managed ()
	end
end

-- $$ VVS

function AB_AP_VS_level ()
    --ipc.writeLvar("AB_AP_ALTmode", 0)
    ipc.writeLvar("AB_AP_VS_Select2", 0)
    ipc.writeLvar("AB_AP_VS_Select3", 0)
    ipc.writeLvar("AB_AP_VSlevel", 1)
    Anim = "AB_AP_VSAni"
    ipc.writeLvar(Anim, 1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    DspShow ("VS", "lvl")
end

function AB_AP_VS_pull ()
    ipc.writeLvar("AB_AP_VSlevel", -1)
    ipc.writeLvar("AB_AP_VSenb", 1)
    ipc.writeLvar("AB_AP_KNOBALT", 1)
    DspShow ("VS", "set")
    Anim = "AB_AP_VSAni"
    ipc.writeLvar(Anim, -1)
    _sleep(100)
    AB_MPL_Knobclick ()
    ipc.writeLvar(Anim, 0)
    AB_AP_DES = 2
end


-- ## Avionics ###############

-- $$ Radios

function AB_PDS_CPT_Radios_on ()
    ipc.writeLvar("AB_PDS_RADIO_CPT_POWER", 1)
    AB_OVH_Pushbutton ()
    DspShow ("Rdio", "on")
end

function AB_PDS_CPT_Radios_off ()
    ipc.writeLvar("AB_PDS_RADIO_CPT_POWER", 0)
    AB_OVH_Pushbutton ()
    DspShow ("Rdio", "off")
end

function AB_PDS_CPT_Radios_toggle ()
	if _tl("AB_PDS_RADIO_CPT_POWER", 0) then
       AB_PDS_CPT_Radios_on ()
	else
       AB_PDS_CPT_Radios_off ()
	end
end

function AB_PDS_FO_Radios_on ()
    ipc.writeLvar("AB_PDS_RADIO_FO_POWER", 1)
    AB_OVH_Pushbutton ()
    DspShow ("Rdio", "on")
end

function AB_PDS_FO_Radios_off ()
    ipc.writeLvar("AB_PDS_RADIO_FO_POWER", 0)
    AB_OVH_Pushbutton ()
    DspShow ("Rdio", "off")
end

function AB_PDS_FO_Radios_toggle ()
	if _tl("AB_PDS_RADIO_FO_POWER", 0) then
       AB_PDS_FO_Radios_on ()
	else
       AB_PDS_FO_Radios_off ()
	end
end

-- $$ PFD Power

function AB_MPL_PFD_Power_show ()
    var = ipc.readLvar("AB_MPL_PFD_Power")
    DspShow ("PFD", var*5 .. "%")
end

function AB_MPL_PFD_Power_inc ()
    var = ipc.readLvar("AB_MPL_PFD_Power")
    if var < 20 then
        ipc.writeLvar("AB_MPL_PFD_Power", var + 1)
    end
    AB_MPL_PFD_Power_show ()
end

function AB_MPL_PFD_Power_dec ()
    var = ipc.readLvar("AB_MPL_PFD_Power")
    if var > 0 then
        ipc.writeLvar("AB_MPL_PFD_Power", var - 1)
    end
    AB_MPL_PFD_Power_show ()
end

function AB_MPL_PFD_Power_on ()
    ipc.writeLvar("AB_MPL_PFD_Power", OnVar)
    AB_MPL_PFD_Power_show ()
end

function AB_MPL_PFD_Power_off ()
    ipc.writeLvar("AB_MPL_PFD_Power", 0)
    AB_MPL_PFD_Power_show ()
end

-- $$ ND Power

function AB_MPL_ND_Power_show ()
    var = ipc.readLvar("AB_MPL_ND_Bright")
    DspShow ("ND", var*5 .. "%")
end

function AB_MPL_ND_Power_inc ()
    var = ipc.readLvar("AB_MPL_ND_Bright")
    if var < 20 then
        ipc.writeLvar("AB_MPL_ND_Bright", var + 1)
    end
    AB_MPL_ND_Power_show ()
end

function AB_MPL_ND_Power_dec ()
    var = ipc.readLvar("AB_MPL_ND_Bright")
    if var > 0 then
        ipc.writeLvar("AB_MPL_ND_Bright", var - 1)
    end
    AB_MPL_ND_Power_show ()
end

function AB_MPL_ND_Power_on ()
    ipc.writeLvar("AB_MPL_ND_Bright", OnVar)
    AB_MPL_ND_Power_show ()
end

function AB_MPL_ND_Power_off ()
    ipc.writeLvar("AB_MPL_ND_Bright", 0)
    AB_MPL_ND_Power_show ()
end

-- $$ Radar Power

function AB_MPL_ND_RadarPower_show ()
    var = ipc.readLvar("AB_MPL_NDTERR_Bright")
    DspShow ("RDR", var*5 .. "%")
end

function AB_MPL_ND_RadarPower_inc ()
    var = ipc.readLvar("AB_MPL_NDTERR_Bright")
    if var < 20 then
        ipc.writeLvar("AB_MPL_NDTERR_Bright", var + 1)
    end
    AB_MPL_ND_RadarPower_show()
end

function AB_MPL_ND_RadarPower_dec ()
    var = ipc.readLvar("AB_MPL_NDTERR_Bright")
    if var > 0 then
        ipc.writeLvar("AB_MPL_NDTERR_Bright", var - 1)
    end
    AB_MPL_ND_RadarPower_show()
end

function AB_MPL_ND_RadarPower_on ()
    ipc.writeLvar("AB_MPL_NDTERR_Bright", OnVar)
    AB_MPL_ND_RadarPower_show ()
end

function AB_MPL_ND_RadarPower_off ()
    ipc.writeLvar("AB_MPL_NDTERR_Bright", 0)
    AB_MPL_ND_RadarPower_show ()
end

-- $$ ECAM Power Upper

function AB_MPL_ECAMU_Power_show ()
    var = ipc.readLvar("AB_MPL_ECAMU_Power")
    DspShow ("ECMU", var*5 .. "%")
end

function AB_MPL_ECAMU_Power_inc ()
    var = ipc.readLvar("AB_MPL_ECAMU_Power")
    if var < 20 then
        ipc.writeLvar("AB_MPL_ECAMU_Power", var + 1)
    end
    AB_MPL_ECAMU_Power_show ()
end

function AB_MPL_ECAMU_Power_dec ()
    var = ipc.readLvar("AB_MPL_ECAMU_Power")
    if var > 0 then
        ipc.writeLvar("AB_MPL_ECAMU_Power", var - 1)
    end
    AB_MPL_ECAMU_Power_show ()
end

function AB_MPL_ECAMU_Power_on ()
    ipc.writeLvar("AB_MPL_ECAMU_Power", OnVar)
    AB_MPL_ECAMU_Power_show ()
end

function AB_MPL_ECAMU_Power_off ()
    ipc.writeLvar("AB_MPL_ECAMU_Power", 0)
    AB_MPL_ECAMU_Power_show ()
end

-- $$ ECAM Power Lower

function AB_MPL_ECAML_Power_show ()
    var = ipc.readLvar("AB_MPL_ECAML_Power")
    DspShow ("ECML", var*5 .. "%")
end

function AB_MPL_ECAML_Power_inc ()
    var = ipc.readLvar("AB_MPL_ECAML_Power")
    if var < 20 then
        ipc.writeLvar("AB_MPL_ECAML_Power", var + 1)
    end
    AB_MPL_ECAML_Power_show ()
end

function AB_MPL_ECAML_Power_dec ()
    var = ipc.readLvar("AB_MPL_ECAML_Power")
    if var > 0 then
        ipc.writeLvar("AB_MPL_ECAML_Power", var - 1)
    end
    AB_MPL_ECAML_Power_show ()
end

function AB_MPL_ECAML_Power_on ()
    ipc.writeLvar("AB_MPL_ECAML_Power", OnVar)
    AB_MPL_ECAML_Power_show ()
end

function AB_MPL_ECAML_Power_off ()
    ipc.writeLvar("AB_MPL_ECAML_Power", 0)
    AB_MPL_ECAML_Power_show ()
end

-- $$ All Displays

function AB_MPL_AllDisp_Power_inc ()
    AB_MPL_PFD_Power_inc ()
    AB_MPL_ND_Power_inc ()
    AB_MPL_ND_RadarPower_inc ()
    AB_MPL_ECAMU_Power_inc ()
    AB_MPL_ECAML_Power_inc ()
end

function AB_MPL_AllDisp_Power_dec ()
    AB_MPL_PFD_Power_dec ()
    AB_MPL_ND_Power_dec ()
    AB_MPL_ND_RadarPower_dec ()
    AB_MPL_ECAMU_Power_dec ()
    AB_MPL_ECAML_Power_dec ()
end

function AB_All_Avionics_on ()
    AB_MPL_PFD_Power_on ()
    _sleep(200,500)
    AB_MPL_ND_Power_on ()
    _sleep(200,500)
    AB_MPL_ECAMU_Power_on ()
    _sleep(200,500)
    AB_MPL_ECAML_Power_on ()
    _sleep(200,500)
    AB_MPL_ND_RadarPower_on ()
    _sleep(200,500)
    AB_PDS_CPT_Radios_on ()
    _sleep(200,500)
    AB_PDS_FO_Radios_on()
end

function AB_All_Avionics_off ()
    AB_PDS_CPT_Radios_off ()
    _sleep(200,500)
    AB_PDS_FO_Radios_on()
    _sleep(200,500)
    AB_MPL_ECAML_Power_off ()
    _sleep(200,500)
    AB_MPL_ECAMU_Power_off ()
    _sleep(200,500)
    AB_MPL_ND_Power_off ()
    _sleep(200,500)
    AB_MPL_ND_RadarPower_off ()
    PFD_Power_off ()
end

-- ## ND controls #####################################

-- $$ ND Display Data

function AB_MPL_ND_CSTR_on ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 1)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "CSTR")
end

function AB_MPL_ND_CSTR_off ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "CSTR")
end

function AB_MPL_ND_CSTR_toggle ()
	if ipc.readLvar("AB_MPL_ND_CSTR") == 0 then
        AB_MPL_ND_CSTR_on ()
    else
        AB_MPL_ND_CSTR_off ()
    end
end

function AB_MPL_ND_WPT_on ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 1)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "WPT")
end

function AB_MPL_ND_WPT_off ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "WPT")
end

function AB_MPL_ND_WPT_toggle ()
	if ipc.readLvar("AB_MPL_ND_WPT") == 0 then
        AB_MPL_ND_WPT_on ()
    else
        AB_MPL_ND_WPT_off ()
    end
end

function AB_MPL_ND_VOR_on ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 1)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "VOR")
end

function AB_MPL_ND_VOR_off ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "VOR")
end

function AB_MPL_ND_VOR_toggle ()
	if ipc.readLvar("AB_MPL_ND_VOR") == 0 then
        AB_MPL_ND_VOR_on ()
    else
        AB_MPL_ND_VOR_off ()
    end
end

function AB_MPL_ND_NDB_on ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 1)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "NDB")
end

function AB_MPL_ND_NDB_off ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "NDB")
end

function AB_MPL_ND_NDB_toggle ()
	if ipc.readLvar("AB_MPL_ND_NDB") == 0 then
        AB_MPL_ND_NDB_on ()
    else
        AB_MPL_ND_NDB_off ()
    end
end

function AB_MPL_ND_ARPT_on ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 1)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "ARPT")
end

function AB_MPL_ND_ARPT_off ()
    ipc.writeLvar("AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("AB_MPL_ND_WPT", 0)
	ipc.writeLvar("AB_MPL_ND_VOR", 0)
	ipc.writeLvar("AB_MPL_ND_NDB", 0)
	ipc.writeLvar("AB_MPL_ND_ARPT", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ND", "ARPT")
end

function AB_MPL_ND_ARPT_toggle ()
	if ipc.readLvar("AB_MPL_ND_ARPT") == 0 then
        AB_MPL_ND_ARPT_on ()
    else
        AB_MPL_ND_ARPT_off ()
    end
end

function AB_MPL_ND_DATA_toggle ()
    AB_MPL_ND_Data_CSTR = ipc.readLvar("AB_MPL_ND_CSTR")
    AB_MPL_ND_Data_WPT = ipc.readLvar("AB_MPL_ND_WPT")
	AB_MPL_ND_Data_VOR = ipc.readLvar("AB_MPL_ND_VOR")
    AB_MPL_ND_Data_NDB = ipc.readLvar("AB_MPL_ND_NDB")
    AB_MPL_ND_Data_ARPT = ipc.readLvar("AB_MPL_ND_ARPT")
    if AB_MPL_ND_Data_CSTR == 1 then
        ND_DATAvar = 1
    elseif ND_Data_WPT == 1 then
        ND_DATAvar = 2
    elseif ND_Data_VOR == 1 then
        ND_DATAvar = 3
    elseif ND_Data_NDB == 1 then
        ND_DATAvar = 4
    elseif ND_Data_ARPT == 1 then
        ND_DATAvar = 5
    end
    if ND_DATAvar == 1 then
        AB_MPL_ND_WPT_on ()
    elseif ND_DATAvar == 2 then
        AB_MPL_ND_VOR_on ()
    elseif ND_DATAvar == 3 then
        AB_MPL_ND_NDB_on ()
    elseif ND_DATAvar == 4 then
        AB_MPL_ND_ARPT_on ()
    elseif ND_DATAvar == 5 then
        AB_MPL_ND_CSTR_on ()
    end
    ND_MODE_show()
end

-- $$ ND Mode

function AB_MPL_ND_MODE_show ()
	NGrng = ipc.readLvar("AB_MPL_ND_Mode")
    if NGrng == 0 then
        NDmodeTxt = "LS"
    elseif NGrng == 1 then
        NDmodeTxt = "VOR"
    elseif NGrng == 2 then
        NDmodeTxt = "NAV"
    elseif NGrng == 3 then
        NDmodeTxt = "ARC"
    elseif NGrng == 4 then
        NDmodeTxt = "PLAN"
    end
    DspShow ("NDmd", NDmodeTxt)
end

function AB_MPL_ND_MODE_LS ()
	ipc.writeLvar("AB_MPL_ND_Mode", 0)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end

function AB_MPL_ND_MODE_VOR ()
	ipc.writeLvar("AB_MPL_ND_Mode", 1)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end

function AB_MPL_ND_MODE_NAV ()
	ipc.writeLvar("AB_MPL_ND_Mode", 2)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end

function AB_MPL_ND_MODE_ARC ()
	ipc.writeLvar("AB_MPL_ND_Mode", 3)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end
function AB_MPL_ND_MODE_PLAN ()
	ipc.writeLvar("AB_MPL_ND_Mode", 4)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end

function AB_MPL_ND_MODE_inc ()
    nd_mode = ipc.readLvar("AB_MPL_ND_Mode")
	nd_mode = nd_mode + 1
	if nd_mode > 4 then
        nd_mode = 4
    end
	ipc.writeLvar("AB_MPL_ND_Mode", nd_mode)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end

function AB_MPL_ND_MODE_dec ()
    nd_mode = ipc.readLvar("AB_MPL_ND_Mode")
	nd_mode = nd_mode - 1
	if nd_mode < 0 then
        nd_mode = 0
    end
	ipc.writeLvar("AB_MPL_ND_Mode", nd_mode)
	AB_MPL_KnobRotate ()
    AB_MPL_ND_MODE_show ()
end

-- $$ ND Range

function AB_MPL_ND_RANGE_show ()
	NGrng = ipc.readLvar("AB_MPL_ND_Range")
    if NGrng == 0 then
        NDrngTxt = "10"
    elseif NGrng == 1 then
        NDrngTxt = "20"
    elseif NGrng == 2 then
        NDrngTxt = "40"
    elseif NGrng == 3 then
        NDrngTxt = "80"
    elseif NGrng == 4 then
        NDrngTxt = "160"
    elseif NGrng == 5 then
        NDrngTxt = "320"
    end
    DspShow ("NDrg", NDrngTxt)
end

function AB_MPL_ND_RANGE_10 ()
    ipc.writeLvar("AB_MPL_ND_Range", 0)
    _sleep(10)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_RANGE_show ()
end

function AB_MPL_ND_RANGE_20 ()
    ipc.writeLvar("AB_MPL_ND_Range", 1)
    _sleep(10)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_RANGE_show ()
end

function AB_MPL_ND_RANGE_40 ()
    ipc.writeLvar("AB_MPL_ND_Range", 2)
    _sleep(10)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_RANGE_show ()
end

function AB_MPL_ND_RANGE_80 ()
    ipc.writeLvar("AB_MPL_ND_Range", 3)
    _sleep(10)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_RANGE_show ()
end

function AB_MPL_ND_RANGE_160 ()
    ipc.writeLvar("AB_MPL_ND_Range", 4)
    _sleep(10)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_RANGE_show ()
end

function AB_MPL_ND_RANGE_320 ()
    ipc.writeLvar("AB_MPL_ND_Range", 5)
    _sleep(10)
    AB_MPL_KnobRotate ()
    AB_MPL_ND_RANGE_show ()
end

function AB_MPL_ND_RANGE_inc ()
	i = ipc.readLvar("AB_MPL_ND_Range")
	if i < 5 then
		ipc.writeLvar("AB_MPL_ND_Range", i+1)
		_sleep(10)
        AB_MPL_KnobRotate ()
        AB_MPL_ND_RANGE_show ()
	end
end

function AB_MPL_ND_RANGE_dec ()
	i = ipc.readLvar("AB_MPL_ND_Range")
	if i > 0 then
		ipc.writeLvar("AB_MPL_ND_Range", i-1)
		_sleep(10)
        AB_MPL_KnobRotate ()
        AB_MPL_ND_RANGE_show ()
	end
end

-- $$ ND ADF/VOR switches

function AB_MPL_ND_ARROW1_vor ()
   Lvar = "AB_MPL_ND_Arrow1"
    ipc.writeLvar(Lvar, 0)
    DspShow ("VOR", "1")
    AB_MPL_LightSwitch ()
end

function AB_MPL_ND_ARROW1_adf ()
   Lvar = "AB_MPL_ND_Arrow1"
    ipc.writeLvar(Lvar, 2)
    DspShow ("ADF", "1")
    AB_MPL_LightSwitch ()
end

function AB_MPL_ND_ARROW1_off ()
   Lvar = "AB_MPL_ND_Arrow1"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
end

function AB_MPL_ND_ARROW2_vor ()
   Lvar = "AB_MPL_ND_Arrow2"
    ipc.writeLvar(Lvar, 0)
    DspShow ("VOR", "2")
    AB_MPL_LightSwitch ()
end

function AB_MPL_ND_ARROW2_adf ()
   Lvar = "AB_MPL_ND_Arrow2"
    ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("ADF", "2")
end

function AB_MPL_ND_ARROW2_off ()
   Lvar = "AB_MPL_ND_Arrow2"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
end

function AB_MPL_ND_ARROW1_right ()
    NDArr1 = ipc.readLvar("AB_MPL_ND_Arrow1")
    if NDArr1 == 2 then
        AB_MPL_ND_ARROW1_off ()
    elseif NDArr1 == 1 then
        AB_MPL_ND_ARROW1_vor ()
    end
end

function AB_MPL_ND_ARROW1_left ()
    NDArr1 = ipc.readLvar("AB_MPL_ND_Arrow1")
    if NDArr1 == 0 then
        AB_MPL_ND_ARROW1_off ()
    elseif NDArr1 == 1 then
        AB_MPL_ND_ARROW1_adf ()
    end
end

function AB_MPL_ND_ARROW2_right ()
    NDArr2 = ipc.readLvar("AB_MPL_ND_Arrow2")
    if NDArr2 == 2 then
        AB_MPL_ND_ARROW2_off ()
    elseif NDArr2 == 1 then
        AB_MPL_ND_ARROW2_vor ()
    end
end

function AB_MPL_ND_ARROW2_left ()
    NDArr2 = ipc.readLvar("AB_MPL_ND_Arrow2")
    if NDArr2 == 0 then
        AB_MPL_ND_ARROW2_off ()
    elseif NDArr2 == 1 then
        AB_MPL_ND_ARROW2_adf ()
    end
end

-- ## Barometric #######

function AB_BARO_show ()
    BaroVarhPa = ipc.readLvar("LINDA_Baro_Hpa")
    BaroVarinHg = ipc.readLvar("LINDA_Baro_inHg")
    BaroUnitVar = ipc.readLvar("AB_MPL_Baro_Unit")
    if BaroUnitVar == 0 then
        BaroText1 = "hPa"
        BaroText2 = BaroVarhPa
    elseif BaroUnitVar == 1 then
        BaroText1 = "inHg"
        BaroText2 = BaroVarinHg
    end
    DspShow (BaroText1, BaroText2)
end

function AB_BARO_inc ()
    if ipc.readLvar("AB_MPL_Baro_Unit") == 0 then
        ipc.control(65883)
        ipc.control(65883)
        ipc.control(65883)
    elseif ipc.readLvar("AB_MPL_Baro_Unit") == 1 then
        ipc.control(65883)
    end
    _sleep(50)
    AB_BARO_show ()
end

function AB_BARO_dec ()
    if ipc.readLvar("AB_MPL_Baro_Unit") == 0 then
        ipc.control(65884)
        ipc.control(65884)
        ipc.control(65884)
    elseif ipc.readLvar("AB_MPL_Baro_Unit") == 1 then
        ipc.control(65884)
    end
    _sleep(50)
    AB_BARO_show ()
end

function AB_Baro_MODE_std ()
   Lvar = "AB_MPL_Baro_STD"
	ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("BARO", "std")
end

function AB_Baro_MODE_set ()
   Lvar = "AB_MPL_Baro_STD"
	ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("BARO", "set")
end

function AB_Baro_MODE_toggle ()
	if _tl("AB_MPL_Baro_STD", 0) then
        AB_Baro_MODE_std ()
	else
        AB_Baro_MODE_set ()
	end
end

function AB_BARO_Unit_inHg ()
    ipc.log ("BARO inHg")
   Lvar = "AB_MPL_Baro_Unit"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    Altimeter_BARO_MODE_inHg ()
    DspShow ("Unit", "inHg")
end

function AB_BARO_Unit_hPa ()
    ipc.log ("BARO hPa")
   Lvar = "AB_MPL_Baro_Unit"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    Altimeter_BARO_MODE_hPa ()
    DspShow ("Unit", "hPa")
end

function AB_BARO_Unit_toggle ()
	if ipc.readLvar("AB_MPL_Baro_Unit") == 0 then
       AB_BARO_Unit_inHg ()
	else
       AB_BARO_Unit_hPa ()
	end
end

-- ## Other Main Panel #######

-- $$ Warning/Caution

function AB_MPL_Alarms_WARN_off ()
    ipc.writeLvar("AB_MPL_Master_Warning", 1)
    AB_OVH_Pushbutton ()
end

function AB_MPL_Alarms_CAUTION_off ()
    ipc.writeLvar("AB_MPL_Master_Caution", 1)
    AB_OVH_Pushbutton ()
end

function AB_MPL_Alarms_BOTH_off ()
	AB_MPL_Alarms_WARN_off ()
    _sleep(100)
	AB_MPL_Alarms_CAUTION_off ()
end

-- $$ Autobrake

function AB_MPL_Autobrake_min ()
   Lvar = "Autobrake_position"
    ipc.writeLvar(Lvar, 2)
    AB_OVH_Pushbutton ()
    DspShow ("ABRK", "min")
end

function AB_MPL_Autobrake_med ()
   Lvar = "Autobrake_position"
    ipc.writeLvar(Lvar, 3)
    AB_OVH_Pushbutton ()
    DspShow ("ABRK", "med")
end

function AB_MPL_Autobrake_max ()
   Lvar = "Autobrake_position"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("ABRK", "max")
end

function AB_MPL_Autobrake_off ()
   Lvar = "Autobrake_position"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("ABRK", "off")
end

function AB_MPL_Autobrake_cycle ()
	auto_brk = auto_brk + 1
	if auto_brk > 4 then
        auto_brk = 1
    end
	if auto_brk == 1 then
		AB_MPL_Autobrake_min ()
	elseif auto_brk == 2 then
		AB_MPL_Autobrake_med ()
	elseif auto_brk == 3 then
		AB_MPL_Autobrake_max ()
	else
		AB_MPL_Autobrake_off ()
	end
end

function AB_MPL_Autobrake_inc ()
    ABRKvar = ipc.readLvar("Autobrake_position")
    if ABRKvar == 1 then
        AB_MPL_Autobrake_min ()
    elseif ABRKvar == 2 then
        AB_MPL_Autobrake_med ()
    elseif ABRKvar == 3 then
        AB_MPL_Autobrake_max ()
    end
end

function AB_MPL_Autobrake_dec ()
    ABRKvar = ipc.readLvar("Autobrake_position")
    if ABRKvar == 0 then
        AB_MPL_Autobrake_med ()
    elseif ABRKvar == 3 then
        AB_MPL_Autobrake_min ()
    elseif ABRKvar == 2 then
        AB_MPL_Autobrake_off ()
    end
end

-- $$ Brake Fan

function AB_MPL_Brakefan_on ()
    ipc.writeLvar("AB_BRK_FAN", 1)
    AB_OVH_Pushbutton ()
    DspShow ("BFan", "on")
end

function AB_MPL_Brakefan_off ()
    ipc.writeLvar("AB_BRK_FAN", 0)
    AB_OVH_Pushbutton ()
    DspShow ("BFan", "off")
end

function AB_MPL_Brakefan_toggle ()
	if _tl("AB_BRK_FAN", 0) then
       AB_MPL_Brakefan_on ()
	else
       AB_MPL_Brakefan_off ()
	end
end

function AB_MPL_Antiskid_toggle ()
	_ANTISKID_BRAKES_TOGGLE ()
    AB_MPL_NormalSwitch ()
    DspShow("Skid","Tog")
end

-- ## Clock Main Panel ###############

-- $$ ND Chrono

function AB_MPL_Chrono ()
   ipc.writeLvar("AB_MPL_CHRONO", 1)
   AB_OVH_Pushbutton ()
end

function AB_MPL_CLOCK_Chrono_start ()
   ipc.writeLvar("AB_MPL_CLOCK_Chrono_start", 1)
    AB_OVH_Pushbutton ()
    DspShow ("CHR", "strt")
end

function AB_MPL_CLOCK_Chrono_stop ()
   ipc.writeLvar("AB_MPL_CLOCK_Chrono_start", 0)
    AB_OVH_Pushbutton ()
    DspShow ("CHR", "stop")
end

function AB_MPL_CLOCK_Chrono_toggle ()
	if _tl("AB_MPL_CLOCK_Chrono_start", 0) then
        AB_MPL_CLOCK_Chrono_start ()
	else
        AB_MPL_CLOCK_Chrono_stop ()
	end
end

function AB_MPL_CLOCK_Chrono_reset ()
    ipc.writeLvar("AB_MPL_CLOCK_RST", 1)
    AB_OVH_Pushbutton ()
    DspShow ("CHR", "rset")
end

-----

function AB_MPL_CLOCK_run ()
    ipc.writeLvar("AB_MPL_CLOCK_ET_SW", 0)
    DspShow ("CLCK", "run")
    AB_MPL_KnobRotate ()
end

function AB_MPL_CLOCK_stp ()
    ipc.writeLvar("AB_MPL_CLOCK_ET_SW", 1)
    DspShow ("CLCK", "stp")
    AB_MPL_KnobRotate ()
end

function AB_MPL_CLOCK_st ()
    ipc.writeLvar("AB_MPL_CLOCK_ET_SW", 2)
    DspShow ("CLCK", "st")
    AB_MPL_KnobRotate ()
end

function AB_MPL_CLOCK_inc ()
    CLCK = ipc.readLvar("AB_MPL_CLOCK_ET_SW")
    if CLCK == 0 then AB_MPL_CLOCK_stp ()
    elseif CLCK == 1 then AB_MPL_CLOCK_st ()
    end
end

function AB_MPL_CLOCK_dec ()
    CLCK = ipc.readLvar("AB_MPL_CLOCK_ET_SW")
    if CLCK == 2 then
        AB_MPL_CLOCK_stp ()
    elseif CLCK == 1 then
        AB_MPL_CLOCK_run ()
    end
end

-- ## OVH EXT Lights ###################################

-- $$ toggle all nav/ident lights

function AB_OVH_Ext_FLYING_toggle ()
	if _tl("AB_VC_OVH_ExtLight_Strobe_Sw", 0) then
		AB_OVH_Ext_STROBE_auto ()
        AB_OVH_Ext_BEACON_on ()
        AB_OVH_Ext_WING_on ()
        AB_OVH_Ext_NAVLOGO_1 ()
	else
		AB_OVH_Ext_STROBE_off ()
        AB_OVH_Ext_BEACON_off ()
        AB_OVH_Ext_WING_off ()
        AB_OVH_Ext_NAVLOGO_off ()
    end
end

-- $$ Landing

function AB_OVH_Ext_LANDING_on ()
    if A330 then
        val = 1
    else
        val = 2
    end
   Lvar = "AB_VC_OVH_ExtLight_Landing_Sw"
	ipc.writeLvar(Lvar, val)
    AB_MPL_LightSwitch ()
    DspShow ("LL", "on")
end

function AB_OVH_Ext_LANDING_off ()
    if A330 then
        val = 0
    else
        val = 1
    end
   Lvar = "AB_VC_OVH_ExtLight_Landing_Sw"
    ipc.writeLvar(Lvar, val)
    AB_MPL_LightSwitch ()
    DspShow ("LL", "off")
end

function AB_OVH_Ext_LANDING_retract ()
    if A330 then
        return
    end
    AB_OVH_Ext_LANDING_off ()
    _sleep(100,200)
   Lvar = "AB_VC_OVH_ExtLight_Landing_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("LL", "retr")
end

function AB_OVH_Ext_LANDING_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_ExtLight_Landing_Sw", 0) then
            AB_OVH_Ext_LANDING_on ()
        else
            AB_OVH_Ext_LANDING_off ()
        end

    else
        if _tl("AB_VC_OVH_ExtLight_Landing_Sw", 0) then
            AB_OVH_Ext_LANDING_on ()
        else
            AB_OVH_Ext_LANDING_retract ()
        end
    end
end

function AB_OVH_Ext_LANDING_cycle ()
    if A330 then

        if _tl("AB_VC_OVH_ExtLight_Landing_Sw", 0) then
            AB_OVH_Ext_LANDING_on ()
        else
            AB_OVH_Ext_LANDING_off ()
        end
    else
        if _tl("AB_VC_OVH_ExtLight_Landing_Sw", 0) then
            AB_OVH_Ext_LANDING_off ()
        elseif _tl("AB_VC_OVH_ExtLight_Landing_Sw", 1) then
            AB_OVH_Ext_LANDING_on ()
        else
            AB_OVH_Ext_LANDING_retract ()
        end
    end
end

-- $$ Taxi

function AB_OVH_Ext_TAXI_on ()
   Lvar = "AB_VC_OVH_ExtLight_Nose_Sw"
	ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("Taxi", "on")
end

function AB_OVH_Ext_TAXI_takeoff ()
   Lvar = "AB_VC_OVH_ExtLight_Nose_Sw"
    ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("Taxi", "T/O")
end

function AB_OVH_Ext_TAXI_off ()
   Lvar = "AB_VC_OVH_ExtLight_Nose_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("Taxi", "off")
end

function AB_OVH_Ext_TAXI_toggle ()
   Lvar = "AB_VC_OVH_ExtLight_Nose_Sw"
    if ipc.readLvar(Lvar) == 0 then
        AB_OVH_Ext_TAXI_on()
    else
        AB_OVH_Ext_TAXI_off()
    end
end

function AB_OVH_Ext_TAXI_cycle ()
	if _tl("AB_VC_OVH_ExtLight_Nose_Sw", 0) then
        AB_OVH_Ext_TAXI_on()
	elseif _tl("AB_VC_OVH_ExtLight_Nose_Sw", 1) then
        AB_OVH_Ext_TAXI_takeoff()
    else
        AB_OVH_Ext_TAXI_off()
    end
end

-- $$ Runway Turn Off

function AB_OVH_Ext_RUNWAY_on ()
   Lvar = "AB_VC_OVH_ExtLight_RwyTO_Sw"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("RwyL", "on")
end

function AB_OVH_Ext_RUNWAY_off ()
   Lvar = "AB_VC_OVH_ExtLight_RwyTO_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("RwyL", "off")
end

function AB_OVH_Ext_RUNWAY_toggle ()
	if _tl("AB_VC_OVH_ExtLight_RwyTO_Sw", 0) then
		AB_OVH_Ext_RUNWAY_on ()
	else
		AB_OVH_Ext_RUNWAY_off ()
	end
end

-- $$ Taxi Lights Both

function AB_OVH_Ext_TAXI_ALL_on()
    AB_OVH_Ext_TAXI_on()
    _sleep(150)
    AB_OVH_Ext_RUNWAY_on()
    DspShow('TAXI', 'on')
end

function AB_OVH_Ext_TAXI_ALL_off()
    AB_OVH_Ext_TAXI_off()
    _sleep(150)
    AB_OVH_Ext_RUNWAY_off()
    DspShow('TAXI', 'off')
end

function AB_OVH_Ext_TAXI_ALL_toggle()
	if _tl("AB_VC_OVH_ExtLight_Nose_Sw", 0) then
        AB_OVH_Ext_TAXI_ALL_on()
    else
        AB_OVH_Ext_TAXI_ALL_off()
    end
end

-- $$ Landing and Taxi Takeoff

function AB_OVH_Ext_LDG_ALL_on()
    AB_OVH_Ext_LANDING_on()
    _sleep(150)
    AB_OVH_Ext_TAXI_takeoff()
    _sleep(150)
    AB_OVH_Ext_RUNWAY_off()
    DspShow('LDG', 'on')
end

function AB_OVH_Ext_LDG_ALL_off()
    AB_OVH_Ext_RUNWAY_on()
    _sleep(150)
    AB_OVH_Ext_TAXI_on()
    _sleep(150)
    AB_OVH_Ext_LANDING_off()
    _sleep(150)
    AB_OVH_Ext_LANDING_retract()
    DspShow('LDG', 'off')
end

function AB_OVH_Ext_LDG_ALL_toggle()
    if A330 then
        val = 1
    else
        val = 0
    end
	if _tl("AB_VC_OVH_ExtLight_Landing_Sw", val) then
        AB_OVH_Ext_LDG_ALL_off()
    else
        AB_OVH_Ext_LDG_ALL_on()
    end
end

-- $$ Strobe

function AB_OVH_Ext_STROBE_on ()
   Lvar = "AB_VC_OVH_ExtLight_Strobe_Sw"
    ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("STRB", "on")
end

function AB_OVH_Ext_STROBE_auto ()
   Lvar = "AB_VC_OVH_ExtLight_Strobe_Sw"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("STRB", "auto")
end

function AB_OVH_Ext_STROBE_off ()
   Lvar = "AB_VC_OVH_ExtLight_Strobe_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("STRB", "off")
end

function AB_OVH_Ext_STROBE_toggle ()
   Lvar = "AB_VC_OVH_ExtLight_Strobe_Sw"
    if ipc.readLvar(Lvar) == 0 then
        AB_OVH_Ext_STROBE_auto()
    else
        AB_OVH_Ext_STROBE_off()
    end
end

function AB_OVH_Ext_STROBE_cycle ()
   Lvar = "AB_VC_OVH_ExtLight_Strobe_Sw"
    if ipc.readLvar(Lvar) == 0 then
        AB_OVH_Ext_STROBE_auto()
    elseif ipc.readLvar(Lvar) == 1 then
        AB_OVH_Ext_STROBE_on()
    else
        AB_OVH_Ext_STROBE_off()
    end
end

-- $$ Beacon

function AB_OVH_Ext_BEACON_on ()
   Lvar = "AB_VC_OVH_ExtLight_Beacon_Sw"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
	DspShow ("BCN", "on")
end

function AB_OVH_Ext_BEACON_off ()
   Lvar = "AB_VC_OVH_ExtLight_Beacon_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
	DspShow ("BCN", "off")
end

function AB_OVH_Ext_BEACON_toggle ()
    if _tl("AB_VC_OVH_ExtLight_Beacon_Sw", 0) then
		AB_OVH_Ext_BEACON_on ()
	else
		AB_OVH_Ext_BEACON_off ()
	end
end

-- $$ Nav Logo

function AB_OVH_Ext_NAVLOGO_2 ()
   Lvar = "AB_VC_OVH_ExtLight_NavLogo_Sw"
    ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
	DspShow ("NAV", "on 2")
end

function AB_OVH_Ext_NAVLOGO_1 ()
   Lvar = "AB_VC_OVH_ExtLight_NavLogo_Sw"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
	DspShow ("NAV", "on 1")
end

function AB_OVH_Ext_NAVLOGO_off ()
   Lvar = "AB_VC_OVH_ExtLight_NavLogo_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
	DspShow ("NAV", "off")
end

function AB_OVH_Ext_NAVLOGO_toggle ()
    if _tl("AB_VC_OVH_ExtLight_NavLogo_Sw", 1) then
		AB_OVH_Ext_NAVLOGO_off ()
	else
		AB_OVH_Ext_NAVLOGO_1 ()
	end
end

function AB_OVH_Ext_NAVLOGO_cycle ()
lval = ipc.readLvar("AB_VC_OVH_ExtLight_NavLogo_Sw")
    if lval == 0 then
		AB_OVH_Ext_NAVLOGO_1 ()
    elseif lval == 1 then
		AB_OVH_Ext_NAVLOGO_2 ()
	else
        AB_OVH_Ext_NAVLOGO_1()
        _sleep(100)
		AB_OVH_Ext_NAVLOGO_off ()
	end
end

-- $$ Wing

function AB_OVH_Ext_WING_on ()
   Lvar = "AB_VC_OVH_ExtLight_Wing_Sw"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
	DspShow ("WING", "on")
end

function AB_OVH_Ext_WING_off ()
   Lvar = "AB_VC_OVH_ExtLight_Wing_Sw"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("WING", "off")
end

function AB_OVH_Ext_WING_toggle ()
    if _tl("AB_VC_OVH_ExtLight_Wing_Sw", 1) then
		AB_OVH_Ext_WING_off ()
	else
		AB_OVH_Ext_WING_on ()
	end
end

-- ## OVH INT Lights ###################################

-- $$ Cabin Crew

function AB_Sign_CABINCREW_on()
    AB_Sign_SEATBELTS_auto()
    AB_Sign_ELECDIV_auto()
    AB_Lights_EMER_armed()
end

function AB_Sign_CABINCREW_off()
    AB_Sign_SEATBELTS_off()
    AB_Sign_ELECDIV_off()
    AB_Lights_EMER_off()
end

function AB_Sign_CABINCREW_toggle()
	if _tl("AB_OVH_SEATBELT", 0) then
        AB_Sign_CABINCREW_on()
    else
        AB_Sign_CABINCREW_off()
    end
end

-- $$ Dome

function AB_OVH_Int_Dome_off()
    if A330 then
        A33_OVH_Int_CTL_off()
    else
        ipc.writeLvar("AB_VC_OVH_IntLight_Dome_Sw", 0)
        AB_MPL_LightSwitch ()
        DspShow('DOME', 'off')
    end
end

function AB_OVH_Int_Dome_dim()
    if A330 then
        A33_OVH_Int_CTL_on()
        _sleep(100)
        ipc.writeLvar("AB_VC_OVH_IntLight_Dome_Sw", 0)
    else
        ipc.writeLvar("AB_VC_OVH_IntLight_Dome_Sw", 1)
    end
    AB_MPL_LightSwitch ()
    DspShow('DOME', 'dim')
end

function AB_OVH_Int_Dome_brt()
    if A330 then
        A33_OVH_Int_CTL_on()
        _sleep(100)
        ipc.writeLvar("AB_VC_OVH_IntLight_Dome_Sw", 1)
    else
        ipc.writeLvar("AB_VC_OVH_IntLight_Dome_Sw", 2)
    end
    AB_MPL_LightSwitch ()
    DspShow('DOME', 'brt')
end

function AB_OVH_Int_Dome_toggle()
    if A330 then
         A33_OVH_Int_CTL_toggle()
    else
        if _tt("AB_VC_OVH_IntLight_Dome_Sw", 2) then
            AB_OVH_Int_Dome_off()
        else
            AB_OVH_Int_Dome_brt()
        end
    end
end

-- ## A330 Internal Lights

-- $$ Overhead Panel

function A33_OVH_Int_CTL_off()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_IntLight_CTL_Sw", 0)
        AB_MPL_LightSwitch ()
        DspShow('CTL', 'on')
    end
end

function A33_OVH_Int_CTL_on()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_IntLight_CTL_Sw", 1)
        AB_MPL_LightSwitch ()
        DspShow('CTL', 'off')
    end
end

function A33_OVH_Int_CTL_toggle()
    if A330 then
Lvar = "AB_VC_OVH_IntLight_CTL_Sw"
        if ipc.readLvar(Lvar) == 0 then
            A33_OVH_Int_CTL_on()
        else
            A33_OVH_Int_CTL_off()
        end
    end
end

function A33_OVH_Int_Dome_storm()
    if A330 then
        A33_OVH_Int_CTL_on()
        _sleep(100)
        ipc.writeLvar("AB_VC_OVH_IntLight_Dome_Sw", 2)
        AB_MPL_LightSwitch ()
        DspShow('DOME', 'strm')
    end
end

-- $$ Capt Main Panel Light Switches (left)

-- Capt Console Light

function AB_OVH_Int_Console_CPT_off()
    ipc.writeLvar("AB_VC_IntLight_CONSOLEFLOOR_CPT_Sw", 0)
    AB_MPL_LightSwitch ()
    DspShow('CSOL', 'on')
end

function AB_OVH_Int_Console_CPT_dim()
    ipc.writeLvar("AB_VC_IntLight_CONSOLEFLOOR_CPT_Sw", 1)
    AB_MPL_LightSwitch ()
    DspShow('CSOL', 'off')
end

function AB_OVH_Int_Console_CPT_brt()
    ipc.writeLvar("AB_VC_IntLight_CONSOLEFLOOR_CPT_Sw", 2)
    AB_MPL_LightSwitch ()
    DspShow('CSOL', 'off')
end

function AB_OVH_Int_Console_CPT_cycle()
Lvar = "AB_VC_IntLight_CONSOLEFLOOR_CPT_Sw"
    Lval = ipc.readLvar(Lvar)
    if Lval == 0 then
        AB_OVH_Int_Console_CPT_dim()
    elseif Lval == 1 then
        AB_OVH_Int_Console_CPT_brt()
    else
        AB_OVH_Int_Console_CPT_dim()
        _sleep(100)
        AB_OVH_Int_Console_CPT_off()
    end
end

-- Capt Ceiling Spot Light

function A33_MPL_Int_Ceiling_CPT_off()
    if A330 then
        ipc.writeLvar("AB_VC_IntLight_CEILING_SPOT_CPT_Sw", 0)
        AB_MPL_LightSwitch ()
        DspShow('SPOT', 'on')
    end
end

function A33_MPL_Int_Ceiling_CPT_on()
    if A330 then
        ipc.writeLvar("AB_VC_IntLight_CEILING_SPOT_CPT_Sw", 1)
        AB_MPL_LightSwitch ()
        DspShow('SPOT', 'off')
    end
end

function A33_MPL_Int_Ceiling_CPT_toggle()
    if A330 then
Lvar = "AB_VC_IntLight_CEILING_SPOT_CPT_Sw"
        if ipc.readLvar(Lvar) == 0 then
            A33_MPL_Int_Ceiling_CPT_on()
        else
            A33_MPL_Int_Ceiling_CPT_off()
        end
    end
end

-- Capt Map Light

function A33_MPL_Int_Map_CPT_off()
    if A330 then
        ipc.writeLvar("AB_Window_IntLight_MAP_CPT_Sw", 0)
        AB_MPL_LightSwitch ()
        DspShow('MAP', 'on')
    end
end

function A33_MPL_Int_Map_CPT_on()
    if A330 then
        ipc.writeLvar("AB_Window_IntLight_MAP_CPT_Sw", 1)
        AB_MPL_LightSwitch ()
        DspShow('MAP', 'off')
    end
end

function A33_MPL_Int_Map_CPT_toggle()
    if A330 then
Lvar = "AB_Window_IntLight_MAP_CPT_Sw"
        if ipc.readLvar(Lvar) == 0 then
            A33_MPL_Int_Map_CPT_on()
        else
            A33_MPL_Int_Map_CPT_off()
        end
    end
end

-- $$ FO Main Panel Light Switches (right)

-- FO Console Light

function AB_MPL_Int_Console_FO_off()
    ipc.writeLvar("AB_VC_IntLight_CONSOLEFLOOR_FO_Sw", 0)
    AB_MPL_LightSwitch ()
    DspShow('CSOL', 'on')
end

function AB_MPL_Int_Console_FO_dim()
    ipc.writeLvar("AB_VC_IntLight_CONSOLEFLOOR_FO_Sw", 1)
    AB_MPL_LightSwitch ()
    DspShow('CSOL', 'off')
end

function AB_MPL_Int_Console_FO_brt()
    ipc.writeLvar("AB_VC_IntLight_CONSOLEFLOOR_FO_Sw", 2)
    AB_MPL_LightSwitch ()
    DspShow('CSOL', 'off')
end

function AB_MPL_Int_Console_FO_cycle()
Lvar = "AB_VC_IntLight_CONSOLEFLOOR_FO_Sw"
    Lval = ipc.readLvar(Lvar)
    if Lval == 0 then
        AB_MPL_Int_Console_FO_dim()
    elseif Lval == 1 then
        AB_MPL_Int_Console_FO_brt()
    else
        AB_MPL_Int_Console_FO_dim()
        _sleep(100)
        AB_MPL_Int_Console_FO_off()
    end
end

-- FO Ceiling Spot Light

function A33_MPL_Int_Ceiling_FO_off()
    if A330 then
        ipc.writeLvar("AB_VC_IntLight_CEILING_SPOT_FO_Sw", 0)
        AB_MPL_LightSwitch ()
        DspShow('SPOT', 'on')
    end
end

function A33_MPL_Int_Ceiling_FO_on()
    if A330 then
        ipc.writeLvar("AB_VC_IntLight_CEILING_SPOT_FO_Sw", 1)
        AB_MPL_LightSwitch ()
        DspShow('SPOT', 'off')
    end
end

function A33_MPL_Int_Ceiling_FO_toggle()
    if A330 then
Lvar = "AB_VC_IntLight_CEILING_SPOT_FO_Sw"
        if ipc.readLvar(Lvar) == 0 then
            A33_MPL_Int_Ceiling_FO_on()
        else
            A33_MPL_Int_Ceiling_FO_off()
        end
    end
end

-- FO Map Light

function A33_MPL_Int_Map_FO_off()
    if A330 then
        ipc.writeLvar("AB_Window_IntLight_MAP_FO_Sw", 0)
        AB_MPL_LightSwitch ()
        DspShow('MAP', 'on')
    end
end

function A33_MPL_Int_Map_FO_on()
    if A330 then
        ipc.writeLvar("AB_Window_IntLight_MAP_FO_Sw", 1)
        AB_MPL_LightSwitch ()
        DspShow('MAP', 'off')
    end
end

function A33_MPL_Int_Map_FO_toggle()
    if A330 then
Lvar = "AB_Window_IntLight_MAP_FO_Sw"
        if ipc.readLvar(Lvar) == 0 then
            A33_MPL_Int_Map_FO_on()
        else
            A33_MPL_Int_Map_FO_off()
        end
    end
end

-- ## Other Lights

-- $$ Seat Belts

function AB_Sign_SEATBELTS_off ()
   Lvar = "AB_OVH_SEATBELT"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("SEAT", "off")
end

function AB_Sign_SEATBELTS_auto ()
   Lvar = "AB_OVH_SEATBELT"
	ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("SEAT", "auto")
end

function AB_Sign_SEATBELTS_on ()
   Lvar = "AB_OVH_SEATBELT"
	ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("SEAT", "on")
end

function AB_Sign_SEATBELTS_toggle ()
	if _tl("AB_OVH_SEATBELT", 0) then
		AB_Sign_SEATBELTS_on()
	else
		AB_Sign_SEATBELTS_off()
	end
end

function AB_Sign_SEATBELTS_cycle ()
    lval = ipc.readLvar("AB_OVH_SEATBELT")
    if lval == 0 then
		AB_Sign_SEATBELTS_auto()
	elseif lval == 1 then
		AB_Sign_SEATBELTS_on()
    else
        AB_Sign_SEATBELTS_auto()
        _sleep(100)
        AB_Sign_SEATBELTS_off()
 	end
end

-- $$ No Portable Elect Devices

function AB_Sign_ELECDIV_off ()
   Lvar = "AB_OVH_NO_SMOKING"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("ELDV", "off")
end

function AB_Sign_ELECDIV_auto ()
   Lvar = "AB_OVH_NO_SMOKING"
	ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("ELDV", "auto")
end

function AB_Sign_ELECDEV_on ()
   Lvar = "AB_OVH_NO_SMOKING"
	ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("ELDV", "on")
end

function AB_Sign_ELECDEV_toggle ()
	if _tl("AB_OVH_NO_SMOKING", 0) then
		AB_Sign_ELECDEV_on()
	else
		AB_Sign_ELECDIV_off()
	end
end

function AB_Sign_ELECDEV_cycle ()
    lval = ipc.readLvar("AB_OVH_NO_SMOKING")
    if lval == 0 then
		AB_Sign_ELECDIV_auto()
	elseif lval == 1 then
		AB_Sign_ELECDEV_on()
    else
		AB_Sign_ELECDIV_auto()
        _sleep(100)
        AB_Sign_ELECDIV_off()
 	end
end

-- $$ Emergency Exits

function AB_Lights_EMER_on ()
   Lvar = "AB_OVH_EMER_LT"
	ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("Emer", "on")
end

function AB_Lights_EMER_armed ()
   Lvar = "AB_OVH_EMER_LT"
	ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("Emer", "armd")
end

function AB_Lights_EMER_off ()
   Lvar = "AB_OVH_EMER_LT"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("Emer", "off")
end

function AB_Lights_EMER_toggle ()
	if _tl("AB_OVH_EMER_LT", 0) then
		AB_Lights_EMER_armed ()
	else
		AB_Lights_EMER_off ()
	end
end

function AB_Lights_EMER_cycle ()
	if _tt("AB_OVH_EMER_LT", 0) then
		AB_Lights_EMER_armed ()
	elseif _tt("AB_OVH_EMER_LT", 1) then
        AB_Lights_EMER_on()
    else
        AB_Lights_EMER_armed()
        _sleep(50)
		AB_Lights_EMER_off()
	end
end

-- $$ Annunicator Test

function AB_OVH_ANN_LIGHTS_TEST_dim ()
    ipc.writeLvar("AB_OVH_ANN_LIGHTS", 0)
    ipc.writeLvar("LightTest", 0)
    AB_MPL_LightSwitch ()
    DspShow ("Test", "dim")
end

function AB_OVH_ANN_LIGHTS_TEST_brt ()
    ipc.writeLvar("AB_OVH_ANN_LIGHTS", 1)
    ipc.writeLvar("LightTest", 0)
    AB_MPL_LightSwitch ()
    DspShow ("Test", "on")
end

function AB_OVH_ANN_LIGHTS_TEST_test ()
    ipc.writeLvar("AB_OVH_ANN_LIGHTS", 2)
    ipc.writeLvar("LightTest", 1)
    AB_MPL_LightSwitch ()
    DspShow ("Test", "test")
end

function AB_OVH_ANN_LIGHTS_TEST_toggle ()
	if _tl("AB_OVH_ANN_LIGHTS", 0) then
       AB_OVH_ANN_LIGHTS_TEST_test ()
	else
       AB_OVH_ANN_LIGHTS_TEST_dim ()
	end
end

function AB_OVH_ANN_LIGHTS_TEST_cycle ()
	if _tt("AB_OVH_ANN_LIGHTS", 0) then
		AB_OVH_ANN_LIGHTS_TEST_brt ()
	elseif _tt("AB_OVH_ANN_LIGHTS", 1) then
        AB_OVH_ANN_LIGHTS_TEST_test()
    else
        AB_OVH_ANN_LIGHTS_TEST_brt()
        _sleep(150)
		AB_OVH_ANN_LIGHTS_TEST_dim()
	end
end

-- ## OVH/GLS/PED Integral Lights

-- $$ All Integral Lights

function AB_ALL_Integral_Lights_off ()
    AB_OVH_Integral_Lights_off()
    AB_GLS_Integral_Lights_off()
    AB_PED_Integral_Lights_off()
end

function AB_ALL_Integral_Lights_med ()
    AB_OVH_Integral_Lights_med()
    AB_GLS_Integral_Lights_med()
    AB_PED_Integral_Lights_med()
end

function AB_ALL_Integral_Lights_full ()
    AB_OVH_Integral_Lights_full()
    AB_GLS_Integral_Lights_full()
    AB_PED_Integral_Lights_full()
end

function AB_ALL_Integral_Lights_toggle ()
    AB_OVH_Integral_Lights_toggle()
    AB_GLS_Integral_Lights_toggle()
    AB_PED_Integral_Lights_toggle()
end

function AB_ALL_Integral_Lights_cycle ()
    AB_OVH_Integral_Lights_cycle()
    AB_GLS_Integral_Lights_cycle()
    AB_PED_Integral_Lights_cycle()
end

function AB_ALL_Integral_Lights_inc ()
    AB_OVH_Integral_Lights_inc()
    AB_GLS_Integral_Lights_inc()
    AB_PED_Integral_Lights_inc()
end

function AB_ALL_Integral_Lights_dec ()
    AB_OVH_Integral_Lights_dec()
    AB_GLS_Integral_Lights_dec()
    AB_PED_Integral_Lights_dec()
end

-- $$ OVH Integral Lights

function AB_OVH_Integral_Lights_off ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    ipc.writeLvar(Lvar, 0)
    DspShow('OVHI', '0%')
end

function AB_OVH_Integral_Lights_med ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    ipc.writeLvar(Lvar, 10)
    DspShow('OVHI', '50%')
end

function AB_OVH_Integral_Lights_full ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    ipc.writeLvar(Lvar, 20)
    DspShow('OVHI', '100%')
end

function AB_OVH_Integral_Lights_toggle ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    lval = ipc.readLvar(Lvar)
    if lval ~= 0 then
        AB_OVH_Integral_Lights_off()
    else
        AB_OVH_Integral_Lights_med()
    end
end

function AB_OVH_Integral_Lights_cycle ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    lval = ipc.readLvar(Lvar)
    if lval == 0 then
        AB_OVH_Integral_Lights_med()
    elseif lval < 20 then
        AB_OVH_Integral_Lights_full()
    else
        AB_OVH_Integral_Lights_off()
    end
end

function AB_OVH_Integral_Lights_inc ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    lval = ipc.readLvar(Lvar)
    if lval < 20 then
        lval = lval + 1
        ipc.writeLvar(Lvar, lval)
        DspShow('OVHI', lval * 5 .. '%')
    end
end

function AB_OVH_Integral_Lights_dec ()
    if A330 then
        return
    end
Lvar = 'AB_OVH_INTEG_LT_SW'
    lval = ipc.readLvar(Lvar)
    if lval > 0 then
        lval = lval - 1
        ipc.writeLvar(Lvar, lval)
        DspShow('OVHI', lval * 5 .. '%')
    end
end

-- $$ GLS Integral Lights

function AB_GLS_Integral_Lights_off ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
    ipc.writeLvar(Lvar, 0)
    DspShow('GLSI', '0%')
end

function AB_GLS_Integral_Lights_med ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
    ipc.writeLvar(Lvar, 10)
    DspShow('GLSI', '50%')
end

function AB_GLS_Integral_Lights_full ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
    ipc.writeLvar(Lvar, 20)
    DspShow('GLSI', '100%')
end

function AB_GLS_Integral_Lights_toggle ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
    lval = ipc.readLvar(Lvar)
    if lval ~= 0 then
        AB_GLS_Integral_Lights_off()
    else
        AB_GLS_Integral_Lights_med()
    end
end

function AB_GLS_Integral_Lights_cycle ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
    lval = ipc.readLvar(Lvar)
    if lval == 0 then
        AB_GLS_Integral_Lights_med()
    elseif lval < 20 then
        AB_GLS_Integral_Lights_full()
    else
        AB_GLS_Integral_Lights_off()
    end
end

function AB_GLS_Integral_Lights_inc ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
lval = ipc.readLvar(Lvar)
    if lval < 20 then
        lval = lval + 1
        ipc.writeLvar(Lvar, lval)
        DspShow('GLSI', lval * 5 .. '%')
    end
end

function AB_GLS_Integral_Lights_dec ()
Lvar = 'AB_GLS_IntLight_INTEGRAL_GLARESHIELD_Rotary'
    lval = ipc.readLvar(Lvar)
    if lval > 0 then
        lval = lval - 1
        ipc.writeLvar(Lvar, lval)
        DspShow('GLSI', lval * 5 .. '%')
    end
end

-- $$ PED Integral Lights

function AB_PED_Integral_Lights_off ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
    ipc.writeLvar(Lvar, 0)
    DspShow('PEDI', '0%')
end

function AB_PED_Integral_Lights_med ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
    ipc.writeLvar(Lvar, 10)
    DspShow('PEDI', '50%')
end

function AB_PED_Integral_Lights_full ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
    ipc.writeLvar(Lvar, 20)
    DspShow('PEDI', '100%')
end

function AB_PED_Integral_Lights_toggle ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
    lval = ipc.readLvar(Lvar)
    if lval ~= 0 then
        AB_PED_Integral_Lights_off()
    else
        AB_PED_Integral_Lights_med()
    end
end

function AB_PED_Integral_Lights_cycle ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
    lval = ipc.readLvar(Lvar)
    _logg('lval=' .. lval)
    if lval == 0 then
        AB_PED_Integral_Lights_med()
    elseif (lval < 20) then
        AB_PED_Integral_Lights_full()
    else
        AB_PED_Integral_Lights_off()
    end
end

function AB_PED_Integral_Lights_inc ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
    lval = ipc.readLvar(Lvar)
    if lval < 20 then
        lval = lval + 1
        ipc.writeLvar(Lvar, lval)
        DspShow('PEDI', lval * 5 .. '%')
    end
end

function AB_PED_Integral_Lights_dec ()
    if A330 then
Lvar = "AB_PDS_IntLight_INTEG_CPT_Rotary"
    else
Lvar = 'AB_PDS_IntLight_INTEG_MAIN_PNL_PED_CPT_ROTARY'
    end
lval = ipc.readLvar(Lvar)
    if lval > 0 then
        lval = lval - 1
        ipc.writeLvar(Lvar, lval)
        DspShow('PEDI', lval * 5 .. '%')
    end
end

-- ## OVH/GLS/PED Flood Lights

-- $$ ALL Flood Lights

function AB_ALL_FLOOD_Lights_off ()
    AB_PED_FLOOD_MAIN_Lights_off()
    AB_PED_FLOOD_PEDESTAL_Lights_off()
end

function AB_ALL_FLOOD_Lights_med ()
    AB_PED_FLOOD_MAIN_Lights_med()
    AB_PED_FLOOD_PEDESTAL_Lights_med()
end

function AB_ALL_FLOOD_Lights_full ()
    AB_PED_FLOOD_MAIN_Lights_full()
    AB_PED_FLOOD_PEDESTAL_Lights_full()
end

function AB_ALL_FLOOD_Lights_toggle ()
    AB_PED_FLOOD_MAIN_Lights_toggle()
    AB_PED_FLOOD_PEDESTAL_Lights_toggle()
end

function AB_ALL_FLOOD_Lights_cycle ()
    AB_PED_FLOOD_MAIN_Lights_cycle()
    AB_PED_FLOOD_PEDESTAL_Lights_cycle()
end

function AB_ALL_FLOOD_Lights_inc ()
    AB_PED_FLOOD_MAIN_Lights_inc()
    AB_PED_FLOOD_PEDESTAL_Lights_inc()
end

function AB_ALL_FLOOD_Lights_dec ()
    AB_PED_FLOOD_MAIN_Lights_dec()
    AB_PED_FLOOD_PEDESTAL_Lights_dec()
end

-- $$ PED Main Panel Flood Lights Capt

function AB_PED_FLOOD_MAIN_Lights_off ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    ipc.writeLvar(Lvar, 0)
    DspShow('FLCM', '0%')
end

function AB_PED_FLOOD_MAIN_Lights_med ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    ipc.writeLvar(Lvar, 10)
    DspShow('FLCM', '50%')
end

function AB_PED_FLOOD_MAIN_Lights_full ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    ipc.writeLvar(Lvar, 20)
    DspShow('FLCM', '100%')
end

function AB_PED_FLOOD_MAIN_Lights_toggle ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    lval = ipc.readLvar(Lvar)
    if lval <= 10 then
        AB_PED_FLOOD_MAIN_Lights_full()
    else
        AB_PED_FLOOD_MAIN_Lights_med()
    end
end

function AB_PED_FLOOD_MAIN_Lights_cycle ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    lval = ipc.readLvar(Lvar)
    if lval == 0 then
        AB_PED_FLOOD_MAIN_Lights_med()
    elseif lval < 20 then
        AB_PED_FLOOD_MAIN_Lights_full()
    else
        AB_PED_FLOOD_MAIN_Lights_off()
    end
end

function AB_PED_FLOOD_MAIN_Lights_inc ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    lval = ipc.readLvar(Lvar)
    if lval < 20 then
        lval = lval + 1
        ipc.writeLvar(Lvar, lval)
        DspShow('FLCM', lval * 5 .. '%')
    end
end

function AB_PED_FLOOD_MAIN_Lights_dec ()
Lvar = 'AB_PDS_FLOOD_MAIN_PNL_Rot'
    lval = ipc.readLvar(Lvar)
    if lval > 0 then
        lval = lval - 1
        ipc.writeLvar(Lvar, lval)
        DspShow('FLCM', lval * 5 .. '%')
    end
end

-- $$ PED Pedestal Flood Lights FO

function AB_PED_FLOOD_PEDESTAL_Lights_off ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    ipc.writeLvar(Lvar, 0)
    DspShow('FLCP', '0%')
end

function AB_PED_FLOOD_PEDESTAL_Lights_med ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    ipc.writeLvar(Lvar, 10)
    DspShow('FLCP', '50%')
end

function AB_PED_FLOOD_PEDESTAL_Lights_full ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    ipc.writeLvar(Lvar, 20)
    DspShow('FLCP', '100%')
end

function AB_PED_FLOOD_PEDESTAL_Lights_toggle ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    lval = ipc.readLvar(Lvar)
    if lval <= 10 then
        AB_PED_FLOOD_PEDESTAL_Lights_full()
    else
        AB_PED_FLOOD_PEDESTAL_Lights_med()
    end
end

function AB_PED_FLOOD_PEDESTAL_Lights_cycle ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    lval = ipc.readLvar(Lvar)
    if lval == 0 then
        AB_PED_FLOOD_PEDESTAL_Lights_med()
    elseif lval < 20 then
        AB_PED_FLOOD_PEDESTAL_Lights_full()
    else
        AB_PED_FLOOD_PEDESTAL_Lights_off()
    end
end

function AB_PED_FLOOD_PEDESTAL_Lights_inc ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    lval = ipc.readLvar(Lvar)
    if lval < 20 then
        lval = lval + 1
        ipc.writeLvar(Lvar, lval)
        DspShow('FLCP', lval * 5 .. '%')
    end
end

function AB_PED_FLOOD_PEDESTAL_Lights_dec ()
Lvar = 'AB_PDS_FLOOD_PED_Rot'
    lval = ipc.readLvar(Lvar)
    if lval > 0 then
        lval = lval - 1
        ipc.writeLvar(Lvar, lval)
        DspShow('FLCP', lval * 5 .. '%')
    end
end

-- ## OVH/GLS/PED Other Lights

-- $$ FCU Display Lights

function AB_FCU_Display_Lights_off ()
Lvar = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    ipc.writeLvar(Lvar, 0)
    DspShow('FCU', '0%')
end

function AB_FCU_Display_Lights_med ()
Lvar = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    ipc.writeLvar(Lvar, 10)
    DspShow('FCU', '50%')
end

function AB_FCU_Display_Lights_full ()
Lvar = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    ipc.writeLvar(Lvar, 20)
    DspShow('FCU', '100%')
end

function AB_FCU_Display_Lights_toggle ()
    Lvarr = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if Lvarl <= 10 then
        AB_FCU_Display_Lights_full()
    else
        AB_FCU_Display_Lights_med()
    end
end

function AB_FCU_Display_Lights_cycle ()
Lvar = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if Lvarl == 0 then
        AB_FCU_Display_Lights_med()
    elseif Lvarl < 20 then
        AB_FCU_Display_Lights_full()
    else
        AB_FCU_Display_Lights_off()
    end
end

function AB_FCU_Display_Lights_inc ()
Lvar = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if Lvarl < 20 then
        Lvarl = Lvarl + 1
        ipc.writeLvar(Lvar, Lvarl)
        DspShow('FCU', Lvarl * 5 .. '%')
    end
end

function AB_FCU_Display_Lights_dec ()
Lvar = 'AB_GLS_IntLight_FCU_DISPLAY_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if Lvarl > 0 then
        Lvarl = Lvarl - 1
        ipc.writeLvar(Lvar, Lvarl)
        DspShow('FLDC', Lvarl * 5 .. '%')
    end
end

-- $$ GLS Table Flood Light Capt

function AB_GLS_TABLE_CAPT_Lights_off ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        ipc.writeLvar(Lvar, 0)
        DspShow('TABC', '0%')
    end
end

function AB_GLS_TABLE_CAPT_Lights_med ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        ipc.writeLvar(Lvar, 10)
        DspShow('TABC', '50%')
    end
end

function AB_GLS_TABLE_CAPT_Lights_full ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        ipc.writeLvar(Lvar, 20)
        DspShow('TABC', '100%')
    end
end

function AB_GLS_TABLE_CAPT_Lights_toggle ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if  Lvarl <= 10 then
            AB_GLS_TABLE_CAPT_Lights_full()
        else
            AB_GLS_TABLE_CAPT_Lights_med()
        end
    end
end

function AB_GLS_TABLE_CAPT_Lights_cycle ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if  Lvarl == 0 then
            AB_GLS_TABLE_CAPT_Lights_med()
        elseif  Lvarl < 20 then
            AB_GLS_TABLE_CAPT_Lights_full()
        else
            AB_GLS_TABLE_CAPT_Lights_off()
        end
    end
end

function AB_GLS_TABLE_CAPT_Lights_inc ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if  Lvarl < 20 then
            Lvarl = Lvarl + 1
            ipc.writeLvar(Lvar,  Lvarl)
            DspShow('TABC',  Lvarl * 5 .. '%')
        end
    end
end

function AB_GLS_TABLE_CAPT_Lights_dec ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_CPT_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if  Lvarl > 0 then
            Lvarl = Lvarl - 1
            ipc.writeLvar(Lvar,  Lvarl)
            DspShow('TABC',  Lvarl * 5 .. '%')
        end
    end
end

-- $$ GLS Table Flood Light FO

function AB_GLS_TABLE_FO_Lights_off ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        ipc.writeLvar(Lvar, 0)
        DspShow('TABF', '0%')
    end
end

function AB_GLS_TABLE_FO_Lights_med ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        ipc.writeLvar(Lvar, 10)
        DspShow('TABF', '50%')
    end
end

function AB_GLS_TABLE_FO_Lights_full ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        ipc.writeLvar(Lvar, 20)
        DspShow('TABF', '100%')
    end
end

function AB_GLS_TABLE_FO_Lights_toggle ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if  Lvarl <= 10 then
            AB_GLS_TABLE_FO_Lights_full()
        else
            AB_GLS_TABLE_FO_Lights_med()
        end
    end
end

function AB_GLS_TABLE_FO_Lights_cycle ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if Lvarl == 0 then
            AB_GLS_TABLE_FO_Lights_med()
        elseif  Lvarl < 20 then
            AB_GLS_TABLE_FO_Lights_full()
        else
            AB_GLS_TABLE_FO_Lights_off()
        end
    end
end

function AB_GLS_TABLE_FO_Lights_inc ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if  Lvarl < 20 then
            Lvarl = Lvarl + 1
            ipc.writeLvar(Lvar,  Lvarl)
            DspShow('TABF',  Lvarl * 5 .. '%')
        end
    end
end

function AB_GLS_TABLE_FO_Lights_dec ()
    if A330 then
        return
    else
Lvar = 'AB_GLS_IntLight_TABLE_FO_Rotary'
        Lvarl = ipc.readLvar(Lvar)
        if Lvarl > 0 then
        Lvarl = Lvarl - 1
            ipc.writeLvar(Lvar,  Lvarl)
            DspShow('TABF',  Lvarl * 5 .. '%')
        end
    end
end

-- $$ Window Map Flood Light Capt

function AB_WIN_MAP_CAPT_Lights_off ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    ipc.writeLvar(Lvar, 0)
    DspShow('MAPC', '0%')
end

function AB_WIN_MAP_CAPT_Lights_med ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    ipc.writeLvar(Lvar, 10)
    DspShow('MAPC', '50%')
end

function AB_WIN_MAP_CAPT_Lights_full ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    ipc.writeLvar(Lvar, 20)
    DspShow('MAPC', '100%')
end

function AB_WIN_MAP_CAPT_Lights_toggle ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl <= 10 then
        AB_WIN_MAP_CAPT_Lights_full()
    else
        AB_WIN_MAP_CAPT_Lights_med()
    end
end

function AB_WIN_MAP_CAPT_Lights_cycle ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl == 0 then
        AB_WIN_MAP_CAPT_Lights_med()
    elseif  Lvarl < 20 then
        AB_WIN_MAP_CAPT_Lights_full()
    else
        AB_WIN_MAP_CAPT_Lights_off()
    end
end

function AB_WIN_MAP_CAPT_Lights_inc ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 20 then
        Lvarl = Lvarl + 1
        ipc.writeLvar(Lvar,  Lvarl)
        DspShow('MAPC',  Lvarl * 5 .. '%')
    end
end

function AB_WIN_MAP_CAPT_Lights_dec ()
Lvar = 'AB_Window_IntLight_MAP_CPT_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl > 0 then
        Lvarl = Lvarl - 1
        ipc.writeLvar(Lvar,  Lvarl)
        DspShow('MAPC',  Lvarl * 5 .. '%')
    end
end

-- $$ Window Map Flood Light FO

function AB_WIN_MAP_FO_Lights_off ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    ipc.writeLvar(Lvar, 0)
    DspShow('MAPF', '0%')
end

function AB_WIN_MAP_FO_Lights_med ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    ipc.writeLvar(Lvar, 10)
    DspShow('MAPF', '50%')
end

function AB_WIN_MAP_FO_Lights_full ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    ipc.writeLvar(Lvar, 20)
    DspShow('MAPF', '100%')
end

function AB_WIN_MAP_FO_Lights_toggle ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl <= 10 then
        AB_WIN_MAP_FO_Lights_full()
    else
        AB_WIN_MAP_FO_Lights_med()
    end
end

function AB_WIN_MAP_FO_Lights_cycle ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl == 0 then
        AB_WIN_MAP_FO_Lights_med()
    elseif  Lvarl < 20 then
        AB_WIN_MAP_FO_Lights_full()
    else
        AB_WIN_MAP_FO_Lights_off()
    end
end

function AB_WIN_MAP_FO_Lights_inc ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 20 then
        Lvarl = Lvarl + 1
        ipc.writeLvar(Lvar,  Lvarl)
        DspShow('MAPF',  Lvarl * 5 .. '%')
    end
end

function AB_WIN_MAP_FO_Lights_dec ()
Lvar = 'AB_Window_IntLight_MAP_FO_Rotary'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl > 0 then
        Lvarl = Lvarl - 1
        ipc.writeLvar(Lvar,  Lvarl)
        DspShow('MAPF',  Lvarl * 5 .. '%')
    end
end



-- ## OVH Anti ICE ###############

function AB_OVH_AntiIce_WING_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_WING", 1)
   AB_OVH_Pushbutton ()
   DspShow ("WIce", "on")
end

function AB_OVH_AntiIce_WING_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_WING", 0)
   AB_OVH_Pushbutton ()
   DspShow ("WIce", "off")
end

function AB_OVH_AntiIce_WING_toggle ()
	if _tl("AB_OVH_ANTIICE_WING", 0) then
       AB_OVH_AntiIce_WING_on ()
	else
       AB_OVH_AntiIce_WING_off ()
	end
end

function AB_OVH_AntiIce_ENGL_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGL", 1)
   AB_OVH_Pushbutton ()
   DspShow ("LIce", "on")
end

function AB_OVH_AntiIce_ENGL_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGL", 0)
   AB_OVH_Pushbutton ()
   DspShow ("LIce", "off")
end

function AB_OVH_AntiIce_ENGL_toggle ()
	if _tl("AB_OVH_ANTIICE_ENGL", 0) then
       AB_OVH_AntiIce_ENGL_on ()
	else
       AB_OVH_AntiIce_ENGL_off ()
	end
end

function AB_OVH_AntiIce_ENGR_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGR", 1)
   AB_OVH_Pushbutton ()
   DspShow ("RIce", "on")
end

function AB_OVH_AntiIce_ENGR_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGR", 0)
   AB_OVH_Pushbutton ()
   DspShow ("RIce", "off")
end

function AB_OVH_AntiIce_ENGR_toggle ()
	if _tl("AB_OVH_ANTIICE_ENGR", 0) then
       AB_OVH_AntiIce_ENGR_on ()
	else
       AB_OVH_AntiIce_ENGR_off ()
	end
end

function AB_OVH_AntiIce_ENG_both_on ()
    AB_OVH_AntiIce_ENGL_on ()
    _sleep(100,500)
    AB_OVH_AntiIce_ENGR_on ()
end

function AB_OVH_AntiIce_ENG_both_off ()
    AB_OVH_AntiIce_ENGL_off ()
    _sleep(100,500)
    AB_OVH_AntiIce_ENGR_off ()
end

function AB_OVH_AntiIce_ENG_both_toggle ()
    AB_OVH_AntiIce_ENGL_toggle ()
    _sleep(100,500)
    AB_OVH_AntiIce_ENGR_toggle ()
end

function AB_OVH_AntiIce_ProbeWind_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_PROBEWINDOW", 1)
   AB_OVH_Pushbutton ()
   DspShow ("RIce", "on")
end

function AB_OVH_AntiIce_ProbeWind_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_PROBEWINDOW", 0)
   AB_OVH_Pushbutton ()
   DspShow ("RIce", "off")
end

function AB_OVH_AntiIce_ProbeWind_toggle ()
	if _tl("AB_OVH_ANTIICE_PROBEWINDOW", 0) then
       AB_OVH_AntiIce_ProbeWind_on ()
	else
       AB_OVH_AntiIce_ProbeWind_off ()
	end
end

-- ## OVH Air Cond ###############

function AB_OVH_Pack1_on ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_PACK1_OFF_PB"
    else
Lvar = "AB_OVH_PNEUPACKL"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PAK1", "on")
end

function AB_OVH_Pack1_off ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_PACK1_OFF_PB"
    else
Lvar = "AB_OVH_PNEUPACKL"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PAK1", "off")
end

function AB_OVH_Pack1_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_PACK1_OFF_PB"
    else
Lvar = "AB_OVH_PNEUPACKL"
    end
	if _tl(Lvar, 0) then
		AB_OVH_Pack1_on ()
	else
		AB_OVH_Pack1_off ()
	end
end

function AB_OVH_Pack2_on ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_PACK2_OFF_PB"
    else
Lvar = "AB_OVH_PNEUPACKR"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PAK2", "on")
end

function AB_OVH_Pack2_off ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_PACK2_OFF_PB"
    else
Lvar = "AB_OVH_PNEUPACKR"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PAK2", "off")
end

function AB_OVH_Pack2_toggle ()
	if _tl("AB_OVH_PNEUPACKR", 0) then
		AB_OVH_Pack2_on ()
	else
		AB_OVH_Pack2_off ()
	end
end

function AB_OVH_Pack_BOTH_on ()
	AB_OVH_Pack1_on ()
    _sleep(100,200)
	AB_OVH_Pack2_on ()
end

function AB_OVH_Pack_BOTH_off ()
	AB_OVH_Pack1_off ()
    _sleep(100,200)
	AB_OVH_Pack2_off ()
end

function AB_OVH_Pack_BOTH_toggle ()
	if _t("PackBOTH") then
		AB_Pack_BOTH_on ()
	else
		AB_Pack_BOTH_off ()
	end
end

-----

function AB_OVH_Eng1_Bleed_on ()
   Lvar = "AB_OVH_PNEUBLEEDL"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("BLD1", "on")
end

function AB_OVH_Eng1_Bleed_off ()
   Lvar = "AB_OVH_PNEUBLEEDL"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("BLD1", "off")
end

function AB_OVH_Eng1_Bleed_toggle ()
	if _tl("AB_OVH_PNEUBLEEDL", 0) then
		AB_OVH_Eng1_Bleed_on ()
	else
		AB_OVH_Eng1_Bleed_off ()
	end
end

function AB_OVH_Eng2_Bleed_on ()
   Lvar = "AB_OVH_PNEUBLEEDR"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("BLD2", "on")
end

function AB_OVH_Eng2_Bleed_off ()
   Lvar = "AB_OVH_PNEUBLEEDR"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("BLD2", "off")
end

function AB_OVH_Eng2_Bleed_toggle ()
	if _tl("AB_OVH_PNEUBLEEDR", 0) then
		AB_OVH_Eng2_Bleed_on ()
	else
		AB_OVH_Eng2_Bleed_off ()
	end
end

function AB_OVH_Eng_Bleed_BOTH_on ()
	AB_OVH_Eng1_Bleed_on ()
    _sleep(100,200)
	AB_OVH_Eng2_Bleed_on ()
end

function AB_OVH_Eng_Bleed_BOTH_off ()
	AB_OVH_Eng1_Bleed_off ()
    _sleep(100,200)
	AB_OVH_Eng2_Bleed_off ()
end

function AB_OVH_Eng_Bleed_BOTH_toggle ()
	if _t("Eng_BleedBOTH") then
		AB_OVH_Eng_Bleed_BOTH_on ()
	else
		AB_OVH_Eng_Bleed_BOTH_off ()
	end
end

function AB_OVH_HotAir_on ()
   Lvar = "AB_OVH_HOTAIR"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("HotA", "on")
end

function AB_OVH_HotAir_off ()
   Lvar = "AB_OVH_HOTAIR"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("HotA", "off")
end

function AB_OVH_HotAir_toggle ()
	if _tl("AB_OVH_HOTAIR", 0) then
		AB_OVH_HotAir_on ()
	else
		AB_OVH_HotAir_off ()
	end
end

function AB_OVH_Pack_Flow_norm ()
    ipc.writeLvar("AB_OVH_PACKFLOWCTR", 1)
    AB_MPL_LightSwitch ()
    DspShow ("PakF", "norm")
end

function AB_OVH_Pack_Flow_low ()
    ipc.writeLvar("AB_OVH_PACKFLOWCTR", 0)
    AB_MPL_LightSwitch ()
    DspShow ("PakF", "low")
end

function AB_OVH_Pack_Flow_high ()
    ipc.writeLvar("AB_OVH_PACKFLOWCTR", 2)
    AB_MPL_LightSwitch ()
    DspShow ("PakF", "high")
end

function AB_OVH_Pack_Flow_inc ()
    PakF = ipc.readLvar("AB_OVH_PACKFLOWCTR")
    if PakF == 0 then AB_Pack_Flow_norm ()
    elseif PakF == 1 then AB_Pack_Flow_high ()
    end
end

function AB_OVH_Pack_Flow_dec ()
    PakF = ipc.readLvar("AB_OVH_PACKFLOWCTR")
    if PakF == 2 then AB_Pack_Flow_norm ()
    elseif PakF == 1 then AB_Pack_Flow_low ()
    end
end

-----

function AB_OVH_XBleed_auto ()
    ipc.writeLvar("AB_OVH_PNEUXBLEED", 1)
    AB_MPL_LightSwitch ()
    DspShow ("XBld", "auto")
end

function AB_OVH_XBleed_shut ()
    ipc.writeLvar("AB_OVH_PNEUXBLEED", 0)
    AB_MPL_LightSwitch ()
    DspShow ("XBld", "shut")
end

function AB_OVH_XBleed_open ()
    ipc.writeLvar("AB_OVH_PNEUXBLEED", 2)
    AB_MPL_LightSwitch ()
    DspShow ("XBld", "open")
end

function AB_OVH_XBleed_inc ()
    XBld = ipc.readLvar("AB_OVH_PNEUXBLEED")
    if XBld == 0 then AB_XBleed_auto ()
    elseif XBld == 1 then AB_XBleed_open ()
    end
end

function AB_OVH_XBleed_dec ()
    XBld = ipc.readLvar("AB_OVH_PNEUXBLEED")
    if XBld == 2 then AB_XBleed_auto ()
    elseif XBld == 1 then AB_XBleed_shut ()
    end
end

---------

function AB_OVH_ZoneTemp_Cockpit_inc ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")
   if ZT1 <= 29.75 then
   ZT1 = ZT1 + 0.25
   else ZT1 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function AB_OVH_ZoneTemp_Cockpit_dec ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")
   if ZT1 >= 20.25 then
   ZT1 = ZT1 - 0.25
   else ZT1 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function AB_OVH_ZoneTemp_Cockpit_incfast ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")
   if ZT1 <= 29 then
   ZT1 = ZT1 + 1
   else ZT1 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function AB_OVH_ZoneTemp_Cockpit_decfast ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")
   if ZT1 >= 21 then
   ZT1 = ZT1 - 1
   else ZT1 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function AB_OVH_ZoneTemp_FwdCabin_inc ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")
   if ZT2 <= 29.75 then
   ZT2 = ZT2 + 0.25
   else ZT2 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function AB_OVH_ZoneTemp_FwdCabin_dec ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")
   if ZT2 >= 20.25 then
   ZT2 = ZT2 - 0.25
   else ZT2 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function AB_OVH_ZoneTemp_FwdCabin_incfast ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")
   if ZT2 <= 29 then
   ZT2 = ZT2 + 1
   else ZT2 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function AB_OVH_ZoneTemp_FwdCabin_decfast ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")
   if ZT2 >= 21 then
   ZT2 = ZT2 - 1
   else ZT2 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function AB_OVH_ZoneTemp_AftCabin_inc ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")
   if ZT3 <= 29.75 then
   ZT3 = ZT3 + 0.25
   else ZT3 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

function AB_OVH_ZoneTemp_AftCabin_dec ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")
   if ZT3 >= 20.25 then
   ZT3 = ZT3 - 0.25
   else ZT3 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

function AB_OVH_ZoneTemp_AftCabin_incfast ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")
   if ZT3 <= 29 then
   ZT3 = ZT3 + 1
   else ZT3 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

function AB_OVH_ZoneTemp_AftCabin_decfast ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")
   if ZT3 >= 21 then
   ZT3 = ZT3 - 1
   else ZT3 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

-- ## OVH ELECTRICAL ########

function AB_OVH_ELECBAT1_on ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_BAT1_OFF_PB"
    else
Lvar = "AB_OVH_ELECBAT1"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("BAT1", "on")
end

function AB_OVH_ELECBAT1_off ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_BAT1_OFF_PB"
    else
Lvar = "AB_OVH_ELECBAT1"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("BAT1", "off")
end

function AB_OVH_ELECBAT1_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_BAT1_OFF_PB"
    else
Lvar = "AB_OVH_ELECBAT1"
    end
	if _tl(Lvar, 0) then
		AB_OVH_ELECBAT1_on()
	else
		AB_OVH_ELECBAT1_off()
	end
end

function AB_OVH_ELECBAT2_on ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_BAT2_OFF_PB"
    else
Lvar = "AB_OVH_ELECBAT2"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("BAT2", "on")
end

function AB_OVH_ELECBAT2_off ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_BAT2_OFF_PB"
    else
Lvar = "AB_OVH_ELECBAT2"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("BAT2", "off")
end

function AB_OVH_ELECBAT2_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_BAT2_OFF_PB"
    else
Lvar = "AB_OVH_ELECBAT2"
    end
	if _tl(Lvar, 0) then
		AB_OVH_ELECBAT2_on()
	else
		AB_OVH_ELECBAT2_off()
	end
end

function AB_OVH_ELECBAT_BOTH_on ()
	AB_OVH_ELECBAT1_on()
    _sleep(100,200)
	AB_OVH_ELECBAT2_on()
end

function AB_OVH_ELECBAT_BOTH_off ()
	AB_OVH_ELECBAT1_off()
    _sleep(100,200)
	AB_OVH_ELECBAT2_off()
end

function AB_Battery_BOTH_toggle ()
	if _t("AB_OVH_ELECBAT1") then
		AB_OVH_ELECBAT_BOTH_on()
        A33_OVH_ELECAPUBAT_on ()
	else
		AB_OVH_ELECBAT_BOTH_off()
        A33_OVH_ELECAPUBAT_off ()
	end
end

----

function A33_OVH_ELECAPUBAT_on ()
   Lvar = "AB_VC_OVH_ELEC_APUBAT_OFF_PB"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("APUB", "on")
end

function A33_OVH_ELECAPUBAT_off ()
   Lvar = "AB_VC_OVH_ELEC_APUBAT_OFF_PB"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("APUB", "off")
end

function A33_OVH_ELECAPUBAT_toggle ()
	if _tl("AB_VC_OVH_ELEC_APUBAT_OFF", 1) then
		A33_OVH_ELECAPUBAT_on()
	else
		A33_OVH_ELECAPUBAT_off()
	end
end

---

function AB_OVH_GEN1_on ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_GEN1_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENL"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("GEN1", "on")
end

function AB_OVH_GEN1_off ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_GEN1_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENL"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("GEN1", "off")
end

function AB_OVH_GEN1_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_GEN1_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENL"
    end
	if _tl(Lvar, 0) then
		AB_OVH_GEN1_on ()
	else
		AB_OVH_GEN1_off ()
	end
end

function AB_OVH_GEN2_on ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_GEN2_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENR"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("GEN2", "on")
end

function AB_OVH_GEN2_off ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_GEN2_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENR"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("GEN2", "off")
end

function AB_OVH_GEN2_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_GEN2_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENR"
    end
	if _tl(Lvar, 0) then
		AB_OVH_GEN2_on ()
	else
		AB_OVH_GEN2_off ()
	end
end

function AB_OVH_GEN_BOTH_on ()
	AB_OVH_GEN1_on ()
    _sleep(100,200)
	AB_OVH_GEN2_on ()
end

function AB_OVH_GEN_BOTH_off ()
	AB_OVH_GEN1_off ()
    _sleep(100,200)
	AB_OVH_GEN2_off ()
end

function AB_OVH_GEN_BOTH_toggle ()
	if _t("GENBOTH") then
		AB_OVH_GEN_BOTH_on ()
	else
		AB_OVH_GEN_BOTH_off ()
	end
end

---

function AB_OVH_BUS_TIE_on ()
   Lvar = "AB_OVH_ELECBT"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("BUS", "on")
end

function AB_OVH_BUS_TIE_off ()
   Lvar = "AB_OVH_ELECBT"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("BUS", "off")
end

function AB_OVH_BUS_TIE_toggle ()
	if _tl("AB_OVH_ELECBT", 0) then
		AB_OVH_BUS_TIE_on ()
	else
		AB_OVH_BUS_TIE_off ()
	end
end

----

function AC_OVH_ESS_FEED_on ()
   Lvar = "AB_OVH_AC_ESS_FEED"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("FEED", "on")
end

function AC_OVH_ESS_FEED_off ()
   Lvar = "AB_OVH_AC_ESS_FEED"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("FEED", "off")
end

function AC_OVH_ESS_FEED_toggle ()
	if _tl("AB_OVH_AC_ESS_FEED", 0) then
		AC_OVH_ESS_FEED_on ()
	else
		AC_OVH_ESS_FEED_off ()
	end
end

-- $$ External Power

function AB_OVH_EXT_PWR_on ()
Lvar = "AB_OVH_ELECEXT"
    Lvar1 = "AB_VC_OVH_ELEC_EXTA_MPB"
    Lvar2 = "AB_VC_OVH_ELEC_EXTA_AVAIL"
    if ipc.readLvar(Lvar2) == 0  then
        DspShow ("!Ext", "!Pwr")
        _sleep(1500)
        DspShow ("not", "avlb")
        _sleep(1500)
    else
        ipc.writeLvar(Lvar, 1)
        _sleep(200)
        ipc.writeLvar(Lvar1, 1)
        ipc.writeLvar(Lvar, 0)
        AB_OVH_Pushbutton ()
        DspShow ("ExtP", "on")
    end
end

function AB_OVH_EXT_PWR_off ()
Lvar = "AB_OVH_ELECEXT"
    Lvar1 = "AB_VC_OVH_ELEC_EXTA_MPB"
    Lvar2 = "AB_VC_OVH_ELEC_EXTA_ON"
    ipc.writeLvar(Lvar, 1)
    _sleep(200)
    if ipc.readLvar(Lvar2) == 1 then
        ipc.writeLvar(Lvar1, 1)
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("ExtP", "off")
end

function AB_OVH_EXT_PWR_toggle ()
	if _tl("AB_VC_OVH_ELEC_EXTA_ON", 0) then
		AB_OVH_EXT_PWR_on ()
	else
		AB_OVH_EXT_PWR_off ()
	end
end

-- $$ A330 External Power

function A33_OVH_EXT_A_PWR_on ()
    if A330 then
Lvar = "AB_OVH_ELECEXT"
        Lvar1 = "AB_VC_OVH_ELEC_EXTA_MPB"
        Lvar2 = "AB_VC_OVH_ELEC_EXTA_AVAIL"
        if ipc.readLvar(Lvar2) == 0  then
            DspShow ("!Ext", "!Pwr")
            _sleep(1500)
            DspShow ("not", "avlb")
            _sleep(1500)
        else
            ipc.writeLvar(Lvar, 1)
            _sleep(200)
            ipc.writeLvar(Lvar1, 1)
            ipc.writeLvar(Lvar, 0)
            AB_OVH_Pushbutton ()
            DspShow ("ExtP", "on")
        end
    end
end

function A33_OVH_EXT_A_PWR_off ()
    if A330 then
Lvar = "AB_OVH_ELECEXT"
        Lvar1 = "AB_VC_OVH_ELEC_EXTA_MPB"
        Lvar2 = "AB_VC_OVH_ELEC_EXTA_ON"
        ipc.writeLvar(Lvar, 1)
        _sleep(200)
        if ipc.readLvar(Lvar2) == 1 then
            ipc.writeLvar(Lvar1, 1)
        end
        ipc.writeLvar(Lvar, 0)
        AB_OVH_Pushbutton ()
        DspShow ("ExtP", "off")
    end
end

function A33_OVH_EXT_A_PWR_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_ELEC_EXTA_ON", 0) then
            A33_OVH_EXT_A_PWR_on ()
        else
            A33_OVH_EXT_A_PWR_off ()
        end
	end
end

function A33_OVH_EXT_B_PWR_on ()
    if A330 then
Lvar = "AB_OVH_ELECEXT"
        Lvar1 = "AB_VC_OVH_ELEC_EXTB_MPB"
        Lvar2 = "AB_VC_OVH_ELEC_EXTB_AVAIL"
        if ipc.readLvar(Lvar2) == 0  then
            DspShow ("!Ext", "!Pwr")
            _sleep(1500)
            DspShow ("not", "avlb")
            _sleep(1500)
        else
            ipc.writeLvar(Lvar, 1)
            _sleep(200)
            ipc.writeLvar(Lvar1, 1)
            ipc.writeLvar(Lvar, 0)
            AB_OVH_Pushbutton ()
            DspShow ("ExtP", "on")
        end
    end
end

function A33_OVH_EXT_B_PWR_off ()
    if A330 then
Lvar = "AB_OVH_ELECEXT"
        Lvar1 = "AB_VC_OVH_ELEC_EXTB_MPB"
        Lvar2 = "AB_VC_OVH_ELEC_EXTB_ON"
        ipc.writeLvar(Lvar, 1)
        _sleep(200)
        if ipc.readLvar(Lvar2) == 1 then
            ipc.writeLvar(Lvar1, 1)
        end
        ipc.writeLvar(Lvar, 0)
        AB_OVH_Pushbutton ()
        DspShow ("ExtP", "off")
    end
end

function A33_OVH_EXT_B_PWR_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_ELEC_EXTB_ON", 0) then
            A33_OVH_EXT_B_PWR_on ()
        else
            A33_OVH_EXT_B_PWR_off ()
        end
	end
end

-- $$ IDG Cover

function AB_IDG1_Cover_open ()
   Lvar = "AB_OVH_IDG1_COVER"
    ipc.writeLvar(Lvar, 1)
end

function AB_IDG1_Cover_close ()
   Lvar = "AB_OVH_IDG1_COVER"
    ipc.writeLvar(Lvar, 0)
end

function AB_IDG1_Cover_toggle ()
	if _tl("AB_OVH_IDGCOVER", 0) then
		AB_IDG1_Cover_open ()
	else
		AB_IDG1_Cover_close ()
	end
end

function AB_IDG2_Cover_open ()
   Lvar = "AB_OVH_IDG2_COVER"
    ipc.writeLvar(Lvar, 1)
end

function AB_IDG2_Cover_close ()
   Lvar = "AB_OVH_IDG2_COVER"
    ipc.writeLvar(Lvar, 0)
end

function AB_IDG2_Cover_toggle ()
	if _tl("AB_OVH_IDG2_COVER", 0) then
		AB_IDG2_Cover_open ()
	else
		AB_IDG2_Cover_close ()
	end
end

----

function AB_IDG1_push ()
    AB_IDG1_Cover_open ()
    _sleep(300,600)
   Lvar = "AB_OVH_IDG1"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("IDG1", "disc")
end

function AB_IDG2_push ()
    AB_IDG2_Cover_open ()
    _sleep(300,600)
   Lvar = "AB_OVH_IDG2"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("IDG2", "disc")
end

-- ## OVH APU

function AB_OVH_APU_MASTER_on ()
    if A330 then
Lvar = "AB_VC_OVH_APU_MASTER_ON_PB"
    else
Lvar = "AB_OVH_APU_MASTER"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "on")
end

function AB_OVH_APU_MASTER_off ()
    if A330 then
Lvar = "AB_VC_OVH_APU_MASTER_ON_PB"
    else
Lvar = "AB_OVH_APU_MASTER"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    AB_OVH_APU_BLEED_off ()
    AB_OVH_APU_START_off ()
    DspShow ("APU", "off")
end

function AB_OVH_APU_MASTER_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_APU_MASTER_ON_PB"
    else
Lvar = "AB_OVH_APU_MASTER"
    end
	if _tl(Lvar, 0) then
		AB_OVH_APU_MASTER_on ()
	else
		AB_OVH_APU_MASTER_off ()
	end
end

function AB_OVH_APU_START_on ()
    if A330 then
Lvar = "AB_VC_OVH_APU_START_ON_PB"
    else
Lvar = "AB_OVH_APU_Start"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "strt")
end

function AB_OVH_APU_START_off ()
    if A330 then
Lvar = "AB_VC_OVH_APU_START_ON_PB"
    else
Lvar = "AB_OVH_APU_Start"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "Soff")
end

function AB_OVH_APU_START_press ()
    if A330 then
Lvar = "AB_VC_OVH_APU_START_ON_PB"
    else
Lvar = "AB_OVH_APU_Start"
    end
    ipc.writeLvar(Lvar, 1)
    _sleep(50)
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "strt")
end

function AB_OVH_APU_START_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_APU_START_ON_PB"
    else
Lvar = "AB_OVH_APU_Start"
    end
	if _tl(Lvar, 0) then
		AB_OVH_APU_START_on ()
	else
		AB_OVH_APU_START_off ()
	end
end

function AB_OVH_APU_BLEED_on ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_APU_BLD_ON_PB"
    else
Lvar = "AB_OVH_PNEUBLEEDAPU"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "bled")
end

function AB_OVH_APU_BLEED_off ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_APU_BLD_ON_PB"
    else
Lvar = "AB_OVH_PNEUBLEEDAPU"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "Boff")
end

function AB_OVH_APU_BLEED_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_AIR_APU_BLD_ON_PB"
    else
Lvar = "AB_OVH_PNEUBLEEDAPU"
    end
	if _tl(Lvar, 0) then
		AB_OVH_APU_BLEED_on ()
	else
		AB_OVH_APU_BLEED_off ()
	end
end

function AB_OVH_APU_GEN_on ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_APUGEN_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENAPU"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "Gen")
end

function AB_OVH_APU_GEN_off ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_APUGEN_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENAPU"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("APU", "Goff")
end

function AB_OVH_APU_GEN_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_APUGEN_OFF_PB"
    else
Lvar = "AB_OVH_ELECGENAPU"
    end
	if _tl(Lvar, 0) then
		AB_OVH_APU_GEN_on ()
	else
		AB_OVH_APU_GEN_off ()
	end
end

function AB_OVH_APU_Master_Start_on ()
    AB_OVH_APU_MASTER_on ()
    _sleep(200, 600)
    AB_OVH_APU_START_on ()
end

function AB_OVH_APU_Master_Start_off ()
    AB_OVH_APU_START_off ()
    _sleep(200, 600)
    AB_OVH_APU_MASTER_off ()
end

function AB_OVH_APU_Master_Start_toggle ()
	if _tl("APUMasterStart",0) then
       AB_OVH_APU_Master_Start_on ()
	else
       AB_OVH_APU_Master_Start_off ()
	end
end

function AB_OVH_APU_Master_Start_Bleed_on ()
    AB_OVH_APU_MASTER_on ()
    _sleep(200, 600)
    AB_OVH_APU_START_on ()
    _sleep(200, 600)
    AB_OVH_APU_BLEED_on ()
end

function AB_OVH_APU_Master_Start_Bleed_off ()
    AB_OVH_APU_BLEED_off ()
    _sleep(200, 600)
    AB_OVH_APU_START_off ()
    _sleep(200, 600)
    AB_OVH_APU_MASTER_off ()
end

function AB_OVH_APU_Master_Start_Bleed_toggle ()
	if _tl("APUMasterStartBleed",1) then
       AB_OVH_APU_Master_Start_Bleed_on ()
	else
       AB_OVH_APU_Master_Start_Bleed_off ()
	end
end

-- ## OVH Fuel  ###############

function AB_OVH_FuelPump_L_1_on ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_L1_OFF_PB"
    else
Lvar = "AB_OVH_FUELPL1"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PmpL", "1 on")
end

function AB_OVH_FuelPump_L_1_off ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_L1_OFF_PB"
    else
Lvar = "AB_OVH_FUELPL1"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PmpL", "1off")
end

function AB_OVH_FuelPump_L_1_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_L1_OFF_PB"
    else
Lvar = "AB_OVH_FUELPL1"
    end
	if _tl(Lvar, 0) then
		AB_OVH_FuelPump_L_1_on ()
	else
		AB_OVH_FuelPump_L_1_off ()
	end
end

function AB_OVH_FuelPump_L_2_on ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_L2_OFF_PB"
    else
Lvar = "AB_OVH_FUELPL2"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PmpL", "2 on")
end

function AB_OVH_FuelPump_L_2_off ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_L2_OFF_PB"
    else
Lvar = "AB_OVH_FUELPL2"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PmpL", "2off")
end

function AB_OVH_FuelPump_L_2_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_L2_OFF_PB"
    else
Lvar = "AB_OVH_FUELPL2"
    end
	if _tl(Lvar, 0) then
		AB_OVH_FuelPump_L_2_on ()
	else
		AB_OVH_FuelPump_L_2_off ()
	end
end

function AB_OVH_FuelPump_L_BOTH_on ()
    AB_OVH_FuelPump_L_1_on ()
    _sleep(100,250)
    AB_OVH_FuelPump_L_2_on ()
end

function AB_OVH_FuelPump_L_BOTH_off ()
    AB_OVH_FuelPump_L_1_off ()
    _sleep(100,250)
    AB_OVH_FuelPump_L_2_off ()
end

function AB_OVH_FuelPump_L_BOTH_toggle ()
	if _t("AB_FuelPump_LBOTH") then
		AB_OVH_FuelPump_L_BOTH_on ()
	else
		AB_OVH_FuelPump_L_BOTH_off ()
	end
end

---------

function AB_OVH_FuelPump_C_1_on ()
    if A330 then
        return
    end
Lvar = "AB_OVH_FUELPCL"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PmpC", "1 on")
end

function AB_OVH_FuelPump_C_1_off ()
    if A330 then
        return
    end
Lvar = "AB_OVH_FUELPCL"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PmpC", "1off")
end

function AB_OVH_FuelPump_C_1_toggle ()
    if A330 then
        return
    end
	if _tl("AB_OVH_FUELPCL", 0) then
		AB_OVH_FuelPump_C_1_on ()
	else
		AB_OVH_FuelPump_C_1_off ()
	end
end

function AB_OVH_FuelPump_C_2_on ()
    if A330 then
        return
    end
Lvar = "AB_OVH_FUELPCR"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PmpC", "2 on")
end

function AB_OVH_FuelPump_C_2_off ()
    if A330 then
        return
    end
Lvar = "AB_OVH_FUELPCR"
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PmpC", "2off")
end

function AB_OVH_FuelPump_C_2_toggle ()
    if A330  then
        return
    end
	if _tl("AB_OVH_FUELPCR", 0) then
		AB_OVH_FuelPump_C_2_on ()
	else
		AB_OVH_FuelPump_C_2_off ()
	end
end

function AB_OVH_FuelPump_C_BOTH_on ()
    if A330 then
        return
    end
    AB_OVH_FuelPump_C_1_on ()
    _sleep(100,250)
    AB_OVH_FuelPump_C_2_on ()
end

function AB_OVH_FuelPump_C_BOTH_off ()
    if A330 then
        return
    end
    AB_OVH_FuelPump_C_1_off ()
    _sleep(100,250)
    AB_OVH_FuelPump_C_2_off ()
end

function AB_OVH_FuelPump_C_BOTH_toggle ()
    if A330 then
        return
    end
	if _t("AB_FuelPump_CBOTH") then
		AB_OVH_FuelPump_C_BOTH_on ()
	else
		AB_OVH_FuelPump_C_BOTH_off ()
	end
end

function AB_OVH_FuelPump_R_1_on ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_R1_OFF_PB"
    else
Lvar = "AB_OVH_FUELPR1"
    end
    ipc.writeLvar(Lvar, 1)
    ipc.writeLvar("AB_OVH_FUELPR1", 1)
    AB_OVH_Pushbutton ()
    DspShow ("PmpR", "1 on")
end

function AB_OVH_FuelPump_R_1_off ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_R1_OFF_PB"
    else
Lvar = "AB_OVH_FUELPR1"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PmpR", "1off")
end

function AB_OVH_FuelPump_R_1_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_R1_OFF_PB"
    else
Lvar = "AB_OVH_FUELPR1"
    end
	if _tl(Lvar, 0) then
		AB_OVH_FuelPump_R_1_on ()
	else
		AB_OVH_FuelPump_R_1_off ()
	end
end

function AB_OVH_FuelPump_R_2_on ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_R2_OFF_PB"
    else
Lvar = "AB_OVH_FUELPR2"
    end
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("PmpR", "2 on")
end

function AB_OVH_FuelPump_R_2_off ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_R2_OFF_PB"
    else
Lvar = "AB_OVH_FUELPR2"
    end
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("PmpR", "2off")
end

function AB_OVH_FuelPump_R_2_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_FUEL_R2_OFF_PB"
    else
Lvar = "AB_OVH_FUELPR2"
    end
	if _tl(Lvar, 0) then
		AB_OVH_FuelPump_R_2_on ()
	else
		AB_OVH_FuelPump_R_2_off ()
	end
end

function AB_OVH_FuelPump_R_BOTH_on ()
    AB_OVH_FuelPump_R_1_on ()
    _sleep(100,250)
    AB_OVH_FuelPump_R_2_on ()
end

function AB_OVH_FuelPump_R_BOTH_off ()
    AB_OVH_FuelPump_R_1_off ()
    _sleep(100,250)
    AB_OVH_FuelPump_R_2_off ()
end

function AB_OVH_FuelPump_R_BOTH_toggle ()
	if _t("AB_FuelPump_RBOTH") then
		AB_OVH_FuelPump_R_BOTH_on ()
	else
		AB_OVH_FuelPump_R_BOTH_off ()
	end
end

function AB_OVH_FuelPumps_ALL_on ()
    AB_OVH_FuelPump_L_BOTH_on ()
    _sleep(100,250)
    AB_OVH_FuelPump_C_BOTH_on ()
    _sleep(100,250)
    AB_OVH_FuelPump_R_BOTH_on ()
    _sleep(100,250)
    A33_OVH_FuelPump_L_STBY_on ()
    _sleep(100,250)
    A33_OVH_FuelPump_R_STBY_on ()
end

function AB_OVH_FuelPumps_ALL_off ()
    AB_OVH_FuelPump_L_BOTH_off ()
    _sleep(100,250)
    AB_OVH_FuelPump_C_BOTH_off ()
    _sleep(100,250)
    AB_OVH_FuelPump_R_BOTH_off ()
    _sleep(100,250)
    A33_OVH_FuelPump_L_STBY_off ()
    _sleep(100,250)
    A33_OVH_FuelPump_R_STBY_off ()
end

function AB_OVH_FuelXFeed_on ()
    ipc.writeLvar("AB_OVH_FUELXF", 1)
    AB_OVH_Pushbutton ()
    DspShow ("XFed", "on")
end

function AB_OVH_FuelXFeed_off ()
    ipc.writeLvar("AB_OVH_FUELXF", 0)
    AB_OVH_Pushbutton ()
    DspShow ("XFed", "off")
end

function AB_OVH_FuelXFeed_toggle ()
	if _tl("AB_OVH_FUELXF", 0) then
		AB_OVH_FuelXFeed_on ()
	else
		AB_OVH_FuelXFeed_off ()
	end
end

function AB_OVH_Fuel_Mode_auto ()
    ipc.writeLvar("AB_OVH_FUELMODE", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FMod", "auto")
end

function AB_OVH_Fuel_Mode_manual ()
    ipc.writeLvar("AB_OVH_FUELMODE", 0)
    AB_OVH_Pushbutton ()
    DspShow ("FMod", "man")
end

function AB_OVH_Fuel_Mode_toggle ()
	if _tl("AB_OVH_FUELMODE", 0) then
		AB_OVH_Fuel_Mode_auto ()
	else
		AB_OVH_Fuel_Mode_manual()
	end
end

-- ## A330 Fuel Functions

function A33_OVH_FuelPump_L_STBY_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_LSTBY_OFF_PB", 1)
        AB_OVH_Pushbutton ()
        DspShow ("PmpL", "S on")
    end
end

function A33_OVH_FuelPump_L_STBY_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_LSTBY_OFF_PB", 0)
        AB_OVH_Pushbutton ()
        DspShow ("PmpL", "Soff")
    end
end

function A33_OVH_FuelPump_L_STBY_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_FUEL_LSTBY_OFF_PB", 0) then
            A33_OVH_FuelPump_L_STBY_on ()
        else
            A33_OVH_FuelPump_L_STBY_off ()
        end
	end
end

function A33_OVH_FuelPump_R_STBY_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_RSTBY_OFF_PB", 1)
        AB_OVH_Pushbutton ()
        DspShow ("PmpR", "S on")
    end
end

function A33_OVH_FuelPump_R_STBY_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_RSTBY_OFF_PB", 0)
        AB_OVH_Pushbutton ()
        DspShow ("PmpR", "Soff")
    end
end

function A33_OVH_FuelPump_R_STBY_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_FUEL_RSTBY_OFF_PB", 0) then
            A33_OVH_FuelPump_R_STBY_on ()
        else
            A33_OVH_FuelPump_R_STBY_off ()
        end
	end
end

function A33_OVH_FuelPump_L_STBY_BOTH_on ()
    if A330 then
        A33_OVH_FuelPump_L_STBY_on ()
        _sleep(100,250)
        A33_OVH_FuelPump_R_STBY_on ()
    end
end

function A33_OVH_FuelPump_L_STBY_BOTH_off ()
    if A330 then
        A33_OVH_FuelPump_L_STBY_off ()
        _sleep(100,250)
        A33_OVH_FuelPump_R_STBY_off ()
    end
end

function A33_OVH_FuelPump_L_STBY_BOTH_toggle ()
    if A330 then
        A33_OVH_FuelPump_L_STBY_toggle ()
        _sleep(100,250)
        A33_OVH_FuelPump_R_STBY_toggle ()
    end
end

function A33_OVH_FuelXFeedOuter_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_OTK_XFR_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_FUEL_OTK_XFR_OFF_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_FUEL_OTK_XFR_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("XFed", "off")
    end
end

function A33_OVH_FuelXFeedOuter_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_FUEL_OTK_XFR_ON", 0) then
            A33_OVH_FuelXFeedOuter_on ()
        else
            A33_OVH_FuelXFeedOuter_off ()
        end
	end
end

function A33_OVH_Fuel_Mode_auto ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_MODE_PB", 1)
        AB_OVH_Pushbutton ()
        DspShow ("FMod", "auto")
    end
end

function A33_OVH_Fuel_Mode_manual ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_MODE_PB", 0)
        AB_OVH_Pushbutton ()
        DspShow ("FMod", "man")
    end
end

function A33_OVH_Fuel_Mode_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_FUEL_TTANK_MODE_PB", 0) then
            A33_OVH_Fuel_Mode_auto ()
        else
            A33_OVH_Fuel_Mode_manual()
        end
	end
end

function A33_OVH_Fuel_TTank_isol ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_FD_GUARD", 1)
        _sleep(100)
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_FD_SW", 0)
        DspShow("TTnk", "isol")
    end
end

function A33_OVH_Fuel_TTank_auto ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_FD_GUARD", 1)
        _sleep(100)
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_FD_SW", 1)
        _sleep(100)
        ipc.writeLvar("AB_VC_OVH_FUEL_TTANK_FD_GUARD", 0)
        DspShow("TTnk", "isol")
    end
end

function A33_OVH_Fuel_TTank_open ()
    if A330 then
        ipc.writeLvar("A33_VC_OVH_FUEL_TTANK_FD_GUARD", 1)
        _sleep(100)
        ipc.writeLvar("A33_VC_OVH_FUEL_TTANK_FD_SW", 2)
        DspShow("TTnk", "isol")
    end
end

-- ## OVH Hyd ###############

function AB_OVH_Hyd_Pump_L_on ()
    ipc.writeLvar("AB_OVH_HYDL", 1)
    AB_OVH_Pushbutton ()
    DspShow ("HydP", "1 on")
end

function AB_OVH_Hyd_Pump_L_off ()

    ipc.writeLvar("AB_OVH_HYDL", 0)
    AB_OVH_Pushbutton ()
    DspShow ("HydP", "1off")
end

function AB_OVH_Hyd_Pump_L_toggle ()
	if _tl("AB_OVH_HYDL", 0) then
		AB_OVH_Hyd_Pump_L_on ()
	else
		AB_OVH_Hyd_Pump_L_off()
	end
end

function AB_OVH_Hyd_Pump_R_on ()
    ipc.writeLvar("AB_OVH_HYDR", 1)
    AB_OVH_Pushbutton ()
    DspShow ("HydP", "2 on")
end

function AB_OVH_Hyd_Pump_R_off ()
    ipc.writeLvar("AB_OVH_HYDR", 0)
    AB_OVH_Pushbutton ()
    DspShow ("HydP", "2off")
end

function AB_OVH_Hyd_Pump_R_toggle ()
	if _tl("AB_OVH_HYDR", 0) then
		AB_OVH_Hyd_Pump_R_on ()
	else
		AB_OVH_Hyd_Pump_R_off()
	end
end

function AB_OVH_Hyd_PTU_auto ()
    ipc.writeLvar("AB_OVH_HYDPTU", 1)
    AB_OVH_Pushbutton ()
    DspShow ("PTU", "auto")
end

function AB_OVH_Hyd_PTU_off ()
    ipc.writeLvar("AB_OVH_HYDPTU", 0)
    AB_OVH_Pushbutton ()
    DspShow ("PTU", "off")
end

function AB_OVH_Hyd_PTU_toggle ()
	if _tl("AB_OVH_HYDPTU", 0) then
		AB_OVH_Hyd_PTU_auto ()
	else
		AB_OVH_Hyd_PTU_off()
	end
end

function AB_OVH_Hyd_Elec_Pump1_Cover_open ()
    ipc.writeLvar("AB_OVH_HYDELEC1_COVER", 1)
end

function AB_OVH_Hyd_Elec_Pump1_Cover_close ()
    ipc.writeLvar("AB_OVH_HYDELEC1_COVER", 0)
end

function AB_OVH_Hyd_Elec_Pump1_Cover_toggle ()
	if _tl("AB_OVH_HYDELEC1_COVER", 0) then
		AB_OVH_Hyd_Elec_Pump1_Cover_open ()
	else
		AB_OVH_Hyd_Elec_Pump1_Cover_close ()
	end
end

function AB_OVH_Hyd_Elec_Pump1_auto ()
    AB_OVH_Hyd_Elec_Pump1_Cover_open ()
    ipc.writeLvar("AB_OVH_HYDELEC1", 1)
    AB_OVH_Pushbutton ()
    _sleep(300,600)
    AB_OVH_Hyd_Elec_Pump1_Cover_close ()
    DspShow ("EPmp", "1 on")
end

function AB_OVH_Hyd_Elec_Pump1_off ()
    AB_OVH_Hyd_Elec_Pump1_Cover_open ()
    _sleep(300,600)
    ipc.writeLvar("AB_OVH_HYDELEC1", 0)
    AB_OVH_Pushbutton ()
    AB_OVH_Hyd_Elec_Pump1_Cover_close ()
    DspShow ("EPmp", "1off")
end

function AB_OVH_Hyd_Elec_Pump1_toggle ()
	if _tl("AB_OVH_HYDELEC1", 0) then
		AB_OVH_Hyd_Elec_Pump1_auto ()
	else
		AB_OVH_Hyd_Elec_Pump1_off()
	end
end

function AB_OVH_Hyd_Elec_Pump2_on ()
    ipc.writeLvar("AB_OVH_HYDELEC2", 1)
    AB_OVH_Pushbutton ()
    DspShow ("EPmp", "2 on")
    _sleep(200)
    if ipc.readLvar("AB_OVH_HYDELEC2") == 0 then
    DspShow ("EPmp", "fail")
    end
end

function AB_OVH_Hyd_Elec_Pump2_off ()
    ipc.writeLvar("AB_OVH_HYDELEC2", 0)
    AB_OVH_Pushbutton ()
    DspShow ("EPmp", "2off")
end

function AB_OVH_Hyd_Elec_Pump2_toggle ()
	if _tl("AB_OVH_HYDELEC2", 0) then
		AB_OVH_Hyd_Elec_Pump2_on ()
	else
		AB_OVH_Hyd_Elec_Pump2_off()
	end
end

-- ## A330 OVH Hyd ###############

--$$ OVH Hyd Green

function A33_OVH_Hyd_G_Eng1_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_G_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_G_OFF_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_G_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydG", "1on")
    end
end

function A33_OVH_Hyd_G_Eng1_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_G_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_G_OFF_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_G_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydG", "1off")
    end
end

function A33_OVH_Hyd_G_Eng1_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ENG1_G_OFF_PB", 0) then
            AB_OVH_Hyd_G_Eng1_on ()
        else
            AB_OVH_Hyd_G_Eng1_off ()
        end
	end
end

function A33_OVH_Hyd_G_Eng2_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_G_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_G_OFF_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_G_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydG", "2on")
    end
end

function A33_OVH_Hyd_G_Eng2_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_G_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_G_OFF_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_G_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydG", "2off")
    end
end

function A33_OVH_Hyd_G_Eng2_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ENG2_G_OFF_PB", 0) then
            AB_OVH_Hyd_G_Eng2_on ()
        else
            AB_OVH_Hyd_G_Eng2_off ()
        end
	end
end

function A33_OVH_Hyd_G_Auto_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_ON_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydA", "1on")
    end
end

function A33_OVH_Hyd_G_Auto_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_ON_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydA", "1off")
    end
end

function A33_OVH_Hyd_G_Auto_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ELEC_G_ON_PB", 0) then
            A33_OVH_Hyd_G_Auto_on ()
        else
            A33_OVH_Hyd_G_Auto_off ()
        end
	end
end

function A33_OVH_Hyd_G_Elec_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_OFF_PB", 1)
        AB_OVH_Pushbutton ()
        DspShow ("ElHG", "1on")
    end
end

function A33_OVH_Hyd_G_Elec_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_G_OFF_PB", 0)
        AB_OVH_Pushbutton ()
        DspShow ("E1HG", "1off")
    end
end

function A33_OVH_Hyd_G_Elec_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ELEC_G_OFF_PB", 0) then
            A33_OVH_Hyd_G_Elec_on ()
        else
            A33_OVH_Hyd_G_Elec_off ()
        end
	end
end

--$$ OVH Hyd Blue

function A33_OVH_Hyd_B_Eng1_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_B_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_B_OFF_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_B_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydB", "1on")
    end
end

function A33_OVH_Hyd_B_Eng1_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_B_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_B_OFF_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG1_B_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydB", "1off")
    end
end

function A33_OVH_Hyd_B_Eng1_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ENG1_B_OFF_PB", 0) then
            A33_OVH_Hyd_B_Eng1_on ()
        else
            A33_OVH_Hyd_B_Eng1_off ()
        end
	end
end

function A33_OVH_Hyd_B_Auto_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_ON_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydB", "1on")
    end
end

function A33_OVH_Hyd_B_Auto_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_ON_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydB", "1off")
    end
end

function A33_OVH_Hyd_B_Auto_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ELEC_B_ON_PB", 0) then
            A33_OVH_Hyd_B_Auto_on ()
        else
            A33_OVH_Hyd_B_Auto_off ()
        end
	end
end

function A33_OVH_Hyd_B_Elec_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_OFF_PB", 1)
        AB_OVH_Pushbutton ()
        DspShow ("ElHB", "1on")
    end
end

function A33_OVH_Hyd_B_Elec_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_B_OFF_PB", 0)
        AB_OVH_Pushbutton ()
        DspShow ("E1HB", "1off")
    end
end

function A33_OVH_Hyd_B_Elec_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ELEC_B_OFF_PB", 0) then
            A33_OVH_Hyd_B_Elec_on ()
        else
            A33_OVH_Hyd_B_Elec_off ()
        end
	end
end

--$$ OVH Hyd Yellow

function A33_OVH_Hyd_Y_Eng2_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_Y_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_Y_OFF_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_Y_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydY", "2on")
    end
end

function A33_OVH_Hyd_Y_Eng2_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_Y_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_Y_OFF_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ENG2_Y_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydY", "2off")
    end
end

function A33_OVH_Hyd_Y_Eng2_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ENG2_Y_OFF_PB", 0) then
            A33_OVH_Hyd_Y_Eng2_on ()
        else
            A33_OVH_Hyd_Y_Eng2_off ()
        end
	end
end

function A33_OVH_Hyd_Y_Auto_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_ON_PB", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydY", "1on")
    end
end

function A33_OVH_Hyd_Y_Auto_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_GUARD", 1)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_ON_PB", 0)
        _sleep(50)
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_GUARD", 0)
        _sleep(50)
        AB_OVH_Pushbutton ()
        DspShow ("HydY", "1off")
    end
end

function A33_OVH_Hyd_Y_Auto_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ELEC_Y_ON_PB", 0) then
            A33_OVH_Hyd_Y_Auto_on ()
        else
            A33_OVH_Hyd_Y_Auto_off ()
        end
	end
end

function A33_OVH_Hyd_Y_Elec_on ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_OFF_PB", 1)
        AB_OVH_Pushbutton ()
        DspShow ("ElHY", "1on")
    end
end

function A33_OVH_Hyd_Y_Elec_off ()
    if A330 then
        ipc.writeLvar("AB_VC_OVH_HYD_ELEC_Y_OFF_PB", 0)
        AB_OVH_Pushbutton ()
        DspShow ("E1HY", "1off")
    end
end

function A33_OVH_Hyd_Y_Elec_toggle ()
    if A330 then
        if _tl("AB_VC_OVH_HYD_ELEC_Y_OFF_PB", 0) then
            A33_OVH_Hyd_Y_Elec_on ()
        else
            A33_OVH_Hyd_Y_Elec_off ()
        end
	end
end

-- ## OVH ADIRS ###############

function AB_OVH_IRS1_off ()
    ipc.writeLvar("AB_OVH_IRS1_KNOB", 0)
    AB_MPL_LightSwitch ()
    DspShow ("IRS1", "off")
end

function AB_OVH_IRS1_nav ()
    ipc.writeLvar("AB_OVH_IRS1_KNOB", 1)
    AB_MPL_LightSwitch ()
    DspShow ("IRS1", "nav")
end

function AB_OVH_IRS1_att ()
    ipc.writeLvar("AB_OVH_IRS1_KNOB", 2)
    AB_MPL_LightSwitch ()
    DspShow ("IRS1", "att")
end

function AB_OVH_IRS1_inc ()
    IRS1var = ipc.readLvar("AB_OVH_IRS1_KNOB")
    if IRS1var == 0 then AB_OVH_IRS1_nav ()
    elseif IRS1var == 1 then AB_OVH_IRS1_att ()
    end
end

function AB_OVH_IRS1_dec ()
    IRS1var = ipc.readLvar("AB_OVH_IRS1_KNOB")
    if IRS1var == 2 then AB_OVH_IRS1_nav ()
    elseif IRS1var == 1 then AB_OVH_IRS1_off ()
    end
end

function AB_OVH_IRS2_off ()
    ipc.writeLvar("AB_OVH_IRS2_KNOB", 0)
    AB_MPL_LightSwitch ()
    DspShow ("IRS2", "off")
end

function AB_OVH_IRS2_nav ()
    ipc.writeLvar("AB_OVH_IRS2_KNOB", 1)
    AB_MPL_LightSwitch ()
    DspShow ("IRS2", "nav")
end

function AB_OVH_IRS2_att ()
    ipc.writeLvar("AB_OVH_IRS2_KNOB", 2)
    AB_MPL_LightSwitch ()
    DspShow ("IRS2", "att")
end

function AB_OVH_IRS2_inc ()
    IRS2var = ipc.readLvar("AB_OVH_IRS2_KNOB")
    if IRS2var == 0 then AB_OVH_IRS2_nav ()
    elseif IRS2var == 1 then AB_OVH_IRS2_att ()
    end
end

function AB_OVH_IRS2_dec ()
    IRS2var = ipc.readLvar("AB_OVH_IRS2_KNOB")
    if IRS2var == 2 then AB_OVH_IRS2_nav ()
    elseif IRS2var == 1 then AB_OVH_IRS2_off ()
    end
end

function AB_OVH_IRS3_off ()
    ipc.writeLvar("AB_OVH_IRS3_KNOB", 0)
    AB_MPL_LightSwitch ()
    DspShow ("IRS3", "off")
end

function AB_OVH_IRS3_nav ()
    ipc.writeLvar("AB_OVH_IRS3_KNOB", 1)
    AB_MPL_LightSwitch ()
    DspShow ("IRS3", "nav")
end

function AB_OVH_IRS3_att ()
    ipc.writeLvar("AB_OVH_IRS3_KNOB", 2)
    AB_MPL_LightSwitch ()
    DspShow ("IRS3", "att")
end

function AB_OVH_IRS3_inc ()
    IRS3var = ipc.readLvar("AB_OVH_IRS3_KNOB")
    if IRS3var == 0 then AB_OVH_IRS3_nav ()
    elseif IRS3var == 1 then AB_OVH_IRS3_att ()
    end
end

function AB_OVH_IRS3_dec ()
    IRS3var = ipc.readLvar("AB_OVH_IRS3_KNOB")
    if IRS3var == 2 then AB_OVH_IRS3_nav ()
    elseif IRS3var == 1 then AB_OVH_IRS3_off ()
    end
end

function AB_OVH_IRS_ALL_off ()
    AB_OVH_IRS1_off ()
    _sleep(100,200)
    AB_OVH_IRS2_off ()
    _sleep(100,200)
    AB_OVH_IRS3_off ()
end

function AB_OVH_IRS_ALL_nav ()
    AB_OVH_IRS1_nav ()
    _sleep(100,200)
    AB_OVH_IRS2_nav ()
    _sleep(100,200)
    AB_OVH_IRS3_nav ()
end

function AB_OVH_IRS_ALL_att ()
    AB_OVH_IRS1_att ()
    _sleep(100,200)
    AB_OVH_IRS2_att ()
    _sleep(100,200)
    AB_OVH_IRS3_att ()
end

function AB_OVH_IRS_ALL_inc ()
    AB_OVH_IRS1_inc ()
    _sleep(100,200)
    AB_OVH_IRS2_inc ()
    _sleep(100,200)
    AB_OVH_IRS3_inc ()
end

function AB_OVH_IRS_ALL_dec ()
    AB_OVH_IRS1_dec ()
    _sleep(100,200)
    AB_OVH_IRS2_dec ()
    _sleep(100,200)
    AB_OVH_IRS3_dec ()
end

function AB_OVH_ADR1_Button_on ()
    ipc.writeLvar("AB_OVH_ADR1", 1)
    AB_OVH_Pushbutton ()
    DspShow ("ADR1", "on")
end

function AB_OVH_ADR1_Button_off ()
    ipc.writeLvar("AB_OVH_ADR1", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ADR1", "off")
end

function AB_OVH_ADR1_Button_toggle ()
	if _tl("AB_OVH_ADR1", 0) then
		AB_OVH_ADR1_Button_on ()
	else
		AB_OVH_ADR1_Button_off()
	end
end

function AB_OVH_ADR2_Button_on ()
    ipc.writeLvar("AB_OVH_ADR2", 1)
    AB_OVH_Pushbutton ()
    DspShow ("ADR2", "on")
end

function AB_OVH_ADR2_Button_off ()
    ipc.writeLvar("AB_OVH_ADR2", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ADR2", "off")
end

function AB_OVH_ADR2_Button_toggle ()
	if _tl("AB_OVH_ADR2", 0) then
		AB_OVH_ADR2_Button_on ()
	else
		AB_OVH_ADR2_Button_off()
	end
end

function AB_OVH_ADR3_Button_on ()
    ipc.writeLvar("AB_OVH_ADR3", 1)
    AB_OVH_Pushbutton ()
    DspShow ("ADR3", "on")
end

function AB_OVH_ADR3_Button_off ()
    ipc.writeLvar("AB_OVH_ADR3", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ADR3", "off")
end

function AB_OVH_ADR3_Button_toggle ()
	if _tl("AB_OVH_ADR3", 0) then
		AB_OVH_ADR3_Button_on ()
	else
		AB_OVH_ADR3_Button_off()
	end
end

function AB_OVH_ADR_ALL_Button_on ()
    AB_OVH_ADR1_Button_on ()
    _sleep(100,200)
    AB_OVH_ADR2_Button_on ()
    _sleep(100,200)
    AB_OVH_ADR3_Button_on ()
end

function AB_OVH_ADR_ALL_Button_off ()
    AB_OVH_ADR1_Button_off ()
    _sleep(100,200)
    AB_OVH_ADR2_Button_off ()
    _sleep(100,200)
    AB_OVH_ADR3_Button_off ()
end

function AB_OVH_ADR_ALL_Button_toggle ()
    AB_OVH_ADR1_Button_toggle ()
    _sleep(100,200)
    AB_OVH_ADR2_Button_toggle ()
    _sleep(100,200)
    AB_OVH_ADR3_Button_toggle ()
end

-- ## OVH FLT CTL ###############

function AB_OVH_ELAC1_on ()
    ipc.writeLvar("FBW_ELAC_1", 1)
    AB_OVH_Pushbutton ()
    DspShow ("ELAC", "1 on")
end

function AB_OVH_ELAC1_off ()
    ipc.writeLvar("FBW_ELAC_1", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ELAC", "1off")
end

function AB_OVH_ELAC1_toggle ()
	if _tl("FBW_ELAC_1", 0) then
		AB_OVH_ELAC1_on ()
	else
		AB_OVH_ELAC1_off()
	end
end

function AB_OVH_ELAC2_on ()
    ipc.writeLvar("FBW_ELAC_2", 1)
    AB_OVH_Pushbutton ()
    DspShow ("ELAC", "2 on")
end

function AB_OVH_ELAC2_off ()
    ipc.writeLvar("FBW_ELAC_2", 0)
    AB_OVH_Pushbutton ()
    DspShow ("ELAC", "2off")
end

function AB_OVH_ELAC2_toggle ()
	if _tl("FBW_ELAC_2", 0) then
		AB_OVH_ELAC2_on ()
	else
		AB_OVH_ELAC2_off()
	end
end

function AB_OVH_SEC1_on ()
    ipc.writeLvar("FBW_SEC_1", 1)
    AB_OVH_Pushbutton ()
    DspShow ("SEC", "1 on")
end

function AB_OVH_SEC1_off ()
    ipc.writeLvar("FBW_SEC_1", 0)
    AB_OVH_Pushbutton ()
    DspShow ("SEC", "1off")
end

function AB_OVH_SEC1_toggle ()
	if _tl("FBW_SEC_1", 0) then
		AB_OVH_SEC1_on ()
	else
		AB_OVH_SEC1_off()
	end
end

function AB_OVH_SEC2_on ()
    ipc.writeLvar("FBW_SEC_2", 1)
    AB_OVH_Pushbutton ()
    DspShow ("SEC", "2 on")
end

function AB_OVH_SEC2_off ()
    ipc.writeLvar("FBW_SEC_2", 0)
    AB_OVH_Pushbutton ()
    DspShow ("SEC", "2off")
end

function AB_OVH_SEC2_toggle ()
	if _tl("FBW_SEC_2", 0) then
		AB_OVH_SEC2_on ()
	else
		AB_OVH_SEC2_off()
	end
end

function AB_OVH_SEC3_on ()
    ipc.writeLvar("FBW_SEC_3", 1)
    AB_OVH_Pushbutton ()
    DspShow ("SEC", "3 on")
end

function AB_OVH_SEC3_off ()
    ipc.writeLvar("FBW_SEC_3", 0)
    AB_OVH_Pushbutton ()
    DspShow ("SEC", "3off")
end

function AB_OVH_SEC3_toggle ()
	if _tl("FBW_SEC_3", 0) then
		AB_OVH_SEC3_on ()
	else
		AB_OVH_SEC3_off()
	end
end

function AB_OVH_FAC1_on ()
    ipc.writeLvar("FBW_FAC_1", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FAC", "1 on")
end

function AB_OVH_FAC1_off ()
    ipc.writeLvar("FBW_FAC_1", 0)
    AB_OVH_Pushbutton ()
    DspShow ("FAC", "1off")
end

function AB_OVH_FAC1_toggle ()
	if _tl("FBW_FAC_1", 0) then
		AB_OVH_FAC1_on ()
	else
		AB_OVH_FAC1_off()
	end
end

function AB_OVH_FAC2_on ()
    ipc.writeLvar("FBW_FAC_2", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FAC", "2 on")
end

function AB_OVH_FAC2_off ()
    ipc.writeLvar("FBW_FAC_2", 0)
    AB_OVH_Pushbutton ()
    DspShow ("FAC", "2off")
end

function AB_OVH_FAC2_toggle ()
	if _tl("FBW_FAC_2", 0) then
		AB_OVH_FAC2_on ()
	else
		AB_OVH_FAC2_off()
	end
end

-- ## GWPS ###############

function AB_OVH_GPWS_TERR_on ()
    ipc.writeLvar("AB_OVH_GPWS_TERR", 1)
    AB_OVH_Pushbutton ()
    DspShow ("Terr", "on")
end

function AB_OVH_GPWS_TERR_off ()
    ipc.writeLvar("AB_OVH_GPWS_TERR", 0)
    AB_OVH_Pushbutton ()
    DspShow ("Terr", "off")
end

function AB_OVH_GPWS_TERR_toggle ()
	if _tl("AB_OVH_GPWS_TERR", 0) then
		AB_OVH_GPWS_TERR_on ()
	else
		AB_OVH_GPWS_TERR_off()
	end
end

function AB_OVH_GWPS_SYS_on ()
    ipc.writeLvar("AB_OVH_GPWS_SYS", 1)
    AB_OVH_Pushbutton ()
    DspShow ("SYS", "on")
end

function AB_OVH_GWPS_SYS_off ()
    ipc.writeLvar("AB_OVH_GPWS_SYS", 0)
    AB_OVH_Pushbutton ()
    DspShow ("SYS", "off")
end

function AB_OVH_GWPS_SYS_toggle ()
	if _tl("AB_OVH_GPWS_SYS", 0) then
		AB_OVH_GWPS_SYS_on ()
	else
		AB_OVH_GWPS_SYS_off()
	end
end

function AB_OVH_GWPS_GSMODE_on ()
    ipc.writeLvar("AB_OVH_GPWS_GSMODE", 1)
    AB_OVH_Pushbutton ()
    DspShow ("GSMD", "on")
end

function AB_OVH_GWPS_GSMODE_off ()
    ipc.writeLvar("AB_OVH_GPWS_GSMODE", 0)
    AB_OVH_Pushbutton ()
    DspShow ("GSMD", "off")
end

function AB_OVH_GWPS_GSMODE_toggle ()
	if _tl("AB_OVH_GPWS_GSMODE", 0) then
		AB_OVH_GWPS_GSMODE_on ()
	else
		AB_OVH_GWPS_GSMODE_off()
	end
end

function AB_OVH_GPWS_FLAPMODE_on ()
    ipc.writeLvar("AB_OVH_GPWS_FLAPMODE", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FLPM", "on")
end

function AB_OVH_GPWS_FLAPMODE_off ()

    ipc.writeLvar("AB_OVH_GPWS_FLAPMODE", 0)
    AB_OVH_Pushbutton ()
    DspShow ("FLPM", "off")
end

function AB_OVH_GPWS_FLAPMODE_toggle ()
	if _tl("AB_OVH_GPWS_FLAPMODE", 0) then
		AB_OVH_GPWS_FLAPMODE_on ()
	else
		AB_OVH_GPWS_FLAPMODE_off()
	end
end

function AB_OVH_GPWS_LDGFLAP3_on ()
    ipc.writeLvar("AB_OVH_GPWS_LDGFLAP3", 1)
    AB_OVH_Pushbutton ()
    DspShow ("LDGF", "on")
end

function AB_OVH_GPWS_LDGFLAP3_off ()
    ipc.writeLvar("AB_OVH_GPWS_LDGFLAP3", 0)
    AB_OVH_Pushbutton ()
    DspShow ("LDGF", "off")
end

function AB_OVH_GPWS_LDGFLAP3_toggle ()
	if _tl("AB_OVH_GPWS_LDGFLAP3", 0) then
		AB_OVH_GPWS_LDGFLAP3_on ()
	else
		AB_OVH_GPWS_LDGFLAP3_off()
	end
end

-- ## OVH RCDR ###############

function AB_OVH_FLTRCD_button_on ()
    ipc.writeLvar("AB_OVH_FLTRCD_button", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FREC", "on")
end

function AB_OVH_FLTRCD_button_off ()
    ipc.writeLvar("AB_OVH_FLTRCD_button", 0)
    AB_OVH_Pushbutton ()
    DspShow ("FREC", "off")
end

function AB_OVH_FLTRCD_button_toggle ()
	if _tl("AB_OVH_FLTRCD_button", 0) then
		AB_OVH_FLTRCD_button_on ()
	else
		AB_OVH_FLTRCD_button_off()
	end
end

function AB_OVH_FLTRCD_erase ()
    ipc.writeLvar("AB_OVH_FLTRCD_erase", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FREC", "del")
end

function AB_OVH_FLTRCD_test ()
    ipc.writeLvar("AB_OVH_FLTRCD_test", 1)
    AB_OVH_Pushbutton ()
    DspShow ("FREC", "test")
end


-- ## Other Overhead ###############

function AB_OVH_WiperL_slow ()
    ipc.writeLvar("AB_OVH_WIPERL_KNOB", 1)
    ipc.writeLvar("AB_wiperL", 1)
    AB_MPL_KnobRotate ()
    DspShow ("WipL", "slow")
end

function AB_OVH_WiperL_fast ()
    ipc.writeLvar("AB_OVH_WIPERL_KNOB", 2)
    ipc.writeLvar("AB_wiperL", 2)
    AB_MPL_KnobRotate ()
    DspShow ("WipL", "fast")
end

function AB_OVH_WiperL_off ()
    ipc.writeLvar("AB_OVH_WIPERL_KNOB", 0)
    ipc.writeLvar("AB_wiperL", 0)
    AB_MPL_KnobRotate ()
    DspShow ("WipL", "off")
end

function AB_OVH_WiperR_slow ()
    ipc.writeLvar("AB_OVH_WIPERR_KNOB", 1)
    ipc.writeLvar("AB_wiperR", 1)
    AB_MPL_KnobRotate ()
    DspShow ("WipR", "slow")
end

function AB_OVH_WiperR_fast ()
    ipc.writeLvar("AB_OVH_WIPERR_KNOB", 2)
    ipc.writeLvar("AB_wiperR", 2)
    AB_MPL_KnobRotate ()
    DspShow ("WipR", "fast")
end

function AB_OVH_WiperR_off ()
    ipc.writeLvar("AB_OVH_WIPERR_KNOB", 0)
    ipc.writeLvar("AB_wiperR", 0)
    AB_MPL_KnobRotate ()
    DspShow ("WipR", "off")
end

function AB_OVH_WiperL_inc ()
    WipL = ipc.readLvar("AB_OVH_WIPERL_KNOB")
    if WipL == 0 then
    AB_OVH_WiperL_slow ()
    elseif WipL == 1 then
    AB_OVH_WiperL_fast ()
    end
end

function AB_OVH_WiperL_dec ()
    WipL = ipc.readLvar("AB_OVH_WIPERL_KNOB")
    if WipL == 2 then
    AB_OVH_WiperL_slow ()
    elseif WipL == 1 then
    AB_OVH_WiperL_off ()
    end
end

function AB_OVH_WiperR_inc ()
    WipR = ipc.readLvar("AB_OVH_WIPERR_KNOB")
    if WipR == 0 then
    AB_OVH_WiperR_slow ()
    elseif WipR == 1 then
    AB_OVH_WiperR_fast ()
    end
end

function AB_OVH_WiperR_dec ()
    WipR = ipc.readLvar("AB_OVH_WIPERR_KNOB")
    if WipR == 2 then
    AB_OVH_WiperR_slow ()
    elseif WipR == 1 then
    AB_OVH_WiperR_off ()
    end
end

function AB_OVH_Wiper_both_slow ()
    AB_OVH_WiperL_slow ()
    _sleep(300,600)
    AB_OVH_WiperR_slow ()
end

function AB_OVH_Wiper_both_fast ()
    AB_OVH_WiperL_fast ()
    _sleep(300,600)
    AB_OVH_WiperR_fast ()
end

function AB_OVH_Wiper_both_off ()
    AB_OVH_WiperL_off ()
    _sleep(300,500)
    AB_OVH_WiperR_off ()
end

function AB_OVH_Wiper_both_inc ()
    AB_OVH_WiperL_inc ()
    _sleep(100,200)
    AB_OVH_WiperR_inc ()
end

function AB_OVH_Wiper_both_dec ()
    AB_OVH_WiperL_dec ()
    _sleep(100,200)
    AB_OVH_WiperR_dec ()
end


-- ## MCDU LEFT ###############

-- $$ Keyboard Input

function AB_PED_MCDU_KEYB_on ()
    ipc.writeLvar("MCDU_KBD", 1)
    _sleep(50)
    ipc.set("MCDU", ipc.elapsedtime())
    AB_PED_MCDU_Key_Flag = true
    DspShow("MCDU","KOn")
end

function AB_PED_MCDU_KEYB_off()
    ipc.writeLvar("MCDU_KBD", 0)
    _sleep(50)
    AB_PED_MCDU_Key_Flag = false
    DspShow("MCDU","KOff")
end

function AB_PED_MCDU_KEYB_toggle()
    if ipc.readLvar("MCDU_KBD") == 1 then
        AB_PED_MCDU_KEYB_off()
    else
        AB_PED_MCDU_KEYB_on()
    end
end

-- $$ MCDU L buttons

function AB_PED_MCDU1_LSK1L ()
    ipc.writeLvar("MCDU_LSK1L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK2L ()
    ipc.writeLvar("MCDU_LSK2L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK3L ()
    ipc.writeLvar("MCDU_LSK3L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK4L ()
    ipc.writeLvar("MCDU_LSK4L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK5L ()
    ipc.writeLvar("MCDU_LSK5L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK6L ()
    ipc.writeLvar("MCDU_LSK6L", 1)
    AB_PED_MCDU_CLICK ()
end

-------

function AB_PED_MCDU1_LSK1R ()
    ipc.writeLvar("MCDU_LSK1R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK2R ()
    ipc.writeLvar("MCDU_LSK2R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK3R ()
    ipc.writeLvar("MCDU_LSK3R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK4R ()
    ipc.writeLvar("MCDU_LSK4R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK5R ()
    ipc.writeLvar("MCDU_LSK5R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_LSK6R ()
    ipc.writeLvar("MCDU_LSK6R", 1)
    AB_PED_MCDU_CLICK ()
end

-----

function AB_PED_MCDU1_DIR_key ()
    ipc.writeLvar("MCDU1_DIR_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_PROG_key ()
    ipc.writeLvar("MCDU1_PROG_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_PERF_key ()
    ipc.writeLvar("MCDU1_PERF_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_INIT_key ()
    ipc.writeLvar("MCDU1_INIT_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_DATA_key ()
    ipc.writeLvar("MCDU1_DATA_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_FPLN_key ()
    ipc.writeLvar("MCDU1_FPLN_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_RAD_key ()
    ipc.writeLvar("MCDU1_RAD_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_FUEL_key ()
    ipc.writeLvar("MCDU1_FUEL_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_SPLN_key ()
    ipc.writeLvar("MCDU1_SPLN_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_ATC_key ()
    ipc.writeLvar("MCDU1_ATC_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_MENU_key ()
    ipc.writeLvar("MCDU1_MENU_key", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_ARPRT_key ()
    ipc.writeLvar("MCDU1_ARPRT_key", 1)
    AB_PED_MCDU_CLICK ()
end

----------

function AB_PED_MCDU1_arrowdn ()
    ipc.writeLvar("MCDU_arrowdn", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_arrowleft ()
    ipc.writeLvar("MCDU_arrowleft", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_arrowright ()
    ipc.writeLvar("MCDU_arrowright", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_arrowup ()
    ipc.writeLvar("MCDU_arrowup", 1)
    AB_PED_MCDU_CLICK ()
end

-- ## MCDU L Keys

function AB_PED_MCDU1_0 ()
    ipc.writeLvar("MCDU_0", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_1 ()
    ipc.writeLvar("MCDU_1", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_2 ()
    ipc.writeLvar("MCDU_2", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_3 ()
    ipc.writeLvar("MCDU_3", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_4 ()
    ipc.writeLvar("MCDU_4", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_5 ()
    ipc.writeLvar("MCDU_5", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_6 ()
    ipc.writeLvar("MCDU_6", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_7 ()
    ipc.writeLvar("MCDU_7", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_8 ()
    ipc.writeLvar("MCDU_8", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_9 ()
    ipc.writeLvar("MCDU_9", 1)
    AB_PED_MCDU_CLICK ()
end

-----------------

function AB_PED_MCDU1_A ()
    ipc.writeLvar("MCDU_A", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_B ()
    ipc.writeLvar("MCDU_B", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_C ()
    ipc.writeLvar("MCDU_C", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_D ()
    ipc.writeLvar("MCDU_D", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_E ()
    ipc.writeLvar("MCDU_E", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_F ()
    ipc.writeLvar("MCDU_F", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_G ()
    ipc.writeLvar("MCDU_G", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_H ()
    ipc.writeLvar("MCDU_H", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_I ()
    ipc.writeLvar("MCDU_I", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_J ()
    ipc.writeLvar("MCDU_J", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_K ()
    ipc.writeLvar("MCDU_K", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_L ()
    ipc.writeLvar("MCDU_L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_M ()
    ipc.writeLvar("MCDU_M", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_N ()
    ipc.writeLvar("MCDU_N", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_O ()
    ipc.writeLvar("MCDU_O", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_P ()
    ipc.writeLvar("MCDU_P", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_Q ()
    ipc.writeLvar("MCDU_Q", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_R ()
    ipc.writeLvar("MCDU_R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_S ()
    ipc.writeLvar("MCDU_S", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_T ()
    ipc.writeLvar("MCDU_T", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_U ()
    ipc.writeLvar("MCDU_U", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_V ()
    ipc.writeLvar("MCDU_V", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_W ()
    ipc.writeLvar("MCDU_W", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_X ()
    ipc.writeLvar("MCDU_X", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_Y ()
    ipc.writeLvar("MCDU_Y", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_Z ()
    ipc.writeLvar("MCDU_Z", 1)
    AB_PED_MCDU_CLICK ()
end

----

function AB_PED_MCDU1_SP ()
    ipc.writeLvar("MCDU_SP", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_OVFLY ()
    ipc.writeLvar("MCDU_OVFLY", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_CLR ()
    ipc.writeLvar("MCDU_CLR", 1)
    AB_PED_MCDU_CLICK ()
end


function AB_PED_MCDU1_SLASH ()
    ipc.writeLvar("MCDU_SL", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_PLUSMINUS ()
    ipc.writeLvar("MCDU_SGN", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_POINT ()
    ipc.writeLvar("MCDU_ST", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_BRT ()
    ipc.writeLvar("MCDU_BRT", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU1_DIM ()
    ipc.writeLvar("MCDU_DIM", 1)
    AB_PED_MCDU_CLICK ()
end

-- ## MCDU right ###############

function AB_PED_MCDU2_LSK1L ()
    ipc.writeLvar("AB_MCDU2_LSK1L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK2L ()
    ipc.writeLvar("AB_MCDU2_LSK2L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK3L ()
    ipc.writeLvar("AB_MCDU2_LSK3L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK4L ()
    ipc.writeLvar("AB_MCDU2_LSK4L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK5L ()
    ipc.writeLvar("AB_MCDU2_LSK5L", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK6L ()
    ipc.writeLvar("AB_MCDU2_LSK6L", 1)
    AB_PED_MCDU_CLICK ()
end

-------

function AB_PED_MCDU2_LSK1R ()
    ipc.writeLvar("AB_MCDU2_LSK1R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK2R ()
    ipc.writeLvar("AB_MCDU2_LSK2R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK3R ()
    ipc.writeLvar("AB_MCDU2_LSK3R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK4R ()
    ipc.writeLvar("AB_MCDU2_LSK4R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK5R ()
    ipc.writeLvar("AB_MCDU2_LSK5R", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_LSK6R ()
    ipc.writeLvar("AB_MCDU2_LSK6R", 1)
    AB_PED_MCDU_CLICK ()
end

-----

function AB_PED_MCDU2_arrowleft ()
    ipc.writeLvar("MCDU2_arrowleft", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_arrowright ()
    ipc.writeLvar("MCDU2_arrowright", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_BRT ()
    ipc.writeLvar("MCDU2_BRT", 1)
    AB_PED_MCDU_CLICK ()
end

function AB_PED_MCDU2_DIM ()
    ipc.writeLvar("MCDU2_DIM", 1)
    AB_PED_MCDU_CLICK ()
end

-- ## ECAM Buttons ############

function AB_ECAM_ENG ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 1 then
        ipc.writeLvar("ECAM_Mode", 1)
        ipc.writeLvar("LowECAM_Page", 1)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "ENG ")
end

function AB_ECAM_BLEED ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 2 then
        ipc.writeLvar("ECAM_Mode", 2)
        ipc.writeLvar("LowECAM_Page", 2)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "BLED")
end

function AB_ECAM_PRESS ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 3 then
        ipc.writeLvar("ECAM_Mode", 3)
        ipc.writeLvar("LowECAM_Page", 3)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "PRES")
end

function AB_ECAM_ELEC ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 4 then
        ipc.writeLvar("ECAM_Mode", 4)
        ipc.writeLvar("LowECAM_Page", 4)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "ELEC")
end

function A33_ECAM_ELAC ()
    if A330 then
        EcamVar = ipc.readLvar("ECAM_Mode")
        if EcamVar ~= 4 then
            ipc.writeLvar("ECAM_Mode", 4)
            ipc.writeLvar("LowECAM_Page", 4)
        else
            ipc.writeLvar("ECAM_Mode", 0)
        end
        AB_OVH_Pushbutton ()
	   DspShow("ECAM", "ELAC")
    end
end

function A33_ECAM_ELDC ()
    if A330 then
        EcamVar = ipc.readLvar("ECAM_Mode")
        if EcamVar ~= 5 then
            ipc.writeLvar("ECAM_Mode", 5)
            ipc.writeLvar("LowECAM_Page", 5)
        else
            ipc.writeLvar("ECAM_Mode", 0)
        end
        AB_OVH_Pushbutton ()
	   DspShow("ECAM", "ELDC")
    end
end

function AB_ECAM_HYD ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 6
    else
        val = 5
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "HYD ")
end

function A33_ECAM_CB ()
    if A330 then
        EcamVar = ipc.readLvar("ECAM_Mode")
        if EcamVar ~= 7 then
            ipc.writeLvar("ECAM_Mode", 7)
            ipc.writeLvar("LowECAM_Page", 7)
        else
            ipc.writeLvar("ECAM_Mode", 0)
        end
        AB_OVH_Pushbutton ()
	   DspShow("ECAM", "C/B")
    end
end

function AB_ECAM_FUEL ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 13
    else
        val = 6
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "FUEL")
end

function AB_ECAM_APU ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 8
    else
        val = 7
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "APU ")
end

function AB_ECAM_COND ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 9
    else
        val = 8
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "COND")
end

function AB_ECAM_DOOR ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 10
    else
        val = 9
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "DOOR")
end

function AB_ECAM_WHEEL ()
    if A330 then
        val = 11
    else
        val = 10
    end
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "WHEL")
end

function AB_ECAM_FCTL ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 12
    else
        val = 11
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "FCTL")
end

function AB_ECAM_STS ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        val = 14
    else
        val = 13
    end
    if EcamVar ~= val then
        ipc.writeLvar("ECAM_Mode", val)
        ipc.writeLvar("LowECAM_Page", val)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "STS ")
end

function AB_ECAM_NONE ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 0 then
        ipc.writeLvar("ECAM_Mode", 0)
    end
    AB_OVH_Pushbutton ()
	DspShow("ECAM", "None")
end

function AB_ECAM_MODE_next ()
	EcamVar = ipc.readLvar("ECAM_Mode")
    if A330 then
        maxval = 14
    else
        maxval = 13
    end
    if (EcamVar > maxval or EcamVar == 0) then AB_ECAM_ENG ()
    elseif EcamVar == 1 then AB_ECAM_BLEED ()
    elseif EcamVar == 2 then AB_ECAM_PRESS ()
    elseif EcamVar == 3 then
        if A330 then
            A33_ECAM_ELAC ()
        else
            AB_ECAM_ELEC ()
        end
    elseif EcamVar == 4 then
        if A330 then
            A33_ECAM_ELDC ()
        else
            AB_ECAM_HYD ()
        end
    elseif EcamVar == 5 then
        if A330 then
            AB_ECAM_HYD ()
        else
            AB_ECAM_FUEL ()
        end
    elseif EcamVar == 6 then
        if A330 then
            A33_ECAM_CB ()
        else
            AB_ECAM_APU ()
        end
    elseif EcamVar == 7 then
        if A330 then
            AB_ECAM_APU ()
        else
            AB_ECAM_COND ()
        end
    elseif EcamVar == 8 then
        if A330 then
            AB_ECAM_COND ()
        else
            AB_ECAM_DOOR ()
        end
    elseif EcamVar == 9 then
        if A330 then
            AB_ECAM_DOOR ()
        else
            AB_ECAM_WHEEL ()
        end
    elseif EcamVar == 10 then
        if A330 then
            AB_ECAM_WHEEL ()
        else
            AB_ECAM_FCTL ()
        end
    elseif EcamVar == 11 then
        if A330 then
            AB_ECAM_FCTL ()
        else
            AB_ECAM_STS ()
        end
    elseif EcamVar == 12 then
        if A330 then
            AB_ECAM_FUEL ()
        else
            AB_ECAM_NONE ()
        end
    elseif EcamVar == 13 then
        if A330 then
            AB_ECAM_STS ()
        else
            AB_ECAM_NONE ()
        end
    elseif EcamVar == 14 then AB_ECAM_NONE ()
    end
    AB_ECAM_modes_show ()
end

function AB_ECAM_MODE_prev ()
	EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar == 2 then AB_ECAM_ENG ()
    elseif EcamVar == 3 then AB_ECAM_BLEED ()
    elseif EcamVar == 4 then AB_ECAM_PRESS ()
    elseif EcamVar == 5 then
        if A330 then
            A33_ECAM_ELAC ()
        else
            AB_ECAM_ELEC ()
        end
    elseif EcamVar == 6 then
        if A330 then
            A33_ECAM_ELDC ()
        else
            AB_ECAM_HYD ()
        end
    elseif EcamVar == 7 then
        if A330 then
            AB_ECAM_HYD ()
        else
            AB_ECAM_FUEL ()
        end
    elseif EcamVar == 8 then
        if A330 then
            A33_ECAM_CB ()
        else
            AB_ECAM_APU ()
        end
    elseif EcamVar == 9 then
        if A330 then
            AB_ECAM_APU ()
        else
            AB_ECAM_COND ()
        end
    elseif EcamVar == 10 then
        if A330 then
            AB_ECAM_COND ()
        else
            AB_ECAM_DOOR ()
        end
    elseif EcamVar == 11 then
        if A330 then
            AB_ECAM_DOOR ()
        else
            AB_ECAM_WHEEL ()
        end
    elseif EcamVar == 12 then
        if A330 then
            AB_ECAM_WHEEL ()
        else
            AB_ECAM_STS ()
        end
    elseif EcamVar == 13 then
        AB_ECAM_FCTL ()
    elseif EcamVar == 14 then
        if A330 then
            AB_ECAM_FUEL ()
        end
    elseif EcamVar == 0 then
        AB_ECAM_STS ()
    elseif EcamVar == 1 then
         AB_ECAM_NONE ()
    end
    AB_ECAM_modes_show ()
end

function AB_ECAM_ALL ()
    if not A330 then
   Lvar = "ECAM_Mode"
        ipc.writeLvar(Lvar, 12)
        AB_OVH_Pushbutton ()
        DspShow ("ECAM", "ALL ")
    end
end

function AB_ECAM_CLR ()
   Lvar = "AB_ECAM_CLR"
    ipc.writeLvar(Lvar, 1)
    AB_OVH_Pushbutton ()
    DspShow ("ECAM", "CLR ")
end

function AB_ECAM_RCL ()
   Lvar = "AB_ECAM_RCL"
    ipc.writeLvar(Lvar, 1)
    _sleep(50)
    ipc.writeLvar(Lvar, 0)
    AB_OVH_Pushbutton ()
    DspShow ("ECAM", "RCL ")
end

function AB_ECAM_TO_CONFIG ()
    ipc.writeLvar("AB_ECAM_TOCFG", 1)
	ipc.writeLvar("AB_ECAM_TOconf", 1)
	ipc.writeLvar("AB_ECAM_TOconf_Hasbeentested", 1)
	ipc.writeLvar("AB_ECAM_RCL", 1)
	DspShow ("ECAM", "T/O ")
    AB_OVH_Pushbutton ()
 end


-- ## Engine Management ###################################

function AB_PED_Engine1_MASTER_on ()
   Lvar = "AB_PDS_Eng1Master"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("ENG1", "on")
end

function AB_PED_Engine1_MASTER_off ()
   Lvar = "AB_PDS_Eng1Master"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("ENG1", "off")
end

function AB_PED_Engine1_MASTER_toggle ()
	if _tl("AB_PDS_Eng1Master", 0) then
		AB_PED_Engine1_MASTER_on ()
	else
		AB_PED_Engine1_MASTER_off ()
	end
end

function AB_PED_Engine2_MASTER_on ()
   Lvar = "AB_PDS_Eng2Master"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("ENG2", "on")
end

function AB_PED_Engine2_MASTER_off ()
   Lvar = "AB_PDS_Eng2Master"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("ENG2", "off")
end

function AB_PED_Engine2_MASTER_toggle ()
	if _tl("AB_PDS_Eng2Master", 0) then
		AB_PED_Engine2_MASTER_on ()
	else
		AB_PED_Engine2_MASTER_off ()
	end
end

function AB_PED_Ignition_inc ()
   Lvar = "AB_PDS_ignition"
    var = ipc.readLvar(Lvar)
    if (var < 2) then
        var = var + 1
        ipc.writeLvar(Lvar, var)
    end
end

function AB_PED_Ignition_dec ()
   Lvar = "AB_PDS_ignition"
    var = ipc.readLvar(Lvar)
    if (var > 0) then
        var = var - 1
        ipc.writeLvar(Lvar, var)
    end
end

function AB_PED_Ignition_start ()
   Lvar = "AB_PDS_ignition"
    ipc.writeLvar(Lvar, 2)
    AB_MPL_LightSwitch ()
    DspShow ("IGN", "start")
end

function AB_PED_Ignition_norm ()
   Lvar = "AB_PDS_ignition"
    ipc.writeLvar(Lvar, 1)
    AB_MPL_LightSwitch ()
    DspShow ("IGN", "norm")
end

function AB_PED_Ignition_crank ()
   Lvar = "AB_PDS_ignition"
    ipc.writeLvar(Lvar, 0)
    AB_MPL_LightSwitch ()
    DspShow ("IGN", "crnk")
end

function AB_PED_Ignition_toggle ()
	if _tl("AB_PDS_ignition", 1) then
       AB_PED_Ignition_start ()
	else
       AB_PED_Ignition_norm ()
	end
end

function AB_PED_ThrustReverse_1 ()
local i, epr
    _loggg('[AB] RevL=' .. ipc.readLvar("AS_FADEC_0"))
    i = 100 --0000
    epr = ipc.readLvar("TURB ENG1 EPR")
    while (epr > 1.09) and (i > 0) do
        epr = ipc.readLvar("TURB ENG1 EPR")
        i = i - 1
    end
    _loggg('[awg] L Eng exit while epr '.. tostring(epr) .. '-' .. tostring(i))
    ipc.writeLvar("AS_FADEC_0", 32506)
    for i = 1, 16 do
        ipc.control(65966, 0)
    end
end

function AB_PED_ThrustReverse_2 ()
local i, epr
    _loggg('[AB] RevR=' .. ipc.readLvar("AS_FADEC_1"))
    i = 100 --0000
    epr = ipc.readLvar("TURB ENG2 EPR")
    while (epr > 1.09) and (i > 0) do
        epr = ipc.readLvar("TURB ENG2 EPR")
        i = i - 1
    end
    _loggg('[awg] R Eng exit while epr '.. tostring(epr) .. '-' .. tostring(i))
    ipc.writeLvar("AS_FADEC_1", 32506)
    for i = 1, 16 do
        ipc.control(65966, 0)
    end
end

-- ## Rudder Trim ###############

function AB_Rudder_Trim_show ()
    RuddVal = ipc.readUW(0x0C04)
    if RuddVal >= 49000 then
    RuddVal = (RuddVal - 65487)
    end

    RuddTrimVar = round2((RuddVal*0.006103515625)/5, 1)

    if RuddTrimVar > 0 then
    DirTxt = "R"
    RudTrimTxt = RuddTrimVar
    elseif RuddTrimVar < 0 then
    DirTxt = "L"
    RudTrimTxt = RuddTrimVar*-1
    elseif RuddTrimVar == 0 then
    DirTxt = " "
    end
    DspShow(DirTxt.."Rud", RudTrimTxt)
end

function AB_RudderTrim_R ()
    ipc.writeLvar("Ruddertrimknob", 1)
    ipc.control(66279)
    _sleep(50)
    AB_Rudder_Trim_show ()
end

function AB_RudderTrim_stop ()
    ipc.writeLvar("Ruddertrimknob", 0)
    AB_Rudder_Trim_show ()
end

function AB_RudderTrim_L ()
    ipc.writeLvar("Ruddertrimknob", -1)
    ipc.control(66278)
    _sleep(50)
    AB_Rudder_Trim_show ()
end

function AB_Rudder_reset ()
    ipc.writeLvar("AB_RUDDERTRIM_Neutral_button", 1)
    AB_OVH_Pushbutton ()
end

-- ## RADIO CRS/DME ###############

function AB_ILS_test ()
    local ILS_freq = ipc.readLvar("MCDU_ILS1")
    local ILS_crs = ipc.readLvar("MCDU_ILS1_CRS")
    local ILS_disp = ipc.readLvar("AB_MPL_ILS")
    local ILS_name = string.format("%s", ipc.readSTR(0x3000, 5))
    local VOR1_freq = ipc.readLvar("MCDU_VOR1")
    local VOR1_crs = ipc.readLvar("MCDU_VOR1_CRS")
    local VOR2_freq = ipc.readLvar("MCDU_VOR2")
    local VOR2_crs = ipc.readLvar("MCDU_VOR2_CRS")
    _log ('[awg] ILS disp  = ' .. ILS_disp)
    _log ('[awg] ILS crs   = ' .. ILS_crs)
    _log ('[awg] ILS freq  = ' .. ILS_freq)
    _log ('[awg] ILS name  = ' .. ILS_name)
    _log ('[awg] VOR1 crs  = ' .. VOR1_crs)
    _log ('[awg] VOR1 freq = ' .. VOR1_freq)
    _log ('[awg] VOR2 crs  = ' .. VOR2_crs)
    _log ('[awg] VOR2 freq = ' .. VOR2_freq)
    Default_DME_ILS()
end

function AB_AP_ILS1_set ()
    ipc.writeLvar("MCDU_ILS1_CRS", CRS1)
    _logg('[awg] ILS CRS set = ' .. CRS1)
    if _MCP1()  then
        DspShow("ILS1", CRS1)
    else
        DspCRS(CRS1)
    end
end

function AB_AP_CRS1_set ()
    ipc.writeLvar("MCDU_VOR1_CRS", CRS1)
    _logg('[awg] DME1 set = ' .. CRS1)
    if _MCP1()  then
        DspShow("CRS1", CRS1)
    else
        DspCRS(CRS1)
    end
end

function AB_AP_CRS2_set ()
    ipc.writeLvar("MCDU_VOR2_CRS", CRS2)
    _logg('[awg] DME2 CRS2 set = ' .. CRS2)
    if _MCP1()  then
        DspShow("CRS2", CRS2)
    else
        DspCRS(CRS2)
    end
end

function AB_AP_CRS_show ()
    local DME_crs
    if dme_sel then
        DME_crs = ipc.readLvar("MCDU_ILS1_CRS")
        _logg('[awg] ILS CRS Show = ' .. DME_crs)
    else
        DME_crs = ipc.readLvar("MCDU_VOR1_CRS")
        _logg('[awg] VOR1 CRS Show = ' .. DME_crs)
    end
    if DME_crs ~= -1 then
        if _MCP1()  then
            DspShow("CRS1", DME_crs)
        else
            DspCRS(DME_crs)
        end
    else
        DME_crs = 0
        if _MCP1()  then
            DspShow("CRS2", DME_crs)
        else
            DspDME(DME_crs)
        end
    end
end

function AB_AP_CRS_inc ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("MCDU_ILS1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("MCDU_VOR1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    end
end

function AB_AP_CRS_incfast ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("MCDU_ILS1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("MCDU_VOR1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    end
end

function AB_AP_CRS_dec ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("MCDU_ILS1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("MCDU_VOR1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    end
end

function AB_AP_CRS_decfast ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("MCDU_ILS1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("MCDU_VOR1_CRS", DME_crs)
        _sleep(50)
        --AB_AP_CRS_show ()
    end
end

-- ## TCAS/XPDR ###############

-- $$ Ident

function AB_PDS_XPDR_Ident ()
    ipc.writeLvar('Mod_Xponder_IDENT', 1)
    ipc.writeSB(0x7b93,1)
    AB_MPL_Knobclick()
    _sleep(100)
    ipc.writeLvar('Mod_Xponder_IDENT', 0)
    ipc.writeSB(0x7b93,0)
    DspShow("XPDR","ID")
end

-- $$ Mode C

function AB_PDS_XPDR_ModeC_on ()
    AB_PDS_XPDR_STBY_auto()
    AB_PDS_XPDR_RPTG_on()
    AB_PDS_XPDR_THRT_thrt()
    AB_PDS_XPDR_MODE_tara()
end

-- $$ XPDR Stby/auto/on

function AB_PDS_XPDR_STBY_show ()
local XPDRvar = ipc.readLvar("AB_PDS_XPDR_STBY_AUTO_ON")
    if XPDRvar == 0 then
        XPDRtext = "stby"
    elseif XPDRvar == 1 then
        XPDRtext = "auto"
    elseif XPDRvar == 2 then
        XPDRtext = "on"
    end
    if _MCP1() then
        DspShow("XPDR", XPDRtext)
    elseif _MCP2() then
        DspRadioShort(XPDRtext)
    elseif _MCP2a() then
        DspShow("XPDR", XPDRtext)
    end
end

function AB_PDS_XPDR_STBY_inc ()
Lvar = 'AB_PDS_XPDR_STBY_AUTO_ON'
	i = ipc.readLvar(Lvar)
	if i < 3 then
	   ipc.writeLvar(Lvar, i + 1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_STBY_show ()
end

function AB_PDS_XPDR_STBY_dec ()
Lvar = 'AB_PDS_XPDR_STBY_AUTO_ON'
	i = ipc.readLvar(Lvar)
 	if i > 0 then
	   ipc.writeLvar(Lvar, i-1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_STBY_show ()
end

function AB_PDS_XPDR_STBY_stby ()
Lvar = 'AB_PDS_XPDR_STBY_AUTO_ON'
    ipc.writeLvar(Lvar, 0)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_STBY_show ()
end

function AB_PDS_XPDR_STBY_auto ()
Lvar = 'AB_PDS_XPDR_STBY_AUTO_ON'
    ipc.writeLvar(Lvar, 1)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_STBY_show ()
end

function AB_PDS_XPDR_STBY_on ()
Lvar = 'AB_PDS_XPDR_STBY_AUTO_ON'
    ipc.writeLvar(Lvar, 2)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_STBY_show ()
end

function AB_PDS_XPDR_STBY_cycle ()
Lvar = 'AB_PDS_XPDR_STBY_AUTO_ON'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 2 then
        AB_PDS_XPDR_STBY_inc ()
    else
        AB_PDS_XPDR_STBY_stby()
    end
end

-- $$ XPDR 1/2

function AB_PDS_XPDR_SYS_show ()
local XPDRvar = ipc.readLvar("AB_PDS_XPDR_SYS1_SYS2")
    if XPDRvar == 0 then
        XPDRtext = "1"
    elseif XPDRvar == 1 then
        XPDRtext = "2"
    end
    if _MCP1() then
        DspShow("XSYS", XPDRtext)
    elseif _MCP2() then
        DspRadioShort(XPDRtext)
    elseif _MCP2a() then
        DspShow("XSYS", XPDRtext)
    end
end

function AB_PDS_XPDR_SYS_inc ()
Lvar = 'AB_PDS_XPDR_SYS1_SYS2'
	i = ipc.readLvar(Lvar)
	if i < 1 then
	   ipc.writeLvar(Lvar, i + 1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_SYS_show ()
end

function AB_PDS_XPDR_SYS_dec ()
Lvar = 'AB_PDS_XPDR_SYS1_SYS2'
	i = ipc.readLvar(Lvar)
 	if i > 0 then
	   ipc.writeLvar(Lvar, i-1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_SYS_show ()
end

function AB_PDS_XPDR_SYS_1 ()
Lvar = 'AB_PDS_XPDR_SYS1_SYS2'
    ipc.writeLvar(Lvar, 0)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_SYS_show ()
end

function AB_PDS_XPDR_SYS_2 ()
Lvar = 'AB_PDS_XPDR_SYS1_SYS2'
    ipc.writeLvar(Lvar, 1)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_SYS_show ()
end

function AB_PDS_XPDR_SYS_toggle ()
Lvar = 'AB_PDS_XPDR_SYS1_SYS2'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 1 then
        AB_PDS_XPDR_SYS_2()
    else
        AB_PDS_XPDR_SYS_1()
    end
end

-- $$ XPDR RPTG

function AB_PDS_XPDR_RPTG_show ()
local XPDRvar = ipc.readLvar("AB_PDS_XPDR_ALT_RPTG")
    if XPDRvar == 0 then
        XPDRtext = "off"
    elseif XPDRvar == 1 then
        XPDRtext = "on"
    end
    if _MCP1() then
        DspShow("RPTG", XPDRtext)
    elseif _MCP2() then
        DspRadioShort(XPDRtext)
    elseif _MCP2a() then
        DspShow("RPTG", XPDRtext)
    end
end

function AB_PDS_XPDR_RPTG_inc ()
Lvar = 'AB_PDS_XPDR_ALT_RPTG'
	i = ipc.readLvar(Lvar)
	if i < 1 then
	   ipc.writeLvar(Lvar, i + 1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_RPTG_show ()
end

function AB_PDS_XPDR_RPTG_dec ()
Lvar = 'AB_PDS_XPDR_ALT_RPTG'
	i = ipc.readLvar(Lvar)
 	if i > 0 then
	   ipc.writeLvar(Lvar, i-1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_RPTG_show ()
end

function AB_PDS_XPDR_RPTG_off ()
Lvar = 'AB_PDS_XPDR_ALT_RPTG'
    ipc.writeLvar(Lvar, 0)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_RPTG_show ()
end

function AB_PDS_XPDR_RPTG_on ()
Lvar = 'AB_PDS_XPDR_ALT_RPTG'
    ipc.writeLvar(Lvar, 1)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_RPTG_show ()
end

function AB_PDS_XPDR_RPTG_toggle ()
Lvar = 'AB_PDS_XPDR_ALT_RPTG'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 1 then
        AB_PDS_XPDR_RPTG_on()
    else
        AB_PDS_XPDR_RPTG_off()
    end
end

-- $$ XPDR Threat

function AB_PDS_XPDR_THRT_show ()
local XPDRvar = ipc.readLvar("AB_PDS_XPDR_THRT_ALL_ABV_BLW")
    if XPDRvar == 0 then
        XPDRtext = "thrt"
    elseif XPDRvar == 1 then
        XPDRtext = "all"
    elseif XPDRvar == 2 then
        XPDRtext = "abv"
    elseif XPDRvar == 3 then
        XPDRtext = "blw"
    elseif XPDRvar == 4 then
        XPDRtext = "TA"
    elseif XPDRvar == 5 then
        XPDRtext = "TARA"
    end
    if _MCP1() then
        DspShow("XPDR", XPDRtext)
    elseif _MCP2() then
        DspRadioShort(XPDRtext)
    elseif _MCP2a() then
        DspShow("XPDR", XPDRtext)
    end
end

function AB_PDS_XPDR_THRT_inc ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
	i = ipc.readLvar(Lvar)
	if i < 3 then
	   ipc.writeLvar(Lvar, i + 1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_THRT_show ()
end

function AB_PDS_XPDR_THRT_dec ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
	i = ipc.readLvar(Lvar)
 	if i > 0 then
	   ipc.writeLvar(Lvar, i-1)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_THRT_show ()
end

function AB_PDS_XPDR_THRT_thrt ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
    ipc.writeLvar(Lvar, 0)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_THRT_show ()
end

function AB_PDS_XPDR_THRT_all ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
    ipc.writeLvar(Lvar, 1)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_THRT_show ()
end

function AB_PDS_XPDR_THRT_abv ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
    ipc.writeLvar(Lvar, 2)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_THRT_show ()
end

function AB_PDS_XPDR_THRT_blw ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
    ipc.writeLvar(Lvar, 3)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_THRT_show ()
end

function AB_PDS_XPDR_THRT_cycle ()
Lvar = 'AB_PDS_XPDR_THRT_ALL_ABV_BLW'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 3 then
        AB_PDS_XPDR_THRT_inc ()
    else
        AB_PDS_XPDR_THRT_thrt()
    end
end

--$$ XPDR Mode

function AB_PDS_XPDR_MODE_show ()
local XPDRvar = ipc.readLvar("AB_PDS_XPDR_STBY_TA_TARA")
    if XPDRvar == 0 then
        XPDRtext = "stby"
    elseif XPDRvar == 1 then
        XPDRtext = "ta"
    elseif XPDRvar == 2 then
        XPDRtext = "tara"
    end
    if _MCP1() then
        DspShow("XPDR", XPDRtext)
    elseif _MCP2() then
        DspRadioShort(XPDRtext)
    elseif _MCP2a() then
        DspShow("XPDR", XPDRtext)
    end
end

function AB_PDS_XPDR_MODE_inc ()
Lvar = 'AB_PDS_XPDR_STBY_TA_TARA'
	i = ipc.readLvar(Lvar)
	if i < 2 then
	   ipc.writeLvar(Lvar, i + 1)
       --ipc.writeLvar("Mod_Xponder_mode_knob", i)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_MODE_show ()
end

function AB_PDS_XPDR_MODE_dec ()
Lvar = 'AB_PDS_XPDR_STBY_TA_TARA'
	i = ipc.readLvar(Lvar)
 	if i > 0 then
	   ipc.writeLvar(Lvar, i - 1)
       --ipc.writeLvar("Mod_Xponder_mode_knob", i-2)
	end
    AB_OVH_AdirsKnobRotate ()
    AB_PDS_XPDR_MODE_show ()
end

function AB_PDS_XPDR_MODE_stby ()
Lvar = 'AB_PDS_XPDR_STBY_TA_TARA'
    ipc.writeLvar(Lvar, 0)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_MODE_show ()
end

function AB_PDS_XPDR_MODE_ta ()
Lvar = 'AB_PDS_XPDR_STBY_TA_TARA'
    ipc.writeLvar(Lvar, 1)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_MODE_show ()
end

function AB_PDS_XPDR_MODE_tara ()
Lvar = 'AB_PDS_XPDR_STBY_TA_TARA'
    ipc.writeLvar(Lvar, 2)
    AB_MPL_KnobRotate ()
    AB_PDS_XPDR_MODE_show ()
end

function AB_PDS_XPDR_MODE_cycle ()
Lvar = 'AB_PDS_XPDR_STBY_TA_TARA'
    Lvarl = ipc.readLvar(Lvar)
    if  Lvarl < 2 then
        AB_PDS_XPDR_MODE_inc ()
    else
        AB_PDS_XPDR_MODE_stby()
    end
end

-- ## Weather Radar ###############

function AB_WX_SYS_on ()
    ipc.writeLvar("AB_WX_SYS", 0)
    AB_MPL_LightSwitch ()
    DspShow ("WXR", "on")
end

function AB_WX_SYS_off ()
    ipc.writeLvar("AB_WX_SYS", 1)
    AB_MPL_LightSwitch ()
    DspShow ("WXR", "off")
end

function AB_WX_SYS_toggle ()
    if _tl("AB_WX_SYS", 1) then
        AB_WX_SYS_on ()
	else
        AB_WX_SYS_off ()
	end
end

function AB_WX_GAIN_show ()
    WXRgain = round(ipc.readLvar("AB_WX_GAIN")/5)
    if WXRgain == 0 then WXRgainTxt = "MIN"
    elseif WXRgain == 1 then WXRgainTxt = "-12"
    elseif WXRgain == 2 then WXRgainTxt = "-9 "
    elseif WXRgain == 3 then WXRgainTxt = "-6 "
    elseif WXRgain == 4 then WXRgainTxt = "-3 "
    elseif WXRgain == 5 then WXRgainTxt = "CAL"
    elseif WXRgain == 6 then WXRgainTxt = "+4 "
    elseif WXRgain == 7 then WXRgainTxt = "+8 "
    elseif WXRgain == 8 then WXRgainTxt = "+12"
    elseif WXRgain == 9 then WXRgainTxt = "MAX"
    end
    DspShow ("GAIN", WXRgainTxt)
end

function AB_WX_GAIN_inc ()
    WXRgain = ipc.readLvar("AB_WX_GAIN")
    if WXRgain < 45 then
        WXRgain = WXRgain + 5
    else
        WXRgain = 45
    end
    ipc.writeLvar("AB_WX_GAIN", WXRgain)
    AB_WX_GAIN_show ()
end

function AB_WX_GAIN_dec ()
    WXRgain = ipc.readLvar("AB_WX_GAIN")
    if WXRgain > 0 then
        WXRgain = WXRgain - 5
    else
        WXRgain = 0
    end
    ipc.writeLvar("AB_WX_GAIN", WXRgain)
    AB_WX_GAIN_show ()
end

function AB_WX_GAIN_cal ()
    ipc.writeLvar("AB_WX_GAIN", 25)
    AB_WX_GAIN_show ()
end

---

function AB_WX_TILT_show ()
    WXRTILT = ipc.readLvar("AB_WX_TILT")
    if WXRTILT > 97 then
        WXRTILTtxt = round((WXRTILT - 97)/2.5) + 5
    elseif WXRTILT < 30 then
        WXRTILTtxt = round (WXRTILT/2.5) - 15
    else
        WXRTILTtxt = round(((WXRTILT - 20)/7) - 5.9)
    end
    DspShow ("TILT", WXRTILTtxt)
end

function AB_WX_TILT_inc ()
    WXRTILT = ipc.readLvar("AB_WX_TILT")
    if WXRTILT < 122 then
        if (WXRTILT <= 25 or WXRTILT >= 97) then
            WXRTILT = WXRTILT + 5
        elseif WXRTILT >= 62 then
            WXRTILT = WXRTILT + 7
        else
            WXRTILT = WXRTILT + 8
        end
    else
        WXRTILT = 122
    end
    ipc.writeLvar("AB_WX_TILT", WXRTILT)
    AB_WX_TILT_show ()
    _sleep(150)
end

function AB_WX_TILT_dec ()
    WXRTILT = ipc.readLvar("AB_WX_TILT")
    if WXRTILT > 0 then
        if (WXRTILT <= 30 or WXRTILT > 97) then
            WXRTILT = WXRTILT - 5
        elseif WXRTILT > 62 then
            WXRTILT = WXRTILT - 7
        else
            WXRTILT = WXRTILT - 8
        end
    else
        WXRTILT = 0
    end
    ipc.writeLvar("AB_WX_TILT", WXRTILT)
    AB_WX_TILT_show ()
    _sleep(150)
end

function AB_WX_TILT_zero ()
    ipc.writeLvar("AB_WX_TILT", 62)
    AB_WX_TILT_show ()
    _sleep(1000)
end

-----

function AB_WX_MULTI_off ()
    ipc.writeLvar("AB_WX_MULTI_AUTO", 0)
    AB_MPL_LightSwitch ()
    DspShow ("MULT", "off")
end

function AB_WX_MULTI_on ()
    ipc.writeLvar("AB_WX_MULTI_AUTO", 1)
    AB_MPL_LightSwitch ()
    DspShow ("MULT", "auto")
end

function AB_WX_MULTI_toggle ()
    if _tl("AB_WX_MULTI_AUTO", 0) then
        AB_WX_MULTI_on ()
	else
        AB_WX_MULTI_off ()
	end
end

-----

function AB_WX_GCS_off ()
    ipc.writeLvar("AB_WX_GCS", 0)
    AB_MPL_LightSwitch ()
    DspShow ("GCS", "off")
end

function AB_WX_GCS_on ()
    ipc.writeLvar("AB_WX_GCS", 1)
    AB_MPL_LightSwitch ()
    DspShow ("GCS", "auto")
end

function AB_WX_GCS_toggle ()
    if _tl("AB_WX_GCS", 0) then
        AB_WX_GCS_on ()
	else
        AB_WX_GCS_off ()
	end
end

-----

function AB_WX_TERR_on ()
    ipc.writeLvar("AB_MPL_ND_TERR", 1)
    AB_MPL_LightSwitch ()
    DspShow ("TERR", "on")
end

function AB_WX_TERR_off ()
    ipc.writeLvar("AB_MPL_ND_TERR", 0)
    AB_MPL_LightSwitch ()
    DspShow ("TERR", "off")
end

function AB_WX_TERR_toggle ()
    if _tl("AB_MPL_ND_TERR", 0) then
        AB_WX_TERR_on ()
	else
        AB_WX_TERR_off ()
	end
end


-- ## Other Pedestal ###############

function AB_PED_Spoilers_ARM ()
    ipc.control(66066)
    DspShow ("Splr", "arm")
end

function AB_PED_Spoilers_DISARM ()
    ipc.control(66067)
    DspShow ("Splr", "dsrm")
end

function AB_PED_Spoilers_arm_toggle ()
	if _tl("ASC_Spoilers_armed", 0) then
       AB_PED_Spoilers_ARM ()
	else
       AB_PED_Spoilers_DISARM ()
	end
end

function AB_PED_SecurityScreen_on ()
    ipc.writeLvar("AB_SECURITYSCREEN_SWITCH", 1)
    DspShow ("Scrn", "on")
    AB_OVH_Pushbutton ()
end

function AB_PED_SecurityScreen_off ()
    ipc.writeLvar("AB_SECURITYSCREEN_SWITCH", 0)
    DspShow ("Scrn", "off")
    AB_OVH_Pushbutton ()
end

function AB_PED_SecurityScreen_toggle ()
	if _tl("AB_SECURITYSCREEN_SWITCH", 0) then
       AB_PED_SecurityScreen_on ()
	else
       AB_PED_SecurityScreen_off ()
	end
end


-- ## windows ###############

function AB_CAPT_Window_open ()
   ipc.writeLvar("Sidewindow_open_CP", 1)
end

function AB_CAPT_Window_close ()
   ipc.writeLvar("Sidewindow_close_CP", 1)
end

function AB_CAPT_Window_toggle ()
	if _t("cwin") then
       AB_CAPT_Window_open ()
	else
       AB_CAPT_Window_close ()
	end
end

function AB_FO_Window_open ()
   ipc.writeLvar("Sidewindow_open_FO", 1)
end

function AB_FO_Window_close ()
   ipc.writeLvar("Sidewindow_close_FO", 1)
end

function AB_FO_Window_toggle ()
	if _t("cowin") then
       AB_FO_Window_open ()
	else
       AB_FO_Window_close ()
	end
end

-- ## Open Doors ###############

function AB_DOORS_Front_left_toggle ()
    ipc.control(66389)
    _sleep(200)
    ipc.control(65538)
    DspShow ("Frnt", "left", "Front", "left")
end

function AB_DOORS_Front_right_toggle ()
    ipc.control(66389)
    _sleep(200)
    ipc.control(65539)
    DspShow ("Back", "left", "Back", "left")
end

function AB_DOORS_Front_toggle ()
    AB_DOORS_Front_left_toggle()
    _sleep(1000)
    AB_DOORS_Front_right_toggle()
end

function AB_DOORS_Cargo_front_toggle ()
    ipc.control(66389)
    _sleep(100)
    ipc.control(65540)
    DspShow ("Crgo", "frnt", "Cargo", "front")
end

function AB_DOORS_Cargo_back_toggle ()
    ipc.control(66389)
    _sleep(100)
    ipc.control(65541)
    DspShow ("Crgo", "back", "Cargo", "back")
end

function AB_DOORS_Cargo_toggle ()
    _sleep(100)
    ipc.control(66389)
    _sleep(100)
    ipc.control(65540)
    DspShow ("Crgo", "frnt", "Cargo", "front")
    _sleep(1000)
    ipc.control(66389)
    _sleep(100)
    ipc.control(65541)
    DspShow ("Crgo", "back", "Cargo", "back")
end

-- $$ A330 Doors

function A33_DOOR_PAX_LEFT_FWD2_toggle()
    if A330 then
        Lvarl = ipc.readLvar('AB_DOOR_PAX_LEFT_FWD2')
        _loggg("PAXL2=" ..     Lvarl)
        if  Lvarl == 0 or     Lvarl == 100 then
            ipc.writeLvar('AB_DOOR_PAX_LEFT_FWD2_toggle',1)
            _sleep(20)
            ipc.writeLvar('AB_DOOR_PAX_LEFT_FWD2_toggle',1)
            _sleep(20)
            ipc.writeLvar('AB_DOOR_PAX_LEFT_FWD2_toggle',1)
            _sleep(20)
        end
    end
end

function A33_DOOR_PAX_RIGHT_FWD2_toggle()
    if A330 then
        Lvarl = ipc.readLvar('AB_DOOR_PAX_RIGHT_FWD2')
        _loggg("PAXR2=" ..     Lvarl)
        if  Lvarl == 0 or     Lvarl == 100 then
            ipc.writeLvar('AB_DOOR_PAX_RIGHT_FWD2_toggle',1)
            _sleep(20)
            ipc.writeLvar('AB_DOOR_PAX_RIGHT_FWD2_toggle',1)
            _sleep(20)
            ipc.writeLvar('AB_DOOR_PAX_RIGHT_FWD2_toggle',1)
            _sleep(20)
        end
    end
end

function A33_DOOR_CARGO_BULK_toggle()
    if A330 then
        Lvarl = ipc.readLvar('AB_DOOR_CARGO_BULK')
        _loggg("CARGOB=" ..     Lvarl)
        if  Lvarl == 0 or     Lvarl == 100 then
            ipc.writeLvar('AB_DOOR_CARGO_BULK_toggle',1)
            _sleep(20)
            ipc.writeLvar('AB_DOOR_CARGO_BULK_toggle',1)
            _sleep(20)
            ipc.writeLvar('AB_DOOR_CARGO_BULK_toggle',1)
            _sleep(20)
        end
    end
end

-- ## Ground Services ###############

-- $$ cones

function AB_EXT_TrafficCones_set ()
    ipc.writeLvar("MCDU_cones", 1)
    DspShow("Cone","set")
end

function AB_EXT_TrafficCones_removed ()
    ipc.writeLvar("MCDU_cones", 0)
    DspShow("Cone","rmov")
end

function AB_EXT_TrafficCones_toggle ()
    var = ipc.readLvar("MCDU_cones")
    if var == 1 then
        AB_EXT_TrafficCones_removed ()
    else
        AB_EXT_TrafficCones_set ()
    end
end

-- $$ chocks

function AB_EXT_WheelChocks_set ()
    ipc.writeLvar("Wheelchocks", 1)
    DspShow("Chok","set")
end

function AB_EXT_WheelChocks_removed ()
    ipc.writeLvar("Wheelchocks", 0)
    DspShow("Chok","rmov")
end

function AB_EXT_WheelChocks_toggle ()
    var = ipc.readLvar("Wheelchocks")
    if var == 1 then
        AB_EXT_WheelChocks_removed ()
    else
        AB_EXT_WheelChocks_set ()
    end
end

-- $$ External Power Set

function AB_EXT_ExtPwrGPU_conn ()
    ipc.writeLvar("MCDU_EXTPOWERCART", 1)
    DspShow("GPU","conn")
end

function AB_EXT_ExtPwrGPU_disc ()
    AB_OVH_EXT_PWR_off()
    ipc.writeLvar("MCDU_EXTPOWERCART", 0)
    DspShow("GPU","disc")
end

function AB_EXT_ExtPwrGPU_toggle ()
    var = ipc.readLvar("MCDU_EXTPOWERCART")
    if var == 1 then
        AB_EXT_ExtPwrGPU_disc()
    else
        AB_EXT_ExtPwrGPU_conn()
    end
end

-- $$ External Fixed Power Connection

function AB_EXT_ExtPwr_on ()
Lvar = "AB_VC_OVH_ELEC_EXTA_MPB"
    ipc.writeLvar(Lvar, 1)
    _sleep(50)
    ipc.writeLvar(Lvar, 0)
    DspShow("EPwr","on")
end

function AB_EXT_ExtPwr_off ()
Lvar = "AB_VC_OVH_ELEC_EXTA_MPB"
    ipc.writeLvar(Lvar, 1)
    _sleep(50)
    ipc.writeLvar(Lvar, 0)
    DspShow("EPwr","disc")
end

function AB_EXT_ExtPwr_toggle ()
Lvar = "AB_VC_OVH_ELEC_EXTA_MPB"
    var = ipc.readLvar(Lvar)
    if var == 1 then
        AB_EXT_ExtPwr_off()
    else
        AB_EXT_ExtPwr_on()
    end
end

-- ## A330 External Fixed Power Connection

function A33_EXT_ExtPwrB_on ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_EXTB_MPB"
    else
        return
    end
    ipc.writeLvar(Lvar, 1)
    DspShow("EPwr","on")
end

function A33_EXT_ExtPwrB_off ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_EXTB_MPB"
    else
        return
    end
    ipc.writeLvar(Lvar, 0)
    DspShow("EPwr","disc")
end

function A33_EXT_ExtPwr_toggle ()
    if A330 then
Lvar = "AB_VC_OVH_ELEC_EXTB_MPB"
    else
        return
    end
    var = ipc.readLvar(Lvar)
    if var == 1 then
        A33_EXT_ExtPwrB_off()
    else
        A33_EXT_ExtPwrB_on()
    end
end

-- ## other gimmicks ###############

-- $$ Standby Compass

function AB_STBY_Compass_open ()
   ipc.writeLvar("AB_STDBYCompass_anim_set", 1)
end

function AB_STBY_Compass_close ()
   ipc.writeLvar("AB_STDBYCompass_anim_set", 0)
end

function AB_STBY_Compass_toggle ()
    if _tl("AB_STDBYCompass_anim_set", 0) then
       AB_STBY_Compass_open ()
	else
       AB_STBY_Compass_close ()
	end
end

-- $$ Capt's Table

function AB_TableCapt_open ()
    ipc.writeLvar("Table1_open", 1)
end

function AB_TableCapt_close ()
    AB_Newspaper_off()
    _sleep(200)
    AB_Coffee_off()
    _sleep(200)
    AB_Mobile_off()
    _sleep(200)
    ipc.writeLvar("Table1_close", 1)
end

function AB_TableCapt_toggle ()
    if ipc.readLvar("Table1_pos") == 0 then
        AB_TableCapt_open()
    else
        AB_TableCapt_close()
    end
end

-- $$ FO Table

function AB_TableFO_open ()
    ipc.writeLvar("Table2_open", 1)
end

function AB_TableFO_close ()
    ipc.writeLvar("Table2_close", 1)
end

function AB_TableFO_toggle ()
    if ipc.readLvar("Table2_pos") == 0 then
        AB_TableFO_open()
    else
        AB_TableFO_close()
    end
end

-- $$ Tables

function AB_Tables_open ()
    AB_TableCapt_open()
    _sleep(300, 500)
    AB_TableFO_open()
end

function AB_Tables_close ()
    AB_TableCapt_close()
    _sleep(300, 500)
    AB_TableFO_close()
end

function AB_Tables_toggle ()
    AB_TableCapt_toggle()
    _sleep(300, 500)
    AB_TableFO_toggle()
end

-- $$ Jumpseat

function AB_Jumpseat_open ()
   ipc.writeLvar("Jumpseat_open", 1)
end

function AB_Jumpseat_close ()
   ipc.writeLvar("Jumpseat_close", 1)
end

function AB_Jumpseat_toggle ()
	if _t("jump") then
       AB_Jumpseat_open ()
	else
       AB_AB_Jumpseat_close ()
	end
end

-- $$ Newspaper

function AB_Newspaper_on ()
    if ipc.readLvar("Table1_open") == 1 then
        ipc.writeLvar("AB_VC_NEWSPAPER_ON_TABLE_CPT", 1)
    end
end

function AB_Newspaper_off ()
   ipc.writeLvar("AB_VC_NEWSPAPER_ON_TABLE_CPT", 0)
end

function AB_Newspaper_toggle ()
	if _t("AB_VC_NEWSPAPER_ON_TABLE_CPT") then
       AB_Newspaper_on ()
	else
       AB_Newspaper_off ()
	end
end

-- $$ Coffee Cup

function AB_Coffee_on ()
    if ipc.readLvar("Table1_open") == 1 then
        ipc.writeLvar("AB_VC_COFFEE_ON_TABLE_CPT", 1)
    end
end

function AB_Coffee_off ()
   ipc.writeLvar("AB_VC_COFFEE_ON_TABLE_CPT", 0)
end

function AB_Coffee_toggle ()
	if _t("AB_VC_COFFEE_ON_TABLE_CPT") then
       AB_Coffee_on ()
	else
       AB_Coffee_off ()
	end
end

-- $$ Mobile

function AB_Mobile_on ()
    if ipc.readLvar("Table1_open") == 1 then
        ipc.writeLvar("AB_VC_MOBILE_ON_TABLE_CPT", 1)
    end
end

function AB_Mobile_off ()
   ipc.writeLvar("AB_VC_MOBILE_ON_TABLE_CPT", 0)
end

function AB_Mobile_toggle ()
	if _t("AB_VC_MOBILE_ON_TABLE_CPT") then
       AB_Mobile_on ()
	else
       AB_Mobile_off ()
	end
end

-- ## Cockpit prepare ###############
function AB_Cockpit_Prepare ()
    -- << uncomment/comment for your needs
    AB_CD ()
end

-- skip checklist item
function AB_CL_SkipItem()
   ipc.writeLvar("CL_Skip_Item", 1)
   DspShow("CL","skip")
end

-- $$ Checklist

function A33_Checklist_Skip_Item ()
    if A330 then
        MCU2_PageVar = ipc.readLvar("MCDU2_Page")
        ipc.writeLvar("MCDU2_Page", 8)
        _sleep(200, 600)
        ipc.writeLvar("MCDU2_LSK2L", 1)
        _sleep(200, 600)
        ipc.writeLvar("MCDU2_LSK2L", 0)
        _sleep(200, 400)
        ipc.writeLvar("MCDU2_Page", MCU2_PageVar)
    end
end

function A33_Checklist_Copilot_toggle ()
    if A330 then
        MCU2_PageVar = ipc.readLvar("MCDU2_Page")
        ipc.writeLvar("MCDU2_Page", 8)
        _sleep(200, 600)
        ipc.writeLvar("MCDU2_LSK1R", 1)
        _sleep(200, 600)
        ipc.writeLvar("MCDU2_LSK1R", 0)
        _sleep(200, 400)
        ipc.writeLvar("MCDU2_Page", MCU2_PageVar)
    end
end

-- ## System functions   ##

-- Initial info on MCP display
function InitDsp ()
    if _MCP1() or _MCP2() then
        DspSPD(ipc.readLvar("AB_AP_SPEED_Select"))
        DspHDG(ipc.readLvar("AB_AP_HDG_Select"))
        DspALT(ipc.readLvar("AB_AP_ALT_Select") / 100)
        DspVVS(ipc.readLvar("AB_AP_VS_Select2"))
    else -- MCP2a
        AB_DspSPDtxt()
        AB_DspHDGtxt()
        AB_DspALTtxt()
        AB_DspSPD()
        AB_DspHDG()
        AB_DspALT()
        AB_DspVVS()
    end
end

-- Initial variables
function InitVars ()
    Airbus = true -- set flag for Airbus MCP2a panels

    -- test for A330 present
    A330 = false -- flag for Airbus A330 Pro
    airfile = ipc.readSTR(0x3D00,35)
    _loggg('[A3XX] Airfile=' .. airfile)
    if string.find(airfile, "A33") ~= nil then
        A330 = true
        _loggg("[A3XX] A330 found")
    end


    -- test for A321 present
    A321 = false -- flag for Airbus A330 Pro
    if string.find(airfile, "A321") ~= nil then
        A321 = true
        _loggg("[A3XX] A321 found")
    end

	nd_mode = 1 -- default ND mode
	baro_mode = 1  -- default BARO mode is hPa
	auto_brk = 0
    AutoDisplay = false -- override automatic display updates (SPD/HDG/ALT/VVS_
    DSP_MODE_one ()
    EcamTxt = 1
    OnVar = 16 -- change this for initial brightness of displays. 0 to 20
    --TestCnt = 0
    TestVar = ""
    TestLast = ""
    -- variables to prevent constant LCD display updating
    AB_MODE = false
    -- MCDU keyboard timeout
    AB_PED_MCDU_Key_Timer = 60000
    AB_PED_MCDU_Key_Flag = false
    ipc.set("MCDU", 0)
    -- ALT/VVS DspE Flash Protection
    AB_ALT_Dot = ' '
    AB_VVS_Sign = '-'
    AB_ALT_Zero = '0'
    AB_Dot = string.char(7)
    AB_NoDot = ' '
end

function AB_CD ()
    ipc.writeLvar("MCDU2_Page", 1)
    _sleep(50)
    AB_PED_MCDU2_LSK1L ()
    _sleep(50)
    ipc.writeLvar("MCDU2_Page", 0)
end

function AB_CTR_knob_show_A ()
    DspShow ("ND", "Mode")
end

function AB_CTR_knob_show_B ()
    DspShow ("WXR", "Mode")
end

function AB_TFC_knob_show_A ()
    DspShow ("ND", "Mode")
end

function AB_TFC_knob_show_B ()
    DspShow ("WXR", "Mode")
end


-- ## Display functions ###############

function AB_DispAB_AP_MCP1 ()

    ILS_cur = ipc.readLvar("AB_MPL_ILS")
    LOC_cur = ipc.readLvar("AB_AP_LOC")
    AP1_cur = ipc.readLvar("AB_AP_AP1")
    AP2_cur = ipc.readLvar("AB_AP_AP2")
    ATT_cur = ipc.readLvar("AB_AP_ATHR")
    APP_cur = ipc.readLvar("AB_AP_LOC2")
    FD_cur  = ipc.readLvar("AB_MPL_FD")

    APUbleed_cur    = ipc.readLvar("AB_OVH_PNEUBLEEDAPU")
    MASTERcaut_cur  = ipc.readLvar("AB_MPL_Master_Warning_Light_state")
    MASTERwarn_cur  = ipc.readLvar("AB_MPL_Master_Warning_Light_state")

    SPDmode_cur = ipc.readLvar("AB_AP_SPDmode_set")
    HDGmode_cur = ipc.readLvar("AB_AP_HDGmode_set")
    -- VSmode_cur  = ipc.readSB(0x5634)

    QNH_cur = ipc.readSW(0x0330) / 16

    -- QNH changed
    if QNH_cur ~= QNH_pre then
        QNH_pre = QNH_cur
        if round(QNH_cur, 0) == 1013 then
            DspShow ('BARO', ' STD')
        else
            DspShow('BARO', QNH_cur)
        end
    end

    -- Important LED change
        -- MASTER Caution
    if MASTERcaut_cur ~= MASTERcaut_pre then
        MASTERcaut_pre = MASTERcaut_cur
        if MASTERcaut_cur == 1 then
            FLIGHT_INFO1 = 'MSTR'
            FLIGHT_INFO2 = 'CAUT'
        else
            APchange = true
        end
    end

        -- MASTER Warning
    if MASTERwarn_cur ~= MASTERwarn_pre then
        MASTERwarn_pre = MASTERwarn_cur
        if MASTERwarn_cur == 1 then
            FLIGHT_INFO1 = 'MSTR'
            FLIGHT_INFO2 = 'WARN'
        else
            APchange = true
        end
    end
        -- APU Bleed LED on/off
    if APUbleed_cur ~= APUbleed_pre then
        APUbleed_pre = APUbleed_cur
        if APUbleed_cur == 1 then
            DspShow("APUb",">>on")
        else
            DspShow("APUb",">off")
        end
    end

    -- Selected / Managed Display
    if SPDmode_cur ~= SPDmode_pre then
        SPDmode_pre = SPDmode_cur
        if SPDmode_cur == 1 then
            val = '---'
    	else
            val = 'sel'
        end
        DspShow ("SPD", val)
    end

    if HDGmode_cur ~= HDGmode_pre then
        HDGmode_pre = HDGmode_cur
        if HDGmode_cur == 1 then
            val = '---'
    	else
            val = 'sel'
        end
        DspShow ("HDG", val)
    end

    if VSmode_cur ~= VSmode_pre then
        VSmode_pre = VSmode_cur
        if VSmode_cur == 1 then
            val = '---'
    	else
            val = 'sel'
        end
        DspShow ("VS", val)
    end

    -- Autopilot Display
    -- AP1
	if AP1_cur ~= AP1_pre then
        AP1_pre = AP1_cur
        APchange = true
        if AP1_cur == 1 then
            D11 = "1"
        else
            D11 = "_"
        end
	end

    -- AP2
	if AP2_cur ~= AP2_pre then
        AP2_pre = AP2_cur
        APchange = true
        if AP2_cur == 1 then
            D12 = "2"
        else
            D12 = "_"
        end
	end

    -- APPR mode
	if APP_cur ~= APP_pre then
        APP_pre = APP_cur
        APchange = true
        if APP_cur == 1 then
            D14 = "A"
        else
            D14 = "_"
        end
	end
    -- LOC mode
	if LOC_cur ~= LOC_pre then
        LOC_pre = LOC_cur
        APchange = true
        if LOC_cur == 1 then
            D14 = "L"
        else
            D14 = D14
        end
	end

    -- FD
	if FD_cur ~= FD_pre then
        FD_pre = FD_cur
        APchange = true
        if FD_cur == 1 then
            D21 = "F"
        else
            D21 = "_"
        end
	end

    -- ILS
	if ILS_cur ~= ILS_pre then
        ILS_pre = ILS_cur
        APchange = true
        if ILS_cur == 1 then
            D22 = "I"
        else
            D22 = "_"
        end
	end

    -- ATHR
	if ATT_cur ~= ATT_pre then
        ATT_pre = ATT_cur
        APchange = true
        if ATT_cur == 1 then
            D24 = "T"
        else
            D24 = "_"
        end
	end

    -- form 2 lines of flight info display
    if APchange == true then
        APchange = false
        FLIGHT_INFO1 = D11 .. D12 .. ' ' .. D14
        FLIGHT_INFO2 = D21 .. D22 .. ' ' .. D24
    end
end

function AB_DispGear_MCP1 ()
    GNOSE_cur = ipc.readSD(0x0BEC)
    GLEFT_cur = ipc.readSD(0x0BF4)
    GRIGHT_cur = ipc.readSD(0x0BF0)

    if GNOSE_cur ~= GNOSE_pre then
        GNOSE_pre = GNOSE_cur
        GEARchange = true

        if GNOSE_cur == 16383 then
            GNOSE = ' oo'
        elseif GNOSE_cur == 0 then
            GNOSE = ' -- '
        else
            GNOSE = ' ** '
        end
    end

    if GLEFT_cur ~= GLEFT_pre then
        GLEFT_pre = GLEFT_cur
        GEARchange = true

        if GLEFT_cur == 16383 then
            GLEFT = 'o##'
        elseif GLEFT_cur == 0 then
            GLEFT = '-##'
        else
            GLEFT = '*##'
        end
    end

    if GRIGHT_cur ~= GRIGHT_pre then
        GRIGHT_pre = GRIGHT_cur
        GEARchange = true

        if GRIGHT_cur == 16383 then
            GRIGHT = 'o'
        elseif GRIGHT_cur == 0 then
            GRIGHT = '-'
        else
            GRIGHT = '*'
        end
    end

    if GEARchange == true then
        GEARchange = false
        FLIGHT_INFO1 = GNOSE
        FLIGHT_INFO2 = GLEFT .. GRIGHT
    else
        APchange = true
    end
end

function AB_DispFlaps_MCP1 ()

    FLAP_cur = ipc.readSD(0x0BDC)

    if FLAP_pre ~= FLAP_cur then
        FLAP_pre = FLAP_cur

        if FLAP_cur == 0 then
            FLAP = '----'
            FLAPchange=true
        elseif FLAP_cur == 4096 or FLAP_cur == 6553 then
            FLAP = '1---'
            FLAPchange=true
        elseif FLAP_cur == 8192 then
            FLAP = '-2--'
            FLAPchange=true
        elseif FLAP_cur == 12287 then
            FLAP = '--3-'
            FLAPchange=true
        else
            FLAP = '---4'
            FLAPchange=true
        end
    end

    if FLAPchange == true then
        FLAPchange=false
        DspShow('FLAP', FLAP)
    else
        APchange = true
    end
end

function AB_ECAM_modes_show ()
    -- ECAM modes
    EcamVar = ipc.readLvar('ECAM_Mode')
--    _log("ECAM Mode = " .. EcamVar)
    if EcamVar == 1 then EcamTxt = "ENG "
    elseif EcamVar == 2 then EcamTxt = "BLED"
    elseif EcamVar == 3 then EcamTxt = "PRES"
    elseif EcamVar == 4 then EcamTxt = "ELEC"
    elseif EcamVar == 5 then EcamTxt = "HYD "
    elseif EcamVar == 6 then EcamTxt = "FUEL"
    elseif EcamVar == 7 then EcamTxt = "APU "
    elseif EcamVar == 8 then EcamTxt = "COND"
    elseif EcamVar == 9 then EcamTxt = "DOOR"
    elseif EcamVar == 10 then EcamTxt = "WHEL"
    elseif EcamVar == 11 then EcamTxt = "FCTL"
    elseif EcamVar == 12 then EcamTxt = "ALL "
    elseif EcamVar == 13 then EcamTxt = "SYS "
    elseif EcamVar == 14 then EcamTxt = "CRSE"
    else EcamTxt = "none"
    end

    -- Flap state
    FlapState = ipc.readLvar('ASC_Flaps_index')
    if FlapState == 0 then
        FlapStatetxt = "up"
    elseif FlapState == 1 then
        FlapStatetxt = " 1"
    elseif FlapState == 2 then
        FlapStatetxt = " 2"
    elseif FlapState == 3 then
        FlapStatetxt = " 3"
    elseif FlapState == 4 then
        FlapStatetxt = "dn"
    end

    if _MCP2() then
        APUstate = round(ipc.readLvar("APU_PCT_RPM"))
        if APUstate < 1 then
            FLIGHT_INFO1 = "FL ECAM"
            FLIGHT_INFO2 = FlapStatetxt .. " " .. EcamTxt
        elseif APUstate > 1 then
            FLIGHT_INFO1 = "FL APU"
            FLIGHT_INFO2 = FlapStatetxt .. " " .. APUstate .. "%  "
        end
    else
        DspShow ("ECAM", EcamTxt)
    end
end

function AB_DspSPD()
    AB_spd = ipc.readLvar("AB_AP_SPEED_Select")
    AB_mach = ipc.readLvar("AB_AP_MACH_Select")
    SPDTimeVar = ipc.readLvar("FCU_Managed_SPDdisp_override")
    SPDModeSet = ipc.readLvar("AB_AP_SPDmode_set")
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    local strVal
    if (SPDModeSet == 1 and SPDTimeVar == 0) then
        strVal = '---'
        if _MCP2a() then
            strVal = '---' .. string.char(7)
        else
            strVal = '---*'
        end
        DspSPDs(strVal, true)
    elseif not _MCP1() then
        if SpdMachVar == 0 then
            AB_spdMach = AB_spd
            DspSPD(AB_spdMach)
            DspSPDs('\\\\\\ ')
            if AB_SPDmode_Dot() then
                if _MCP2a() then
                    AB_DspSPDmode(false)
                else
                    AB_DspSPD_AP_on()
                end
            else
                if _MCP2a() then
                    AB_DspSPDmode(false)
                else
                    AB_DspSPD_AP_off()
                end
            end
        else -- MACH
            AB_spdMach = AB_mach*100+0.5
            DspSPDs("0." .. AB_spdMach)
        end
    end
end

function AB_DspHDG ()
    AB_hdg = ipc.readLvar("AB_AP_HDG_Select")
    AB_trk = ipc.readLvar("AB_AP_TRK_set")
    AB_hdgtrk = ipc.readLvar("AB_AP_HDGTRK")
    AB_drift = ipc.readLvar("WindDriftVal")
    HDGmodeSet = ipc.readLvar("AB_AP_HDGmode_setDisp")
    HDGoverride = ipc.readLvar("FCU_Managed_HDGdisp_override")
    if HDGmodeSet >= 0 and HDGoverride == 0
    then
        if _MCP2a() then
            DspHDGs("---" .. string.char(7))
        else
            DspHDGs("---*")
        end
        AB_DspHDGmode(true)
    else
        if AB_hdgtrk == 0 then
            AB_hdg = round(AB_hdg)
        else -- calculate track
            AB_hdg = round(AB_trk)
        end
        DspHDG(AB_hdg)
        AB_DspHDGmode(AB_HDGmode_Dot())
    end
end

function AB_DspALT ()
    AB_alt = ipc.readLvar("AB_AP_ALT_Select")
    if _MCP1() then return end
    DspALT(AB_alt/100)
    AB_DspALTmode()
end

function AB_DspVVS ()
local VS_alt
    KNOBALT = ipc.readLvar("AB_AP_KNOBALT")
    VSOverride = ipc.readLvar("FCU_Managed_VSdisp_override")
    if KNOBALT == 0 and VSOverride == 0 then
        if _MCP2a() then
            DspVVSs("----")
            AB_VVS_Sign = '-'
        else
            DspVVS_AP_on()
            DspVVSs("----", true)
        end
    else
        DspVVS_AP_off()
        if ipc.readLvar("AB_AP_HDGTRK") == 0 then
            VS_alt = ipc.readLvar("AB_AP_VS_Select2")
            DspVVS((VS_alt) * 1.0)
            if VS_alt >= 0 then
                AB_VVS_Sign = '+'
            else
                AB_VVS_Sign = '-'
            end
        else  -- display FPA
            VS_alt = ipc.readLvar("AB_AP_FPA_Select2")
            DspFPA((VS_alt) * 1.0)
            AB_VVS_Sign = ' '
        end
    end
end

-- function to stop DspE field flashing
function AB_DspE(val)
    if _MCP1() or _MCP2() then return end
    if val == nil then
        val = "0" .. AB_ALT_Dot .. "\\" .. AB_VVS_Sign
    end
    DspE(val, false)
end

function AB_APU_Ready_show ()
    ApuGen = ipc.readLvar("APU_avail")
    if ApuGen == 1 then
    	DspShow ("APU", "rdy")
     	_sleep(4000)
    end
end

-- AP mode dots
function AB_SPDmode_Dot ()
    SPD_mode_set = ipc.readLvar('AB_AP_SPDmode_set')
    if SPD_mode_set == 1 then
        return true
    else
        return false
    end
end

function AB_HDGmode_Dot ()
    HDG_mode_set = ipc.readLvar('AB_AP_HDGmode_setDisp')
    if HDG_mode_set == 1 then
        return true
    else
        return false
    end
end

function AB_ALTmode_Dot ()
    ALT_mode = ipc.readLvar('L:AP_AP_ALT_Mode')
    if ALT_mode == 1 then
        return true
    else
        return false
    end
end

function AB_DspAP1_on()
    DspAP1(true)
end

function AB_DspAP1_off()
    DspAP1(false)
end

function AB_DspAP2_on()
    DspAP2(true)
end

function AB_DspAP2_off()
    DspAP2(false)
end

function AB_DspILS_on()
    DspILS(true)
end

function AB_DspILS_off()
    DspILS(false)
end

function AB_DspSPDtxt(i)
    if _MCP1() then return end
    -- SPD/MACH
    if _MCP2a() then
        if i == 1  then
            Dsp0('MACH')
        else
            Dsp0('SPD ')
        end
    else  -- MCP2
        if i == 1  then
            Dsp0('\\\\\\M')
            Dsp1('ACH\\')
        else
            Dsp0('\\\\\\S')
            Dsp1('PD \\')
        end
    end
end

function AB_DspHDGtxt(i)
    if _MCP1() or _MCP2() then return end
    -- HDG/TRK
    if i == 1 then
        Dsp2('TRK ')
        DspB(' TRK')
        DspC('FPA ')
        Dsp7(' FPA')
    else
        Dsp2('HDG ')
        DspB(' HDG')
        DspC('V/S ')
        Dsp7(' V/S')
    end
end

function AB_DspALTtxt()
    if _MCP1() or _MCP2() then return end
    -- ALT mode
    Dsp5('ALT ')
    DspD('\\\\\\0')
    --DspE('0\\\\\\')
end

function AB_DspInfoClear()
    if _MCP1() or _MCP2() then return end
    DspILS(false)
    DspLOC(false)
    DspAT(false)
    DspAPPR(false)
    Dsp1('    ', true) -- blank ILS
    Dsp9('    ', true) -- blank LOC
    Dsp3('    ', true) -- blank APs
    Dsp4('    ', true) -- blank AT
    DspB('    ', true) -- blank HDG
    DspC('    ', true) -- blank V/S
    Dsp6('    ', true) -- blank APPR
end

function AB_DspSPDmode (i)
	if dev == 0 then return end
    if _MCP1() then return end
    local val
    if _MCP2a() then
        if i == true then
   	        val = "\\\\\\" .. string.char(7)
        else
            val = "\\\\\\ "
        end
        Dsp8(val)
    else
        if i then
            AB_DspSPD_AP_on()
        else
            AB_DspSPD_AP_off()
        end
    end
end

function AB_DspMACHmode (i)
	if dev == 0 then return end
    if not _MCP2a() then return end
    local val
    if i == true then
   	    val = string.char(7) .. "\\\\\\"
    else
        val = " \\\\\\"
    end
    Dsp9(val)
end

function AB_DspHDGmode (i)
	if dev == 0 then return end
    if _MCP1() then return end
    local val
    if _MCP2a() then
        if i then
            val = "\\\\\\" .. string.char(7)
        else
   	        val = "\\\\\\ "
        end
        DspA(val)
    else -- MCP2
        if i then
            val = "\\\\\\*"
        else
            val = "\\\\\\ "
        end
        DspC(val)
    end
end

function AB_DspALTmode ()
	if dev == 0 then return end
    if _MCP1() then return end
    local Dot
    local val
    Dot = ipc.readLvar('AP_AP_ALT_Mode')
    if Dot == 1 then
        if _MCP2a() then
            AB_ALT_Dot = AB_Dot
            AB_DspE()
        else
            val = "\\*\\\\"
            Dsp6(val)
        end
    else
        if _MCP2a() then
            AB_ALT_Dot = ' '
            AB_DspE()
        else
            val = "\\ \\\\"
            Dsp6(val)
        end
    end
end

function AB_DspSPD_AP_on ()
	if dev == 0 then return end
    if not _MCP2() then return end
    if ipc.readLvar("AB_AP_MACH_Select") == 0 then
   	    _sleep(20)
        com.write(dev, "DSP1\\\\*\\", 8)
    end
 end

function AB_DspSPD_AP_off ()
	if dev == 0 then return end
    if not _MCP2() then return end
    if ipc.readLvar("AB_AP_MACH_Select") == 0 then
   	    _sleep(20)
        com.write(dev, "DSP1\\\\ \\", 8)
    end
end

function AB_DspMode_Toggle()
    if ipc.get("DSPmode") == 1 then
        AB_DspInfoClear()
        AB_APPR = false
    end
    DSP_MODE_toggle()
end

-- ## System sounds ###############

function AB_OVH_Pushbutton ()
    ipc.writeLvar("SmallOverheadPushButtons", 1)
end

function AB_MPL_Knobclick ()
    ipc.writeLvar("ASC_Knobclick", 1)
end

function AB_MPL_KnobRotate ()
    ipc.writeLvar("ASC_KnobRotate", 1)
end

function AB_MPL_LightSwitch ()
    ipc.writeLvar("LightSwitch", 1)
end

function AB_MPL_NormalSwitch ()
    ipc.writeLvar("NormalSwitch", 1)
end

function AB_OVH_AdirsKnobRotate ()
    ipc.writeLvar("AdirsKnobRotate", 1)
end

function AB_PED_MCDU_CLICK ()
    ipc.writeLvar("ASC_MCDU_CLICK", 1)
end

-- ## System functions ###############

function Timer ()
    -- check AP2 status
    if ipc.readLvar('AB_AP_LOC2') == 0 and
        ipc.readLvar('AB_AP_AP2') == 1 and
        ipc.readLvar('AB_AP_AP1') == 1 then
        ipc.writeLvar(AB_AP_AP2, 0)
    end
    -- set display information
    if _MCP2() then
        if ipc.get("DSPmode") == 1 then
            -- show autopilot info
            AB_AP_INFO ()
        else
            -- show flaps/gears info
            AB_FLIGHT_INFO ()
        end
    elseif _MCP2a() then
        if ipc.get("DSPmode") == 1 then
            -- keep flag until all MODEs reset
            local info = Modes()
            if info ~= "M111" then
                AB_MODE = true
            else
                AB_MODE = false
            end
            -- show autopilot info
            AB_AP_INFO ()
        else
            -- show flaps/gears info
            AB_FLIGHT_INFO ()
        end
    else  -- Display for MCP1 Users
        -- Display Autopilot
        AB_DispAB_AP_MCP1 ()
        -- Display Gearstatus
        AB_DispGear_MCP1 ()
        -- Display Flapstatus
        AB_DispFlaps_MCP1 ()
    end
    -- set timer for MCDU Key Input Reversion
    if ipc.readLvar("MCDU_KBD") == 1 and AB_PED_MCDU_Key_Flag == false then
        AB_PED_MCDU_KEYB_on()
        Sounds("modechange")
    else
        AB_PED_MCDU_Key_Flag = false
    end
    -- handle timer for MCDU Key Input Reversion
    if ipc.elapsedtime() - ipc.get("MCDU") > AB_PED_MCDU_Key_Timer
        and AB_PED_MCDU_Key_Flag then
        AB_PED_MCDU_KEYB_off()
        Sounds("modechange")
    end
end

----------------------------------------------------------

-- display AP mode information
function AB_AP_INFO ()
    if _MCP2() then
        -- FD
        if ipc.readLvar('AB_MPL_FD') == 0 then
            DspFD(0)
        else
            DspFD(1)
        end
        -- ATHR
        if ipc.readLvar('AB_AP_ATHR') == 0 then
            DspAT(0)
        else
            DspAT(1)
        end
        -- LNAV
        if ipc.readLvar('AB_AP_HDGmode_setDisp') == 1 then
            DspLNAV_on ()
        else
            DspLNAV_off ()
            AB_DspHDGmode(AB_HDGmode_Dot())
        end
        -- VNAV
        if ipc.readLvar('AP_AP_ALT_Mode') == 1 then
            DspVNAV_on ()
            AB_DspALTmode(true)
        else
            DspVNAV_off ()
            AB_DspALTmode(false)
        end
        local Var, str1, str2
        -- A/THR
        Var = ipc.readLvar('AB_AP_ATHR')
        DspAT(Var)
        -- AP1
        Var = ipc.readLvar('AB_AP_AP1')
        if Var == 1 then
            str1 = ' 1AP'
        else
            str1 = ' -AP'
        end
        -- AP2
        Var = ipc.readLvar('AB_AP_AP2')
        if Var == 1 then
            str1 = str1 .. '2 '
        else
            str1 = str1 .. '- '
        end
        -- ILS
        Var = ipc.readLvar('AB_MPL_ILS')
        if Var == 1 then
            str2 = ' ILS '
        else
            str2 = '     '
        end
        -- LOC or APPR
        if (ipc.readLvar('AB_AP_LOC') == 1) then
            str2 = str2 .. 'LOC'
        elseif (ipc.readLvar('AB_AP_LOC2') == 1) then
            str2 = str2 .. 'APR'
        end
        FLIGHT_INFO1 = str1
        FLIGHT_INFO2 = str2
    elseif _MCP2a() then -- Airbus FCU
        local Var
        -- ILS
        Var = ipc.readLvar('AB_MPL_ILS')
        DspILS(Var)
        -- APs 1 & 2
        DspAPs(ipc.readLvar('AB_AP_AP1'), ipc.readLvar('AB_AP_AP2'))
        -- A/THR
        Var = ipc.readLvar('AB_AP_ATHR')
        DspAT(Var)
        -- LOC
        Var = ipc.readLvar('AB_AP_LOC')
        DspLOC(Var)
        -- APPR
        Var = ipc.readLvar('AB_AP_LOC2')
        if not AB_MODE then
            DspAPPR(Var)
        end
        -- reset flight information for Airbus MCP2a display
        FLIGHT_INFO1 = ""
        FLIGHT_INFO2 = ""
    end
    -- SPD/MACH labels
    AB_DspSPDtxt(ipc.readLvar('AB_AP_SPDMACH'))
    -- HDG/TRK labels
    AB_DspHDGtxt(ipc.readLvar('AB_AP_HDGTRK'))
    -- ALT labels
    AB_DspALTtxt()
    -- ALT/VVS DspE to avoid cursor flicker
    AB_DspE()
    -- AP VALUES --
    AB_DspSPD ()
    AB_DspHDG ()
    AB_DspALT ()
    AB_DspVVS ()
end

-----------------------------------------------------------

-- Display Flight Information
function AB_FLIGHT_INFO ()
local APUState, GndPwr, Cones, Chocks, GndConn
local PaxBoard, PaxMax, PaxAct, PaxPzt
local CargoBoard, CargoMax, CargoAct, CargoPzt
local FuelBoard, FuelMax, FuelAct, FuelPzt

    APUstate = round(ipc.readLvar("APU_PCT_RPM"))
    if APUstate == nil then APUstate = 0 end
    GndPwr = ipc.readLvar('AB_OVH_ELECEXT_AVAIL')
    if GndPwr == nil then GndPwr = 0 end
    Cones = ipc.readLvar('Cones')
    if Cones == nil then Cones = 0 end
    Chocks = ipc.readLvar('Wheelchocks')
    if Chocks == nil then Chocks = 0 end
    GndConn = GndPwr + Cones + Chocks

    -- *** NOTE - Lvars misspelt but correct (Dec 14)

    PaxBoard = ipc.readLvar('AB_MCUD2_LD_STS_PAX') -- ***
    if PaxBoard == nil then PaxBoard = 0 end
    PaxMax = ipc.readLvar('AB_PED_MCDU2_LS_PAX')
    if PaxMax == nil then PaxMax = 100 end
    PaxAct = ipc.readLvar('MCDU2_Loaded_Pax')
    if PaxAct == nil then PaxAct = 0 end
	
    CargoBoard = ipc.readLvar('AB_MCUD2_LD_STS_CAR') -- ***
    if CargoBoard == nil then CargoBoard = 0 end
    CargoMax = ipc.readLvar('AB_PED_MCDU2_LS_CAR_KG')
    if CargoMax == nil then CargoMax = 100 end
    CargoAct = ipc.readLvar('MCDU2_Loaded_Cargo')
    if CargoAct == nil then CargoMax = 0 end

    FuelBoard = ipc.readLvar('AB_MCUD2_LD_STS_FUEL') -- ***
    if FuelBoard == nil then FuelBoard = 0 end
    FuelMax = ipc.readLvar('AB_PED_MCDU2_LS_FUEL_KG')
    if FuelMax == nil then FuelMax = 100 end
    FuelAct = ipc.readLvar('MCDU2_Load_act_Fuel')
    if FuelAct == nil then FuelAct = 0 end

    -- calculate percentage boarded
    if PaxMax > 0 then
        PaxPzt = round((PaxAct/PaxMax)*100)
    else
        PaxPzt = 0
    end
    if CargoMax > 0 then
        CargoPzt = round((CargoAct/CargoMax)*100)
    else
        CargoPzt = 0
    end
    if FuelMax > 0 then
        FuelPzt = round((FuelAct/FuelMax)*100)
    else
        FuelPzt = 0
    end

    -- check APU runnng state
    if APUstate < 1 or APUstate > 99 then
        if _MCP2a() and Airbus then
            -- form output text
            PaxTxt = "Pax ".. PaxPzt .. "%"
            CargoTxt = "Cargo ".. CargoPzt .. "%"
            FuelTxt = "Fuel ".. FuelPzt .. "%"

            FLIGHT_INFO2 = ''
            if FuelBoard == 1 then
                FLIGHT_INFO1 = FuelTxt
            elseif PaxBoard == 1 then
                FLIGHT_INFO1 = PaxTxt
            elseif CargoBoard == 1 then
            FLIGHT_INFO1 = CargoTxt
            elseif GndConn > 0 then
                FLIGHT_INFO1 = "Gnd"
                FLIGHT_INFO2 = "Cons"
            else
                AB_ExtPwr_show()
            end
        else -- MCP1 or MCP2
            _logg('[awg] Flt Info MCP1/2')
            FLIGHT_INFO1 = ''
            FLIGHT_INFO2 = ''
            PaxTxt = "Pax  ".. PaxPzt .. "%"
            CargoTxt = "Crgo ".. CargoPzt .. "%"
            FuelTxt = "Fuel ".. FuelPzt .. "%"
            if (FuelBoard == 1
                and PaxBoard == 1
                and CargoBoard == 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = FuelTxt
            elseif (FuelBoard == 1
                and PaxBoard ~= 1
                and CargoBoard ~= 1) then
                FLIGHT_INFO1 = FuelTxt
                FLIGHT_INFO2 = "        "
            elseif (FuelBoard ~= 1
                and PaxBoard == 1
                and CargoBoard ~= 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = "        "
            elseif (FuelBoard ~=1
                and PaxBoard ~= 1
                and CargoBoard == 1) then
                FLIGHT_INFO1 = CargoTxt
                FLIGHT_INFO2 = "        "
            elseif (FuelBoard == 1
                and PaxBoard == 1
                and CargoBoard ~= 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = FuelTxt
            elseif (FuelBoard == 1
                and PaxBoard ~= 1
                and CargoBoard == 1) then
                FLIGHT_INOF1 = CargoTxt
                FLIGHT_INFO2 = FuelTxt
            elseif (FuelBoard ~=1
                and PaxBoard == 1
                and CargoBoard == 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = CargoTxt
            elseif GndConn > 0 then
                AB_ExtPwr_show()
            else
                AB_ECAM_modes_show()
            end
        end
--[[    _logg('[awg] AB F:' .. FuelBoard .. '/'
        .. FuelPzt .. '% =' .. FuelTxt
        .. '/P:' .. PaxBoard .. '/'
        .. PaxPzt .. '% =' .. PaxTxt
        .. '/C:' .. CargoBoard .. '/'
        .. CargoPzt .. '% =' .. CargoTxt
        .. '/Grd=' .. GndConn)
--]]
    else
        FLIGHT_INFO1 = ""
        FLIGHT_INFO2 = ""
    end
end

    --- Ground Conn
function AB_ExtPwr_show ()
    ExtPwr = ipc.readLvar('AB_OVH_ELECEXT_AVAIL') + ipc.readLvar('AB_OVH_ELECEXT')
    if ExtPwr == nil then ExtPwr = 0 end
    Cones = ipc.readLvar('Cones')
    if Cones == nil then Cones = 0 end
    Chocks = ipc.readLvar('Wheelchocks')
    if Chocks == nil then Chocks = 0 end
    if ExtPwr >= 1 and Cones == 1 and Chocks == 1 then
        ExtPwrTxtLong1 = "GPU|Chks"
        ExtPwrTxtLong2 = "Cones   "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr >= 1 and Cones == 1 and Chocks == 0 then
        ExtPwrTxtLong1 = "GPU     "
        ExtPwrTxtLong2 = "Cones   "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr >= 1 and Cones == 0 and Chocks == 0 then
        ExtPwrTxtLong1 = "GPU     "
        ExtPwrTxtLong2 = "avail   "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr >= 0 and Cones == 1 and Chocks == 1 then
        ExtPwrTxtLong1 = "Cones   "
        ExtPwrTxtLong2 = "Chocks  "
        ExtPwrTxtShort1 = "Cons"
        ExtPwrTxtShort2 = "Chks"
    elseif ExtPwr == 0 and Cones == 0 and Chocks == 1 then
        ExtPwrTxtLong1 = "Wheel   "
        ExtPwrTxtLong2 = "Chocks  "
        ExtPwrTxtShort1 = "Chks"
        ExtPwrTxtShort2 = "    "
    elseif ExtPwr >= 1 and Cones == 0 and Chocks == 1 then
        ExtPwrTxtLong1 = "GPU     "
        ExtPwrTxtLong2 = "Chocks  "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr == 0 and Cones == 1 and Chocks == 0 then
        ExtPwrTxtLong1 = "Cones   "
        ExtPwrTxtLong2 = "        "
        ExtPwrTxtShort1 = "Cone"
        ExtPwrTxtShort2 = "    "
    else
        ExtPwrTxtLong1 = "        "
        ExtPwrTxtLong2 = "        "
        ExtPwrTxtShort1 = "    "
        ExtPwrTxtShort2 = "    "
    end
    if (_MCP2a() and Airbus) or _MCP1() then
        FLIGHT_INFO1 = ExtPwrTxtShort1
        FLIGHT_INFO2 = ExtPwrTxtShort2
    else -- MCP2
        FLIGHT_INFO1 = ExtPwrTxtLong1
        FLIGHT_INFO2 = ExtPwrTxtLong2
    end
end

-- ## System show ###############

function Throttle_detends_show ()
    -- throttle detends
    ENG1_THRdet = ipc.readLvar('ThrottleDetend_CheckL')
    ENG2_THRdet = ipc.readLvar('ThrottleDetend_CheckR')
    ENG_THRdet = (ENG1_THRdet + ENG2_THRdet)/2
    if ENG_THRdet == 0 then
        DetTxt1 = "IDLE"
    elseif ENG_THRdet == 20 or ENG_THRdet == 25 then
        DetTxt1 = "CLB"
    elseif ENG_THRdet == 75 then
        DetTxt1 = "MCT"
    elseif ENG_THRdet == 100 then
        DetTxt1 = "TOGA"
    end
    if _MCP2() then
        FLIGHT_INFO1 = "Throttle"
        FLIGHT_INFO2 = DetTxt1
    else
        FLIGHT_INFO1 = "THR"
        FLIGHT_INFO2 = DetTxt1
    end
end

